import QtQuick 1.0
import MOLOMELib 1.0
import "../js/createComponent.js" as CreateComponent
import "../DialogComponents"
import "../ButtonComponents"
import "../../util/constant.js" as Constant


Rectangle {
    id: loginDialog
    width: parent.width
    height: parent.height
    color: "#80000000"
    signal clicked

    MouseArea {
        anchors.fill: loginDialog
        onClicked: {
            CreateComponent.destroyComponent(loginDialog,0);
        }
    }

    DialogHeader {
        id: header
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: -(body.height>>1)
        text: "Log In"
        MouseArea {
            anchors.fill: parent
            onClicked: {

            }
        }
    }

    DialogBody {
        id: body
        anchors.horizontalCenter: parent.horizontalCenter
        height: themeManager.bodyLoginDialogHeight
        anchors.top: header.bottom
        MouseArea {
            anchors.fill: parent
            onClicked: {

            }
        }

        DialogTextBox {
            id: usernameTextBox
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: text1.bottom
            anchors.topMargin: themeManager.smallPadding
            inputMethodHints: Qt.ImhNoPredictiveText
            fontCapitalization: Font.Normal
        }

        Text {
            id: text1
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: parent.top
            anchors.topMargin: themeManager.bigPadding
            anchors.left: parent.left
            anchors.leftMargin: themeManager.paddingLeftRight
            text: qsTr("Username :")
            font.pixelSize: themeManager.dialogFontSizeSmall
        }

        RadioButton {
            id: btnCheck
            anchors.right: body.right
            anchors.rightMargin: themeManager.paddingLeftRight
            anchors.bottom: passwordTextBox.top
            anchors.bottomMargin: themeManager.smallPadding
            bitmap: "../res/dialog_checkbox_normal.png"
            bitmap_pressed: "../res/dialog_checkbox_checked.png"
            bitmap_selected: "../res/dialog_checkbox_checked.png"
            text: qsTr("Show")
            textColor: "#808080"
            selected: false
            onClicked: {
                btnCheck.selected = btnCheck.selected == false ? true : false
                passwordTextBox.mode = btnCheck.selected == true ? TextInput.Normal : TextInput.Password
            }
        }

        MediumButton {
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: passwordTextBox.bottom
            anchors.topMargin: themeManager.bigPadding
            text: "OK"
            color: Constant.COLOR_GREEN
            onClicked: {
                loginDialog.clicked()
            }
        }

        Text {
            id: text3
            anchors.top: usernameTextBox.bottom
            anchors.topMargin: themeManager.bigPadding
            anchors.left: parent.left
            anchors.leftMargin: themeManager.paddingLeftRight
            text: "Password :"
            font.pixelSize: themeManager.dialogFontSizeSmall
        }

        DialogTextBox {
            id: passwordTextBox
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: text3.bottom
            anchors.topMargin: themeManager.smallPadding
            mode: TextInput.Password
        }
    }

    DialogBottom {
        id: bottom
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: body.bottom
        MouseArea {
            anchors.fill: parent
            onClicked: {

            }
        }
    }

    Component.onCompleted: {
        usernameTextBox.setFocus()
    }

    function getUsername() {
        return usernameTextBox.getText();
    }
    function getPassword() {
        return passwordTextBox.getText();
    }
    function destroyDialog() {
        CreateComponent.destroyComponent(loginDialog,0);
    }
}
