import QtQuick 1.0
import "../DialogComponents"
import "../ButtonComponents"
import "../js/createComponent.js" as CreateComponents

Rectangle {
    id: photoContextDialog
    width: parent.width
    height: parent.height
    color: "#80000000"
    signal flagForReviewClicked
    signal replyCommentClicked
    signal viewProfileClicked
    signal blockUserClicked
    signal deleteClicked
    signal readMoreClicked
    signal editCaptionClicked
    signal makeProfilePictureClicked
    signal changeAccessLevelClicked
    signal reshareClicked
    property bool isReshareActive
    property bool isFlagForReviewActive
    property bool isReplyThisCommentActive
    property bool isViewProfileActive
    property bool isBlockUserActive
    property bool isDeletePictureActive
    property bool isReadMoreActive
    property bool isEditCaptionActive
    property bool isMakeProfilePictureActive
    property bool isChangeAccessLevelActive
    property int globalMargins: themeManager.smallPadding

    MouseArea {
        anchors.fill: photoContextDialog
        onClicked: destroyDialog()
    }
    DialogHeader {
        id: header
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: -(body.height>>1)
        MouseArea {
            anchors.fill: parent
            onClicked: {

            }
        }
    }
    DialogBody {
        id:body
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: header.bottom
        height: childrenRect.height
        MouseArea {
            anchors.fill: parent
            onClicked: {

            }
        }
        Item{
            id: itemPhotoContextDialog
            width: body.width
            height: childrenRect.height + photoContextDialog.globalMargins
            Button {
                id: btnReshare
                anchors.top: parent.top
                anchors.topMargin: photoContextDialog.isReshareActive  == true ? photoContextDialog.globalMargins : 0
                bitmap: "../res/darkblue_color_button_long.png"
                bitmap_pressed: "../res/darkblue_color_button_long_click.png"
                text: (photoContextDialog.isReshareActive) ? "Reshare" : ""
                visible: (photoContextDialog.isReshareActive)
                height: (photoContextDialog.isReshareActive) ? themeManager.photoContexDialogBtnHeight : 0
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    photoContextDialog.reshareClicked()
                    destroyDialog();
                }
            }
            Button {
                id: btnFlagforReview
                anchors.top: btnReshare.bottom
                anchors.topMargin: photoContextDialog.isFlagForReviewActive  == true ? photoContextDialog.globalMargins : 0
                bitmap: "../res/orange_color_button_long.png"
                bitmap_pressed: "../res/orange_color_button_long_click.png"
                text: photoContextDialog.isFlagForReviewActive  == true ? "Flag For Review" : ""
                visible: photoContextDialog.isFlagForReviewActive  == true ? true : false
                height: photoContextDialog.isFlagForReviewActive  == true ? themeManager.photoContexDialogBtnHeight : 0
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    photoContextDialog.flagForReviewClicked()
                    destroyDialog();
                }
            }
            Button {
                id: btnReplyThisComment
                anchors.top: btnFlagforReview.bottom
                anchors.topMargin: photoContextDialog.isReplyThisCommentActive  == true ? photoContextDialog.globalMargins : 0
                bitmap: "../res/green_color_button_long.png"
                bitmap_pressed: "../res/green_color_button_long_click.png"
                text: photoContextDialog.isReplyThisCommentActive  == true ? "Reply This Comment" : ""
                visible: photoContextDialog.isReplyThisCommentActive  == true ? true : false
                height: photoContextDialog.isReplyThisCommentActive  == true ? themeManager.photoContexDialogBtnHeight : 0
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    photoContextDialog.replyCommentClicked()
                    destroyDialog();
                }
            }
            Button {
                id: btnViewProfile
                anchors.top: btnReplyThisComment.bottom
                anchors.topMargin: photoContextDialog.isViewProfileActive  == true ? photoContextDialog.globalMargins : 0
                bitmap: "../res/green_color_button_long.png"
                bitmap_pressed: "../res/green_color_button_long_click.png"
                text: photoContextDialog.isViewProfileActive  == true ? "View Profile" : ""
                visible: photoContextDialog.isViewProfileActive  == true ? true : false
                height: photoContextDialog.isViewProfileActive  == true ? themeManager.photoContexDialogBtnHeight : 0
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    photoContextDialog.viewProfileClicked()
                    destroyDialog();
                }
            }
            Button {
                id: btnBlockUser
                anchors.top: btnViewProfile.bottom
                anchors.topMargin: photoContextDialog.isBlockUserActive  == true ? photoContextDialog.globalMargins : 0
                bitmap: "../res/orange_color_button_long.png"
                bitmap_pressed: "../res/orange_color_button_long_click.png"
                text: photoContextDialog.isBlockUserActive  == true ? "Block This User" : ""
                visible: photoContextDialog.isBlockUserActive  == true ? true : false
                height: photoContextDialog.isBlockUserActive  == true ? themeManager.photoContexDialogBtnHeight : 0
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    photoContextDialog.blockUserClicked()
                    destroyDialog();
                }
            }

            Button {
                id: btnReadMore
                anchors.top: btnBlockUser.bottom
                anchors.topMargin: photoContextDialog.isReadMoreActive  == true ? photoContextDialog.globalMargins : 0
                bitmap: "../res/green_color_button_long.png"
                bitmap_pressed: "../res/green_color_button_long_click.png"
                text: photoContextDialog.isReadMoreActive  == true ? "Read More" : ""
                visible: photoContextDialog.isReadMoreActive  == true ? true : false
                height: photoContextDialog.isReadMoreActive  == true ? themeManager.photoContexDialogBtnHeight : 0
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    photoContextDialog.readMoreClicked()
                    destroyDialog();
                }
            }
            Button {
                id: btnEditCaption
                anchors.top: btnReadMore.bottom
                anchors.topMargin: photoContextDialog.isEditCaptionActive  == true ? photoContextDialog.globalMargins : 0
                bitmap: "../res/green_color_button_long.png"
                bitmap_pressed: "../res/green_color_button_long_click.png"
                text: photoContextDialog.isEditCaptionActive  == true ? "Edit Caption" : ""
                visible: photoContextDialog.isEditCaptionActive  == true ? true : false
                height: photoContextDialog.isEditCaptionActive  == true ? themeManager.photoContexDialogBtnHeight : 0
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    photoContextDialog.editCaptionClicked()
                    destroyDialog();
                }
            }
            Button {
                id: btnMakeProfilePicture
                anchors.top: btnEditCaption.bottom
                anchors.topMargin: photoContextDialog.isMakeProfilePictureActive  == true ? photoContextDialog.globalMargins : 0
                bitmap: "../res/green_color_button_long.png"
                bitmap_pressed: "../res/green_color_button_long_click.png"
                text: photoContextDialog.isMakeProfilePictureActive  == true ? "Make Profile Picture" : ""
                visible: photoContextDialog.isMakeProfilePictureActive  == true ? true : false
                height: photoContextDialog.isMakeProfilePictureActive  == true ? themeManager.photoContexDialogBtnHeight : 0
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    photoContextDialog.makeProfilePictureClicked()
                    destroyDialog();
                }
            }
            Button {
                id: btnChangeAccessLevel
                anchors.top: btnMakeProfilePicture.bottom
                anchors.topMargin: photoContextDialog.isChangeAccessLevelActive  == true ? photoContextDialog.globalMargins : 0
                bitmap: "../res/darkblue_color_button_long.png"
                bitmap_pressed: "../res/darkblue_color_button_long_click.png"
                text: photoContextDialog.isChangeAccessLevelActive  == true ? "Change Access Level" : ""
                visible: photoContextDialog.isChangeAccessLevelActive  == true ? true : false
                height: photoContextDialog.isChangeAccessLevelActive  == true ? themeManager.photoContexDialogBtnHeight : 0
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    photoContextDialog.changeAccessLevelClicked()
                    destroyDialog();
                }
            }
            Button {
                id: btnDeletePicture
                anchors.top: btnChangeAccessLevel.bottom
                anchors.topMargin: photoContextDialog.isDeletePictureActive  == true ? photoContextDialog.globalMargins : 0
                bitmap: "../res/orange_color_button_long.png"
                bitmap_pressed: "../res/orange_color_button_long_click.png"
                text: photoContextDialog.isDeletePictureActive  == true ? "Delete" : ""
                visible: photoContextDialog.isDeletePictureActive  == true ? true : false
                height: photoContextDialog.isDeletePictureActive  == true ? themeManager.photoContexDialogBtnHeight : 0
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    photoContextDialog.deleteClicked()
                    destroyDialog();
                }
            }
        }
    }
    DialogBottom {
        id: bottom
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: body.bottom
        MouseArea {
            anchors.fill: parent
            onClicked: ;
        }
    }
    function destroyDialog() {
        CreateComponents.destroyComponent(photoContextDialog, 0);
    }
}
