import QtQuick 1.0
import "../DialogComponents"
import "../ButtonComponents"
import "../js/createComponent.js" as CreateComponent

Rectangle {
    id: registerDialog
    width: parent.width
    height: parent.height
    color: "#80000000"
    signal clicked

    MouseArea {
        anchors.fill: registerDialog
        onClicked: {
            CreateComponent.destroyComponent(registerDialog,100);
        }
    }

    DialogHeader {
        id : header
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: -(body.height>>1)
        text: "Register"
        MouseArea {
            anchors.fill: parent
            onClicked: {

            }
        }
    }

    DialogBody {
        id : body
        anchors.top: header.bottom
        anchors.horizontalCenter: parent.horizontalCenter
        height: themeManager.bodyRegisterDialogHeight
        MouseArea {
            anchors.fill: parent
            onClicked: {

            }
        }

        DialogTextBox {
            id: usernameTextBox
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: text1.bottom
            anchors.topMargin: themeManager.smallPadding
            inputMethodHints: Qt.ImhNoPredictiveText
            fontCapitalization: Font.SmallCaps
        }

        Text {
            id: text1
            anchors.top: parent.top
            anchors.topMargin: themeManager.bigPadding
            anchors.left: parent.left
            anchors.leftMargin: themeManager.paddingLeftRight
            text: qsTr("Username :")
            font.pixelSize: themeManager.dialogFontSizeSmall
        }

        RadioButton {
            id: btnCheck
            anchors.right: body.right
            anchors.rightMargin: themeManager.paddingLeftRight
            anchors.bottom: passwordTextBox.top
            anchors.bottomMargin: themeManager.smallPadding
            bitmap: "../res/dialog_checkbox_normal.png"
            bitmap_pressed: "../res/dialog_checkbox_checked.png"
            bitmap_selected: "../res/dialog_checkbox_checked.png"
            text: qsTr("Show")
            textColor: "#808080"
            selected: false
            onClicked: {
                btnCheck.selected = btnCheck.selected == false ? true : false
                passwordTextBox.mode = btnCheck.selected == true ? TextInput.Normal : TextInput.Password
                confirmPasswordTextBox.mode = btnCheck.selected == true ? TextInput.Normal : TextInput.Password
            }
        }

        Text {
            id: text3
            anchors.left: parent.left
            anchors.leftMargin: themeManager.paddingLeftRight
            anchors.top: usernameTextBox.bottom
            anchors.topMargin: themeManager.bigPadding
            text: "Password :"
            font.pixelSize: themeManager.dialogFontSizeSmall
        }

        DialogTextBox {
            id: passwordTextBox
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: text3.bottom
            anchors.topMargin: themeManager.smallPadding
            mode: TextInput.Password
        }

        Text {
            id: text4
            anchors.top: passwordTextBox.bottom
            anchors.topMargin: themeManager.smallPadding
            anchors.left: parent.left
            anchors.leftMargin: themeManager.paddingLeftRight
            text: qsTr("Confirm Password :")
            font.pixelSize: themeManager.dialogFontSizeSmall
        }

        DialogTextBox {
            id: confirmPasswordTextBox
            anchors.top: text4.bottom
            anchors.topMargin: themeManager.smallPadding
            anchors.horizontalCenter: parent.horizontalCenter
            mode: TextInput.Password
        }

        Text {
            id: text5
            anchors.top: confirmPasswordTextBox.bottom
            anchors.topMargin: themeManager.smallPadding
            anchors.left: parent.left
            anchors.leftMargin: themeManager.paddingLeftRight
            text: qsTr("E-mail :")
            font.pixelSize: themeManager.dialogFontSizeSmall
        }

        DialogTextBox {
            id: emailTextBox
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: text5.bottom
            anchors.topMargin: themeManager.smallPadding
            inputMethodHints: Qt.ImhNoPredictiveText
            fontCapitalization: Font.SmallCaps
        }
        MediumButton {
            id: btnRegis
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: emailTextBox.bottom
            anchors.topMargin: themeManager.bigPadding
            text : "Register"
            onClicked: {
                registerDialog.clicked()
            }
        }
    }
    DialogBottom {
        id: bottom
        anchors.top: body.bottom
        anchors.horizontalCenter: parent.horizontalCenter
        MouseArea {
            anchors.fill: parent
            onClicked: {

            }
        }
    }

    Component.onCompleted: {
        usernameTextBox.setFocus()
    }

    function getUsername() {
        return usernameTextBox.getText();
    }
    function getPassword() {
        return passwordTextBox.getText();
    }
    function getConfirmPassword() {
        return confirmPasswordTextBox.getText();
    }
    function getEmail() {
        return emailTextBox.getText();
    }
    function destroyDialog() {
        CreateComponent.destroyComponent(registerDialog,100);
    }
}
