import QtQuick 1.0
import "../DialogComponents"
import "../ButtonComponents"
import "../js/createComponent.js" as CreateComponents

Rectangle {
    id: reshareDialog
    width: parent.width
    height: parent.height
    color: "#80000000"

    signal twitterClicked
    signal facebookClicked
    signal tumblrClicked
    signal vkClicked
    signal weiboClicked

    property bool isShareToTwitterActive
    property bool isShareToFacebookActive
    property bool isShareToTumblrActive
    property bool isShareToVKActive
    property bool isShareToWeiboActive

    property int globalMargins: themeManager.smallPadding

    MouseArea {
        anchors.fill: reshareDialog
        onClicked: destroyDialog();
    }
    DialogHeader {
        id: header
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: - (body.height >> 1)
        MouseArea {
            anchors.fill: parent
            onClicked: ;
        }
    }
    DialogBody {
        id:body
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: header.bottom
        height: childrenRect.height
        MouseArea {
            anchors.fill: parent
            onClicked: ;
        }
        Item {
            id: itemreshareDialog
            width: body.width
            height: childrenRect.height + reshareDialog.globalMargins
            Button {
                id: btnShareToTwitter
                anchors.top: parent.top
                anchors.topMargin: reshareDialog.isShareToTwitterActive  == true ? reshareDialog.globalMargins : 0
                bitmap: "../res/lightblue_color_button_long.png"
                bitmap_pressed: "../res/lightblue_color_button_long_click.png"
                text: reshareDialog.isShareToTwitterActive  == true ? "Share To Twitter" : ""
                visible: reshareDialog.isShareToTwitterActive  == true ? true : false
                height: reshareDialog.isShareToTwitterActive  == true ? themeManager.photoContexDialogBtnHeight : 0
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    reshareDialog.twitterClicked()
                    destroyDialog();
                }
            }
            Button {
                id: btnshareToFacebook
                anchors.top: btnShareToTwitter.bottom
                anchors.topMargin: reshareDialog.isShareToFacebookActive  == true ? reshareDialog.globalMargins : 0
                bitmap: "../res/darkblue_color_button_long.png"
                bitmap_pressed: "../res/darkblue_color_button_long_click.png"
                text: reshareDialog.isShareToFacebookActive  == true ? "Share To Facebook" : ""
                visible: reshareDialog.isShareToFacebookActive  == true ? true : false
                height: reshareDialog.isShareToFacebookActive  == true ? themeManager.photoContexDialogBtnHeight : 0
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    reshareDialog.facebookClicked()
                    destroyDialog();
                }
            }
            Button {
                id: btnshareToTumblr
                anchors.top: btnshareToFacebook.bottom
                anchors.topMargin: reshareDialog.isShareToTumblrActive  == true ? reshareDialog.globalMargins : 0
                bitmap: "../res/green_color_button_long.png"
                bitmap_pressed: "../res/green_color_button_long_click.png"
                text: reshareDialog.isShareToTumblrActive  == true ? "Share To Tumblr" : ""
                visible: reshareDialog.isShareToTumblrActive  == true ? true : false
                height: reshareDialog.isShareToTumblrActive  == true ? themeManager.photoContexDialogBtnHeight : 0
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    reshareDialog.tumblrClicked()
                    destroyDialog();
                }
            }
            Button {
                id: btnshareToVK
                anchors.top: btnshareToTumblr.bottom
                anchors.topMargin: reshareDialog.isShareToVKActive  == true ? reshareDialog.globalMargins : 0
                bitmap: "../res/orange_color_button_long.png"
                bitmap_pressed: "../res/orange_color_button_long_click.png"
                text: reshareDialog.isShareToVKActive  == true ? "Share To VK" : ""
                visible: reshareDialog.isShareToVKActive  == true ? true : false
                height: reshareDialog.isShareToVKActive  == true ? themeManager.photoContexDialogBtnHeight : 0
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    reshareDialog.vkClicked()
                    destroyDialog();
                }
            }
            Button {
                id: btnshareToWeibo
                anchors.top: btnshareToVK.bottom
                anchors.topMargin: reshareDialog.isShareToWeiboActive  == true ? reshareDialog.globalMargins : 0
                bitmap: "../res/lightblue_color_button_long.png"
                bitmap_pressed: "../res/lightblue_color_button_long_click.png"
                text: reshareDialog.isShareToWeiboActive  == true ? "Share To Weibo" : ""
                visible: reshareDialog.isShareToWeiboActive  == true ? true : false
                height: reshareDialog.isShareToWeiboActive  == true ? themeManager.photoContexDialogBtnHeight : 0
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    reshareDialog.weiboClicked()
                    destroyDialog();
                }
            }
        }
    }
    DialogBottom {
        id: bottom
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: body.bottom
        MouseArea {
            anchors.fill: parent
            onClicked: ;
        }
    }
    function destroyDialog() {
        CreateComponents.destroyComponent(photoViewScreen.reshareDialog, 0);
    }
}
