import QtQuick 1.0
import "../DialogComponents"
import "../UIComponents"
import "../ButtonComponents"
import "../js/createComponent.js" as CreateComponent

Rectangle {
    id: textDialog
    width: parent.width
    height: parent.height
    color: "#80000000"

    function moveCursorToEnd() {
        textBox.moveCursorToEnd()
    }

    MouseArea {
        anchors.fill: parent
        onClicked: {
            CreateComponent.destroyComponent(textDialog,0)
        }
    }
    property string headerText: ""
    property string caption: ""
    property string text
    property string textFake
    signal clicked(string text);
    DialogHeader {
        id: header
        text: textDialog.headerText
        anchors.horizontalCenterOffset: 0
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: -(body.height>>1)
        anchors.horizontalCenter: parent.horizontalCenter
        MouseArea {
            anchors.fill: parent
        }
    }
    DialogBody {
        id: body
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: header.bottom
        height: childrenRect.height
        MouseArea {
            width: parent.width
            height: captionBox.height + textBox.height + betweenTextBoxAndBtn.height + btnOK.height
        }
        Item {
            id: captionBox
            width: parent.width
            height: textDialog.caption == "" ? 0 : childrenRect.height
            anchors.top: parent.top
            anchors.topMargin: themeManager.smallPadding
            Text {
                id: caption
                color: "#808080"
                anchors.top: parent.top
                text: textDialog.caption
                width: parent.width
                anchors.left: parent.left
                anchors.leftMargin: themeManager.paddingLeftRight
                anchors.right: parent.right
                anchors.rightMargin: themeManager.paddingLeftRight
                parent: captionBox
                font.pixelSize: themeManager.dialogFontSizeBig
                styleColor: "#ffffff"
                style: Text.Raised
            }
        }
        GroupTextEdit {
            id: textBox
            width: parent.width
            anchors.top: captionBox.bottom
            anchors.topMargin: themeManager.smallPadding
            anchors.left: parent.left
            anchors.leftMargin: themeManager.paddingLeftRight
            anchors.right: parent.right
            anchors.rightMargin: themeManager.paddingLeftRight
            isMultiLine: true
            text: textDialog.text
            textFake: textDialog.textFake
        }
        Item10 {
            id: betweenTextBoxAndBtn
            anchors.top: textBox.bottom
            parent: body
        }
        MediumButton {
            id: btnOK
            anchors.top: betweenTextBoxAndBtn.bottom
            text: "OK"
            anchors.horizontalCenter: parent.horizontalCenter
            onClicked: textDialog.clicked(textBox.getTextEdit().text);
        }
    }
    DialogBottom {
        id: bottom
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: body.bottom
        MouseArea {
            anchors.fill: parent
        }
    }

    Component.onCompleted: {
        textBox.setFocus()
    }

    function destroyDialog(){
        CreateComponent.destroyComponent(textDialog,0);
    }
}
