import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../../util/constant.js" as Constant

Item {
    id: commentComponent
    width: themeManager.screenWidth
    height: childrenRect.height

    signal profilePictureClicked
    signal actionClicked
    signal usernameClicked

    CacheableImage {
        id: userPhoto
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.topMargin: themeManager.bigPadding
        anchors.leftMargin: themeManager.tenPadding
        width: themeManager.commentComponemtUserProfileWidthHieght
        height: themeManager.commentComponemtUserProfileWidthHieght
        sourceImagePath: "http://p60x60.molo.me/" + profile_picture_code + "_60x60"
        loadingImagePath: "../res/loading_thumbnail_image.png"
        cacheMode: ImageCacheMode.CacheProfileImage
        sourceSize: Qt.size(themeManager.commentComponemtUserProfileWidthHieght, themeManager.commentComponemtUserProfileWidthHieght)
        Rectangle{
            id: imageLeftArea
            anchors.fill: parent
            color : (leftArea.pressed && leftArea.containsMouse) ? Constant.COLOR_ARGB_SELECT_BLUE : Constant.COLOR_ARGB_TRANSPARENT

            MouseArea {
                id: leftArea
                anchors.fill: parent
                onClicked: {
                    if (comment_user_id > 0)
                        commentComponent.profilePictureClicked();
                }
            }
        }
    }
    Text {
        id: usernameTxt
        anchors.top: parent.top
        anchors.left: userPhoto.right
        anchors.topMargin: themeManager.smallPadding
        anchors.leftMargin: themeManager.bigPadding
        font.pixelSize: themeManager.commentComponentMediumFontSize
        text: username
        font.bold: true
        styleColor: "#ffffff"
        style: Text.Raised
        color: "#c09040"
        MouseArea {
            id: usernameHitbox
            anchors.fill: parent
            onClicked: {
                if (comment_user_id > 0)
                    commentComponent.usernameClicked()
            }
        }
    }
    Text {
        id: said
        anchors.top: parent.top
        text: ""
        font.bold: false
        anchors.left: usernameTxt.right
        anchors.leftMargin: themeManager.bigPadding
        font.pixelSize: themeManager.commentComponentMediumFontSize
    }
    Text {
        id: timestampTxt
        text: dateTimeModel.setDateTime(timestamp,Constant.FORMAT_DATE_TIME);
        font.bold: true
        style: Text.Raised
        styleColor: "#ffffff"
        anchors.top: usernameTxt.bottom
        anchors.left: userPhoto.right
        anchors.leftMargin: themeManager.bigPadding
        anchors.bottomMargin: themeManager.bigPadding
        font.pixelSize: themeManager.commentComponentSmallFontSize
        color: "#909090"
    }
    RadioButton {
        id: commentAction
        anchors.top: parent.top
        anchors.right: parent.right
        anchors.topMargin: 2
        anchors.rightMargin: themeManager.bigPadding
        bitmap: "../res/btn_comment_action_normal.png"
        bitmap_pressed: "../res/btn_comment_action_click.png"
        bitmap_selected: "../res/btn_comment_action_click.png"
        onClicked: parent.actionClicked()
    }
    Item {
        id: commentTextBox
        anchors.left: userPhoto.right
        anchors.top: timestampTxt.bottom
        height: comment.height
        anchors.right: parent.right
        anchors.leftMargin: themeManager.bigPadding
        anchors.rightMargin: themeManager.bigPadding
        anchors.topMargin: themeManager.bigPadding
        Text {
            id: comment
            width: parent.width
            wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            text: comment_text
            font.bold: true
            styleColor: "#ffffff"
            style: Text.Raised
            font.pixelSize: themeManager.commentComponentMediumFontSize
            color: "#808080"
        }
    }
    Item {
        id:box
        anchors.top: commentTextBox.bottom
        height: themeManager.bigPadding
    }
    Rectangle {
        id: separator
        width: parent.width
        height: 1
        anchors.top: box.bottom
        color: "#cccccc"
        anchors.left: parent.left
        anchors.leftMargin: themeManager.bigPadding
        anchors.right: parent.right
        anchors.rightMargin: themeManager.bigPadding
    }
}
