import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../../util/constant.js" as Constant

Rectangle {
    id: multiDelegate
    width: themeManager.screenWidth
    height: themeManager.notificationComponentHeight

    property bool pressed: middleArea.pressed && middleArea.containsMouse
    color: pressed ? Constant.COLOR_ARGB_SELECT_BLUE : Constant.COLOR_ARGB_NOTIF_NORMAL

    CacheableImage {
        id: imageLeft
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.topMargin: themeManager.smallPadding
        anchors.leftMargin: themeManager.bigPadding
        width: themeManager.notificationPhotoWidthHeight
        height: themeManager.notificationPhotoWidthHeight
        cacheMode: ImageCacheMode.CacheProfileImage
        loadingImagePath: "../res/loading_thumbnail_image.png"
        sourceImagePath: "http://p60x60.molo.me/" + profile_picture_code + "_60x60"
        sourceSize: Qt.size(themeManager.notificationPhotoWidthHeight, themeManager.notificationPhotoWidthHeight);

        Rectangle {
            id: imageLeftArea
            anchors.fill: parent
            color: (leftAreaHitBox.pressed && leftAreaHitBox.containsMouse) ? Constant.COLOR_ARGB_SELECT_BLUE : Constant.COLOR_ARGB_TRANSPARENT

            MouseArea {
                id: leftAreaHitBox
                anchors.fill: parent
                onClicked: pageStack.push(Qt.resolvedUrl("../Screen/ProfileViewScreen.qml"), {userName: username}, {userId: user_id});
            }
        }
    }

    Item {
        id: rightArea
        anchors.top: parent.top
        anchors.right: parent.right
        anchors.topMargin: themeManager.smallPadding
        anchors.rightMargin: themeManager.smallPadding
        width: 0

        Loader {
            id: rightAreaLoader
        }

        Component {
            id: followButtonComponent
            FollowButton {
                id: followButton
                isFollow: follow
                anchors.top: parent.top
                anchors.topMargin: themeManager.bigPadding
                anchors.right: parent.right
                anchors.rightMargin: themeManager.smallPadding
                onClicked: {
                    if (follow)
                    {
                        molomeServiceController.unfollowUser(username);
                        globalServices.emitSetFollowStatus(username, false);
                    }
                    else
                    {
                        molomeServiceController.followUser(username);
                        globalServices.emitSetFollowStatus(username, true);
                    }
                    globalServices.emitClearTimelineRequested();
                }
                Component.onCompleted: {
                    rightArea.width = followButton.width;
                    rightArea.height = followButton.height;
                }
            }
        }

        Component {
            id: friendRequestButtonComponent
            Item {
                id: friendAcceptRejectButtonArea
                width: btnRejectFriend.width + btnAcceptFriend.width + themeManager.smallPadding
                height: childrenRect.height
                anchors.top: parent.top
                anchors.topMargin: themeManager.bigPadding
                anchors.right: parent.right
                anchors.rightMargin: themeManager.smallPadding
                Button {
                    id: btnRejectFriend
                    anchors.right: parent.right
                    bitmap: "../res/btn_friend_reject.png"
                    bitmap_pressed: "../res/btn_friend_reject_pressed.png"
                    onClicked: {
                        textUpperLine.text = username + "'s request is rejected"
                        textUpperLine.font.pixelSize = themeManager.notificationTextUpperFontSize
                        textLowerLine.font.pixelSize = themeManager.notificationTextLowerFontSize
                        rightAreaLoader.sourceComponent = followButtonComponent
                        molomeServiceController.answerFriendRequest(user_id, false);
                        notificationModel.answerFollowRequest(user_id, false);
                        notificationModel.decreaseFollowRequestCount();
                    }
                }
                Button {
                    id: btnAcceptFriend
                    anchors.right: btnRejectFriend.left
                    anchors.rightMargin: themeManager.smallPadding
                    bitmap: "../res/btn_friend_accept.png"
                    bitmap_pressed: "../res/btn_friend_accept_pressed.png"
                    onClicked: {
                        textUpperLine.text = username + " is now following you"
                        textUpperLine.font.pixelSize = themeManager.notificationTextUpperFontSize
                        textLowerLine.font.pixelSize = themeManager.notificationTextLowerFontSize
                        rightAreaLoader.sourceComponent = followButtonComponent
                        molomeServiceController.answerFriendRequest(user_id, true);
                        notificationModel.answerFollowRequest(user_id, true);
                        notificationModel.decreaseFollowRequestCount();
                    }
                }
                Component.onCompleted: {
                    rightArea.width = friendAcceptRejectButtonArea.width;
                    rightArea.height = friendAcceptRejectButtonArea.height;
                }
            }
        }

        Component.onCompleted: {
            rightAreaLoader.sourceComponent = friendRequestButtonComponent
        }
    }

    Item {
        id: contentArea
        anchors.left: imageLeft.right
        anchors.right: rightArea.left
        anchors.top: imageLeft.top
        anchors.bottom: imageLeft.bottom

        Text {
            id: textUpperLine
            anchors.top: parent.top
            anchors.topMargin: themeManager.smallPadding
            anchors.left: parent.left
            anchors.right: parent.right
            height: themeManager.notificationTextAreaHeight
            color: pressed ? "#FFFFFF" : "#606060"
            style: pressed ? Text.Normal : Text.Raised
            styleColor: "#ffffff"
            font.pixelSize: themeManager.friendListScreenFontSize
            anchors.rightMargin: themeManager.bigPadding
            anchors.leftMargin: themeManager.bigPadding
            verticalAlignment: Text.AlignVCenter
            wrapMode: Text.Wrap

            Component.onCompleted: text = username
        }
        Text {
            id: textLowerLine
            anchors.top: textUpperLine.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            height: themeManager.notificationTextAreaHeight
            color: pressed ? "#FFFFFF" : "#808080"
            style: pressed ? Text.Normal : Text.Raised
            styleColor: "#ffffff"
            font.pixelSize: themeManager.smallProfileSettingFontSize
            anchors.rightMargin: themeManager.bigPadding
            anchors.leftMargin: themeManager.bigPadding
            verticalAlignment: Text.AlignVCenter

            Component.onCompleted: text = "10 photos"
        }

        MouseArea {
            id: middleArea
            anchors.fill: parent
            onClicked: pageStack.push(Qt.resolvedUrl("../Screen/ProfileViewScreen.qml"), {userName: username}, {userId: user_id});
        }
    }

    Rectangle {
        color: "#B0B0B0"
        width: parent.width
        anchors.bottom: parent.bottom
        height: 1
    }
}
