import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../../util/constant.js" as Constant

Item {
    id: multiDelegate
    width: multiDelegate.visible ? themeManager.screenWidth : 0
    height: multiDelegate.visible ? themeManager.friendListScreenHeight : 0

    signal profilePictureClicked
    signal usernameClicked
    signal photoCountClick
    signal followerCountClicked
    signal followingCountClick
    signal followClicked
    signal unfollowClicked

    anchors.topMargin: themeManager.bigPadding

    CacheableImage {
        id: imageProfile
        x: themeManager.friendListScreenImageProfileX
        y: themeManager.friendListScreenImageProfileY
        height: themeManager.friendListScreenImageProfileWidthHeight
        width: themeManager.friendListScreenImageProfileWidthHeight
        sourceImagePath: "http://p60x60.molo.me/" + profile_picture_code + "_60x60"
        loadingImagePath: "../res/loading_thumbnail_image.png"
        sourceSize: Qt.size(themeManager.friendListScreenImageProfileWidthHeight, themeManager.friendListScreenImageProfileWidthHeight)
        cacheMode: ImageCacheMode.CacheProfileImage
        Rectangle{
            id: imageLeftArea
            anchors.fill: parent
            color: (leftArea.pressed && leftArea.containsMouse) ? Constant.COLOR_ARGB_SELECT_BLUE : Constant.COLOR_ARGB_TRANSPARENT

            MouseArea {
                id: leftArea
                anchors.fill: parent
                onClicked: multiDelegate.profilePictureClicked()
            }
        }
    }
    Text {
        id: txtUsername
        x: themeManager.userNameFriendListScreenX
        y: themeManager.userNameFriendListScreenY
        text: username
        style: Text.Raised
        styleColor: "#e6e6e6"
        color: "#808080"
        font.pixelSize: themeManager.friendListScreenFontSize
        MouseArea{
            id: txtHitBox
            anchors.fill: parent
            onClicked: multiDelegate.usernameClicked()
        }
    }
    Image {
        id: imgKeyLock
        source: "../res/key_lock.png"
        anchors.left: txtUsername.right
        anchors.bottom: txtUsername.bottom
        visible: is_protected === 1
     }
    Text {
        id: txtStats
        x: themeManager.userNameFriendListScreenX
        y: themeManager.profileSummaryY
        text: (is_protected === 1 && !is_follow) ? "User is protected" : (photo_cnt + " photos")
        color: "#A0A0A0"
        font.italic: true
        font.pixelSize: themeManager.smallProfileSettingFontSize
    }
    Image {
        id: btnBlock
        visible: blocked
        anchors.verticalCenter: parent.verticalCenter
        anchors.right: parent.right
        anchors.rightMargin: themeManager.bigPadding
        source: "../res/btn_blocked.png"
    }
    SmallButton {
        id: btnFollowing
        text: (is_protected === 1 && !is_follow) ? "Requested" : "Following"
        x: themeManager.followBtnFriendListScreenX
        //y: themeManager.followBtnFriendListScreenY
        anchors.verticalCenter: parent.verticalCenter
        visible: (user_id !== userManager.getUserId()) && (is_follow || is_follow_requested) && !blocked
        iconSource: "../res/following_sign.png"
        onClicked: multiDelegate.unfollowClicked()
    }
    SmallButton {
        id: btnUnFollow
        text: "Follow"
        color: Constant.COLOR_GRAY
        x: themeManager.followBtnFriendListScreenX
        //y: themeManager.followBtnFriendListScreenY
        anchors.verticalCenter: parent.verticalCenter
        visible: (user_id !== userManager.getUserId()) && !(is_follow || is_follow_requested) && !blocked
        onClicked: multiDelegate.followClicked()
    }
    Rectangle {
        id: separator
        width: parent.width; height: 1; color: "#cccccc"
        anchors.top: parent.bottom
    }
}
