import QtQuick 1.0
import MOLOMELib 1.0
import "../ButtonComponents"
import "../UIComponents"
import "../../util/constant.js" as Constant
import "../js/createComponent.js" as CreateComponent
import "../js/uiUtils.js" as UIUtils

Item {
    width: parent.width
    height: isLoadMore ? themeManager.notificationComponentHeight + themeManager.tenPadding * 2 : themeManager.notificationComponentHeight

    Component {
        id: notificationItemElementComponent

        Rectangle {
            property bool pressed: middleArea.pressed && middleArea.containsMouse

            color: pressed ? Constant.COLOR_ARGB_SELECT_BLUE : (pinned ? Constant.COLOR_ARGB_NOTIF_PINNED_ITEM : (is_new ? Constant.COLOR_ARGB_NOTIF_NEW_ITEM : Constant.COLOR_ARGB_NOTIF_NORMAL))
            width: themeManager.screenWidth
            height: themeManager.notificationComponentHeight

            CacheableImage {
                id: imageLeft
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.topMargin: themeManager.smallPadding
                anchors.leftMargin: themeManager.bigPadding
                width: themeManager.notificationPhotoWidthHeight
                height: themeManager.notificationPhotoWidthHeight
                cacheMode: ImageCacheMode.CacheProfileImage
                //source: "http://p60x60.molo.me/" + (notificationType === 3 ? picture_code : profile_picture_code) + "_60x60" //"../res/molo_alert_face.png"
                //loadingSource: "../res/loading_thumbnail_image.png"
                loadingImagePath: "../res/loading_thumbnail_image.png"
                sourceImagePath: "http://p60x60.molo.me/" + ((notificationType === 3 || notificationType === 0) ? picture_code : profile_picture_code) + "_60x60"
                sourceSize: Qt.size(themeManager.notificationPhotoWidthHeight, themeManager.notificationPhotoWidthHeight);

                Rectangle {
                    id: imageLeftArea
                    anchors.fill: parent
                    color: (leftAreaHitBox.pressed && leftAreaHitBox.containsMouse) ? Constant.COLOR_ARGB_SELECT_BLUE : Constant.COLOR_ARGB_TRANSPARENT

                    MouseArea {
                        id: leftAreaHitBox
                        anchors.fill: parent
                        onClicked: {
                            if (action === 3)
                            {
                                var badge = badge_info;
                                CreateComponent.createBadgeDialog("../",mainScreen, QMapUtils.getDataByKey(badge, "path96x96"), QMapUtils.getDataByKey(badge, "name"), QMapUtils.getDataByKey(badge, "description"), QMapUtils.getDataByKey(badge, "badge_id"));
                            }
                            else if (action === 2)
                                Qt.openUrlExternally(url);
                            else
                                pageStack.push(Qt.resolvedUrl("../Screen/ProfileViewScreen.qml"), {userName: username}, {userId: user_id});
                        }
                    }
                }
            }

            Item {
                id: rightArea
                anchors.top: parent.top
                anchors.right: parent.right
                anchors.topMargin: themeManager.smallPadding
                anchors.rightMargin: themeManager.smallPadding
                width: 0

                Loader {
                    id: rightAreaLoader
                }

                Component {
                    id: rightFrameComponent
                    Rectangle {
                        id: rightFrame
                        anchors.top: parent.top
                        anchors.right: parent.right
                        anchors.rightMargin: themeManager.smallPadding
                        width: themeManager.notificationPhotoWidthHeight
                        height: themeManager.notificationPhotoWidthHeight
                        color: (imageRightAreaHitBox.pressed && imageRightAreaHitBox.containsMouse) ? Constant.COLOR_ARGB_SELECT_BLUE : "#FFFFFF"
                        border.width: 1
                        border.color: "#AAAAAA"

                        CacheableImage {
                            id: imageRight
                            anchors.top: parent.top
                            anchors.right: parent.right
                            anchors.topMargin: 3
                            anchors.rightMargin: themeManager.smallPadding
                            width: themeManager.notificationPhotoRightWidthHeight
                            height: themeManager.notificationPhotoRightWidthHeight
                            loadingImagePath: "../res/loading_thumbnail_image.png"
                            sourceImagePath: "http://p60x60.molo.me/" + picture_code + "_60x60"
                            sourceSize: Qt.size(themeManager.notificationPhotoRightWidthHeight, themeManager.notificationPhotoRightWidthHeight)
                            cacheMode: ImageCacheMode.CacheProfileImage
                        }

                        MouseArea {
                            id: imageRightAreaHitBox
                            anchors.fill: parent
                            onClicked: UIUtils.openPhotoViewFromPictureInfo(picture_info);
                        }

                        Component.onCompleted: {
                            rightArea.width = rightFrame.width;
                            rightArea.height = rightFrame.height;
                        }
                    }
                }

                Component {
                    id: followButtonComponent
                    FollowButton {
                        id: followButton
                        isFollow: follow
                        anchors.top: parent.top
                        anchors.topMargin: themeManager.bigPadding
                        anchors.right: parent.right
                        anchors.rightMargin: themeManager.smallPadding
                        onClicked: {
                            if (follow)
                            {
                                molomeServiceController.unfollowUser(username);
                                globalServices.emitSetFollowStatus(username, false);
                            }
                            else
                            {
                                molomeServiceController.followUser(username);
                                globalServices.emitSetFollowStatus(username, true);
                            }
                            globalServices.emitClearTimelineRequested();
                        }
                        Component.onCompleted: {
                            rightArea.width = followButton.width;
                            rightArea.height = followButton.height;
                        }
                    }
                }

                Component {
                    id: friendRequestButtonComponent
                    Item {
                        id: friendAcceptRejectButtonArea
                        width: btnRejectFriend.width + btnAcceptFriend.width + themeManager.smallPadding
                        height: childrenRect.height
                        anchors.top: parent.top
                        anchors.topMargin: themeManager.bigPadding
                        anchors.right: parent.right
                        anchors.rightMargin: themeManager.smallPadding
                        Button {
                            id: btnRejectFriend
                            anchors.right: parent.right
                            bitmap: "../res/btn_friend_reject.png"
                            bitmap_pressed: "../res/btn_friend_reject_pressed.png"
                            onClicked: {
                                textUpperLine.text = username + "'s request is rejected"
                                rightAreaLoader.sourceComponent = followButtonComponent
                                molomeServiceController.answerFriendRequest(action_user_id, false);
                                notificationModel.answerFollowRequest(action_user_id, false);
                                notificationModel.decreaseFollowRequestCount();
                            }
                        }
                        Button {
                            id: btnAcceptFriend
                            anchors.right: btnRejectFriend.left
                            anchors.rightMargin: themeManager.smallPadding
                            bitmap: "../res/btn_friend_accept.png"
                            bitmap_pressed: "../res/btn_friend_accept_pressed.png"
                            onClicked: {
                                textUpperLine.text = username + " is now following you"
                                rightAreaLoader.sourceComponent = followButtonComponent
                                molomeServiceController.answerFriendRequest(action_user_id, true);
                                notificationModel.answerFollowRequest(action_user_id, true);
                                notificationModel.decreaseFollowRequestCount();
                            }
                        }
                        Component.onCompleted: {
                            rightArea.width = friendAcceptRejectButtonArea.width;
                            rightArea.height = friendAcceptRejectButtonArea.height;
                        }
                    }
                }

                Component.onCompleted: {
                    // Consider Right Area Component
                    if (notificationType === 1) // Love
                        rightAreaLoader.sourceComponent = rightFrameComponent
                    else if (notificationType === 2) // Comment
                        rightAreaLoader.sourceComponent = rightFrameComponent
                    else if (notificationType === 3) // Badged
                        ;
                    else if (notificationType === 4) // Followed
                        rightAreaLoader.sourceComponent = followButtonComponent
                    else if (notificationType === 7)
                    {
                        if (be_followed)
                            rightAreaLoader.sourceComponent = followButtonComponent
                        else
                            rightAreaLoader.sourceComponent = friendRequestButtonComponent
                    }
                    else if (notificationType === 8)
                        rightAreaLoader.sourceComponent = followButtonComponent
                    else if (notificationType === 11)
                        rightAreaLoader.sourceComponent = rightFrameComponent
                }
            }

            Item {
                id: contentArea
                anchors.left: imageLeft.right
                anchors.right: rightArea.left
                anchors.top: imageLeft.top
                anchors.bottom: imageLeft.bottom

                Text {
                    id: textUpperLine
                    anchors.top: parent.top
                    anchors.topMargin: themeManager.smallPadding
                    anchors.left: parent.left
                    anchors.right: parent.right
                    height: themeManager.notificationTextAreaHeight
                    color: pressed ? "#FFFFFF" : "#606060"
                    style: pressed ? Text.Normal : Text.Raised
                    styleColor: "#ffffff"
                    font.pixelSize: themeManager.notificationTextUpperFontSize
                    anchors.rightMargin: themeManager.bigPadding
                    anchors.leftMargin: themeManager.bigPadding
                    verticalAlignment: Text.AlignVCenter
                    wrapMode: Text.Wrap

                    Component.onCompleted: text = notificationText
                }
                Text {
                    id: textLowerLine
                    anchors.top: textUpperLine.bottom
                    anchors.left: parent.left
                    anchors.right: parent.right
                    height: themeManager.notificationTextAreaHeight
                    color: pressed ? "#FFFFFF" : "#808080"
                    style: pressed ? Text.Normal : Text.Raised
                    styleColor: "#ffffff"
                    font.pixelSize: themeManager.notificationTextLowerFontSize
                    anchors.rightMargin: themeManager.bigPadding
                    anchors.leftMargin: themeManager.bigPadding
                    verticalAlignment: Text.AlignVCenter

                    Component.onCompleted: text = dateTimeModel.setDateTime(timestamp, Constant.FORMAT_DATE_TIME)
                }

                MouseArea {
                    id: middleArea
                    anchors.fill: parent
                    onClicked: {
                        switch (action)
                        {
                            case 1:
                                UIUtils.openPhotoViewFromPictureInfo(picture_info);
                                break;
                            case 2:
                                Qt.openUrlExternally(url);
                                break;
                            case 3:
                                var badge = badge_info;
                                CreateComponent.createBadgeDialog("../",mainScreen, QMapUtils.getDataByKey(badge, "path96x96"), QMapUtils.getDataByKey(badge, "name"), QMapUtils.getDataByKey(badge, "description"), QMapUtils.getDataByKey(badge, "badge_id"));
                                break;
                            case 4:
                                pageStack.push(Qt.resolvedUrl("../Screen/ProfileViewScreen.qml"), {userName: username}, {userId: user_id});
                                break;
                            default:
                                break;
                        }
                    }
                }
            }

            Rectangle {
                color: "#B0B0B0"
                width: parent.width
                anchors.bottom: parent.bottom
                height: 1
            }
        }
    }

    Component {
        id: notificationLoadMoreComponent
        LoadMoreButtonWithSpacer {
            width: themeManager.screenWidth
        }
    }

    Component {
        id: pendingFriendRequestComponent
        Image {
            property bool pressed: middleArea.pressed && middleArea.containsMouse

            width: themeManager.screenWidth
            height: themeManager.notificationComponentHeight
            source: "../res/friend_request_noti_item_bg.png"

            Rectangle {
                anchors.fill: parent
                color: pressed ? Constant.COLOR_ARGB_SELECT_BLUE : Constant.COLOR_ARGB_TRANSPARENT
            }

            Text {
                anchors.centerIn: parent
                text: notificationText
                color: pressed ? "#FFFFFF" : "#F0F0F0"
                style: Text.Normal
                font.pixelSize: themeManager.notificationFontSize
            }

            MouseArea {
                id: middleArea
                anchors.fill: parent
                onClicked: {
                    pageStack.push(Qt.resolvedUrl("../Screen/FriendRequestListScreen.qml"), {userName: username}, {userId: user_id});
                }
            }
        }
    }

    Loader {
        id: rightAreaLoader
    }

    Component.onCompleted: {
        if (isLoadMore)
            rightAreaLoader.sourceComponent = notificationLoadMoreComponent
        else if (notificationType === 9)
            rightAreaLoader.sourceComponent = pendingFriendRequestComponent
        else
            rightAreaLoader.sourceComponent = notificationItemElementComponent
    }
}
