import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../../util/constant.js" as Constant
import "../js/createComponent.js" as CreateComponent
import "../js/uiUtils.js" as UIUtils

Item {
    id: photoComponent
    width: themeManager.photoComponentWidth
    height: themeManager.photoComponentHeight

    property int cacheMode: ImageCacheMode.NoCache

    Image {
        id: frame
        source: "../res/timeline_thumbnail_bg.png"

        Rectangle {
            id: frameRect
            anchors.fill: parent
            property bool pressed: frameHitBox.pressed && frameHitBox.containsMouse
            color: pressed ? "#0983E8" : "#00000000"
        }

        CacheableImage {
            id: photo
            x: themeManager.photoInPortraitXY
            y: themeManager.photoInPortraitXY
            width: themeManager.photoInPhotoComponentWidthHeight
            height: themeManager.photoInPhotoComponentWidthHeight
            cacheMode: photoComponent.cacheMode
            sourceSize: Qt.size(themeManager.photoInPhotoComponentWidthHeight, themeManager.photoInPhotoComponentWidthHeight)
            loadingImagePath: "../res/loading_thumbnail_image.png"
            sourceImagePath: "http://p105x105.molo.me/" + picture_code + "_105x105" + ((access_level === "only me" || access_level === "friends") ? ("_" + salt) : "")
        }

        MouseArea {
            id: frameHitBox
            anchors.fill: parent
            onClicked: UIUtils.openPhotoViewFromPictureInfo(picture_info);
        }
    }

    Image {
        id: love_comment
        anchors.top: frame.bottom
        anchors.topMargin: themeManager.smallPaddingPhotoComponent
        source: "../res/timeline_love_comment_bar_bg.png"

        property bool lovePressed: hitboxLove.pressed && hitboxLove.containsMouse
        property bool commentPressed: hitboxComment.pressed && hitboxComment.containsMouse

        Image {
            x: themeManager.loveX
            source: love_comment.lovePressed ? "../res/timeline_love_highlighted.png" : "../res/blank.png"

            MouseArea {
                id: hitboxLove
                anchors.fill: parent
                onClicked: {
                    if (done_love)
                    {
                        molomeServiceController.unlovePicture(picture_id);
                        globalServices.emitSetLovedCommentedData(picture_id, love_count-1, false, comment_count, false);
                        CreateComponent.createUnLoveComponent(photo, false);
                    }
                    else
                    {
                        molomeServiceController.lovePicture(picture_id);
                        globalServices.emitSetLovedCommentedData(picture_id, love_count+1, true, comment_count, false);
                        CreateComponent.createLoveComponent(photo, false);
                    }
                }
            }
        }

        Image {
            x: themeManager.commentX
            source: love_comment.commentPressed ? "../res/timeline_comment_highlighted.png" : "../res/blank.png"

            MouseArea {
                id: hitboxComment
                anchors.fill: parent
                onClicked: UIUtils.openPhotoViewFromPictureInfoWithCommentDialog(picture_info);
            }
        }

        Image {
            x: themeManager.loveAreaX
            y: themeManager.loveCommentAreaY
            source: done_love === false ? "../res/thumbnail_loved_icon_gray.png" : "../res/thumbnail_loved_icon.png"
        }

        Image {
            x: themeManager.commentAreaX
            y: themeManager.loveCommentAreaY
            source: "../res/thumbnail_commented_icon.png"
        }

        Text {
            id: loveCount
            x: themeManager.loveCountPhotoComponentX
            y: themeManager.loveCommentCountPhotoComponentY
            width: themeManager.loveCommentCountPhotoComponentWidth
            height: themeManager.loveCommentCountPhotoComponentHeight
            text: love_count
            color: love_comment.lovePressed ? "white" : "#808080"
            font.bold: true
            font.pixelSize: themeManager.loveCommentPhotoComponentFontSize
            verticalAlignment: Text.AlignVCenter
            horizontalAlignment: Text.AlignHCenter
        }

        Text {
            id: commentCount
            x: themeManager.commentCountPhotoComponentX
            y: themeManager.loveCommentCountPhotoComponentY
            width: themeManager.loveCommentCountPhotoComponentWidth
            height: themeManager.loveCommentCountPhotoComponentHeight
            text: comment_count
            color: love_comment.commentPressed ? "white" : "#808080"
            font.bold: true
            font.pixelSize: themeManager.loveCommentPhotoComponentFontSize
            verticalAlignment: Text.AlignVCenter
            horizontalAlignment: Text.AlignHCenter
        }
    }

    Text {
        id: uploader
        x: themeManager.uploaderTimestampPhotoComponentX
        anchors.top: love_comment.bottom
        anchors.topMargin: themeManager.smallPaddingPhotoComponent - 1
        text: "by <b>" + username + "</b>"
        font.pixelSize: themeManager.userDetailPhotoComponentFontSize
        width: parent.width - themeManager.smallPaddingPhotoComponent
        color: "#808080"
    }

    Text {
        id: timestamp
        x: themeManager.uploaderTimestampPhotoComponentX
        anchors.top: uploader.bottom
        text: dateTimeModel.setDateTime(create_time, Constant.FORMAT_DATE_TIME);
        font.pixelSize: themeManager.userDetailPhotoComponentFontSize
        width: parent.width - themeManager.smallPaddingPhotoComponent
        color: "#808080"
    }

}
