import QtQuick 1.0
import MOLOMELib 1.0
import "../ButtonComponents"
import "../UIComponents"
import "../../util/constant.js" as Constant
import "../js/createComponent.js" as CreateComponent
import "../js/uiUtils.js" as UIUtils

Item {
    id: photoViewBox

    property string salt: photoViewScreen.salt
    property string access_level: photoViewScreen.access_level
    property string picture_code: photoViewScreen.picture_code

    property bool access_level_set: false
    property bool picture_code_set: false
    property bool salt_set: false

    width: themeManager.screenWidth
    height: childrenRect.height

    onPicture_codeChanged: {
        if (photoViewScreen.picture_code !== "" && photoViewScreen.pictureInfo.picture_id !== -1 && typeof photoViewScreen.pictureInfo.picture_id !== "undefined")
            picture_code_set = true;
        if (picture_code_set && access_level_set && (access_level === "public" || salt_set))
            loadPhoto()
    }

    onAccess_levelChanged: {
        if (access_level !== "")
            access_level_set = true;
        if (picture_code_set && access_level_set && (access_level === "public" || salt_set))
            loadPhoto()
    }

    onSaltChanged: {
        salt_set = true;
        if (picture_code_set && access_level_set && (access_level === "public" || salt_set))
            loadPhoto()
    }

    function loadPhoto()
    {
        if (photoViewScreen.picture_code !== "" && photoViewScreen.pictureInfo.picture_id !== -1 && typeof photoViewScreen.pictureInfo.picture_id !== "undefined")
        {
            if (themeManager.platform === "meego")
                photo.sourceImagePath = "http://p480x480.molo.me/" + photoViewScreen.picture_code + "_480x480" + ((access_level === "only me" || access_level === "friends") ? ("_" + salt) : "")
            else
                photo.sourceImagePath = "http://p340x340.molo.me/" + photoViewScreen.picture_code + "_340x340" + ((access_level === "only me" || access_level === "friends") ? ("_" + salt) : "")
        }
    }

    Item10 {
        id: headerBox
        anchors.top: parent.top
    }
    CacheableImage {
        id: photo
        Rectangle {
            id: photoBox
            width: themeManager.photoViewScreenPhotoWidthHeight
            height: themeManager.photoViewScreenPhotoWidthHeight
            color: "#DBDBDB"
        }
        anchors.top: headerBox.bottom

        onSourceChanged: downloadProgressBar.visible = false;

        onImageLoaded: {
            if (photoViewScreen.loading !== null && typeof photoViewScreen.loading !== "undefined")
                CreateComponent.destroyComponent(photoViewScreen.loading.getPageId(), 0);
            photoBox.visible = false;
        }

        width: themeManager.photoViewScreenPhotoWidthHeight
        height: themeManager.photoViewScreenPhotoWidthHeight
        sourceSize: Qt.size(themeManager.photoViewScreenPhotoWidthHeight, themeManager.photoViewScreenPhotoWidthHeight)
        loadingImagePath: ""//../res/loading_thumbnail_image.png"
        needOAuth: true
        cacheMode: ImageCacheMode.CacheLargeImage

        Rectangle {
            id: downloadProgressBar
            height: parent.height / 15
            width: parent.width / 3
            color: "#AAAAAA"
            anchors.centerIn: parent
            radius: height / 2

            Rectangle {
                id: downloadProgress
                height: parent.height
                width: radius * 2 + (downloadPercentage * (parent.width - (radius * 2)))
                color: "#666666"
                radius: parent.radius
            }
        }

        Rectangle {
            id: imageLeftArea
            anchors.fill: parent
            color : (leftArea.pressed && leftArea.containsMouse && photoViewScreen.ads_url != "") ? Constant.COLOR_ARGB_SELECT_BLUE : Constant.COLOR_ARGB_TRANSPARENT

            MouseArea {
                id: leftArea
                anchors.fill: parent
                onClicked: {
                    if (photoViewScreen.ads_url != "")
                        readMore();
                }
            }
        }
    }
    Item {
        id: captionPhoto
        width: parent.width
        height: (setting.height > caption.height ? setting.height : (caption.height + themeManager.tenPadding)) + themeManager.bigPadding
        anchors.top: photo.bottom
        anchors.topMargin: themeManager.smallPadding

        Text {
            id: caption
            width: themeManager.photoViewScreenPhotoCaptionWidth
            x: themeManager.photoViewScreenPhotoCaptionX
            y: themeManager.photoViewScreenPhotoCaptionY
            text: photoViewScreen.picture_name
            font.pixelSize: themeManager.photoViewScreenFontSize
            wrapMode: Text.WrapAtWordBoundaryOrAnywhere
        }
        Flickable {
            id: captionFlickable
            visible: false
            width: themeManager.photoViewScreenPhotoCaptionWidth
            contentHeight: caption.height
            anchors.top: captionPhoto.top
            interactive: true
            clip: true
            flickableDirection: Flickable.VerticalFlick
        }
        Button {
            id: setting
            bitmap: "../res/btn_image_action_normal.png"
            bitmap_pressed: "../res/btn_image_action_click.png"
            onClicked: createPictureActionDialog();
        }
    }
    Item {
        id: btnLoveCommentBox
        anchors.top: captionPhoto.bottom
        width: parent.width
        height: childrenRect.height
        LoveCommentButton {
            id: love
            anchors.left: parent.left
            anchors.leftMargin: themeManager.smallPadding
            isLoveBtn: true
            isLove: photoViewScreen.done_love
            value: photoViewScreen.love_count
            onClicked: {
                if (!photoViewScreen.done_love) {
                    molomeServiceController.lovePicture(photoViewScreen.pictureInfo.picture_id);
                    photoViewScreen.love_count +=1;
                    photoViewScreen.done_love = true
                    globalServices.emitSetLovedCommentedData(photoViewScreen.pictureInfo.picture_id, photoViewScreen.love_count, photoViewScreen.done_love, photoViewScreen.comment_count, false);
                    CreateComponent.createLoveComponent(photo, true);
                } else {
                    molomeServiceController.unlovePicture(photoViewScreen.pictureInfo.picture_id);
                    photoViewScreen.love_count -=1;
                    photoViewScreen.done_love = false;
                    globalServices.emitSetLovedCommentedData(photoViewScreen.pictureInfo.picture_id, photoViewScreen.love_count, photoViewScreen.done_love, photoViewScreen.comment_count, false);
                    CreateComponent.createUnLoveComponent(photo, true);
                }
                photoViewScreen.forceLoveStatus = true
            }
        }
        LoveCommentButton {
            id: comment
            isLoveBtn: false
            value: photoViewScreen.comment_count
            onClicked: showPostCommentDialog("", 0);
        }
    }
    GroupTextEdit {
        id: commentBox
        anchors.top: btnLoveCommentBox.bottom
        anchors.topMargin: themeManager.bigPadding
        isMultiLine: true
        anchors.right: parent.right
        anchors.rightMargin: themeManager.bigPadding
        anchors.left: parent.left
        anchors.leftMargin: themeManager.bigPadding
        text: photoViewScreen.commentText
        textFake: "Comment Here"
        onTextChanged: photoViewScreen.commentText = commentBox.getText()
    }
    SmallButton {
        id: summitBtn
        anchors.top: commentBox.bottom
        anchors.topMargin: themeManager.bigPadding
        anchors.left: parent.left
        anchors.leftMargin: themeManager.bigPadding
        text: "Submit"
        onClicked: {
            if (photoViewScreen.pictureInfo.picture_id !== -1 && typeof photoViewScreen.pictureInfo.picture_id !== "undefined")
                postComment(commentBox.getTextEdit().text, photoViewScreen.pictureInfo.picture_id, 0);
        }
    }
    Rectangle {
        id: separator
        width: parent.width
        height: 1
        anchors.top: summitBtn.bottom
        anchors.topMargin: themeManager.bigPadding
        color: "#cccccc"
        anchors.left: parent.left
        anchors.leftMargin: themeManager.bigPadding
        anchors.right: parent.right
        anchors.rightMargin: themeManager.bigPadding
    }

    Component.onCompleted: {
        checkIsPortrait()
        globalServices.largePictureDownloadProgressUpdated.connect(onLargePictureDownloadProgressUpdated);
    }

    Component.onDestruction: {
        globalServices.largePictureDownloadProgressUpdated.disconnect(onLargePictureDownloadProgressUpdated);
    }

    function onLargePictureDownloadProgressUpdated(url, bytesReceived, bytesTotal) {
        downloadPercentage = (bytesReceived + 0.0) / bytesTotal;
    }

    function checkIsPortrait() {
        if (themeManager.isPortrait) {
            // photo
            photo.anchors.horizontalCenter = photoViewBox.horizontalCenter
            // captionPhoto
            //captionPhoto.width = photoViewBox.width
            //captionPhoto.anchors.left = photoViewBox.left
            //captionPhoto.anchors.right = photoViewBox.right
            captionPhoto.anchors.leftMargin = themeManager.bigPadding
            captionPhoto.anchors.rightMargin = themeManager.bigPadding
            // flickable
            captionFlickable.width = 0
            captionFlickable.contentWidth = 0
            captionFlickable.height = 0
            captionFlickable.contentHeight = 0
            // caption
            caption.width = themeManager.photoViewScreenPhotoCaptionWidth
            // setting
            setting.x = themeManager.photoViewScreenSettingX
            setting.anchors.right = captionPhoto.right
            setting.anchors.verticalCenter = captionPhoto.verticalCenter
            setting.anchors.rightMargin = themeManager.smallPadding
            // btnLoveCommentBox
            //btnLoveCommentBox.width = photoViewBox.width
            // love
            love.anchors.left = btnLoveCommentBox.left
            love.anchors.margins = themeManager.smallPadding
            // comment
            comment.anchors.right = btnLoveCommentBox.right
            comment.anchors.rightMargin = themeManager.smallPadding
        } else {
            // photo
            photo.anchors.left = photoViewBox.left
            photo.anchors.leftMargin = themeManager.bigPadding
            // captionPhoto
            captionPhoto.width = photoViewBox.width - photo.width
            captionPhoto.height = photo.height - (btnLoveCommentBox.height + setting.height + ((themeManager.bigPadding * 2)))
            captionPhoto.anchors.top = photoViewBox.top
            captionPhoto.anchors.left = photo.right
            //captionPhoto.anchors.right = photoViewBox.right
            captionPhoto.anchors.leftMargin = themeManager.bigPadding
            captionPhoto.anchors.rightMargin = themeManager.bigPadding
            // caption
            caption.parent = captionFlickable.contentItem
            // flickable
            captionFlickable.visible = true
            captionFlickable.height = captionPhoto.height-setting.height-themeManager.tenPadding
            captionFlickable.contentItem.height = captionPhoto.height-setting.height-themeManager.tenPadding
            // setting
            //betweenCaptionAndLoveBtn.height = 3;
            setting.anchors.left = captionPhoto.left
            setting.anchors.bottom = captionPhoto.bottom
            setting.anchors.leftMargin = themeManager.smallPadding
            // btnLoveCommentBox
            btnLoveCommentBox.anchors.left = photo.right
            btnLoveCommentBox.anchors.leftMargin = themeManager.bigPadding
            btnLoveCommentBox.width = love.width
            // love
            love.anchors.left = btnLoveCommentBox.left
            love.anchors.top = btnLoveCommentBox.top
            // comment
            comment.anchors.left = btnLoveCommentBox.left
            comment.anchors.leftMargin = themeManager.smallPadding
            comment.anchors.top = love.bottom
        }
    }
}
