import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../js/createComponent.js" as CreateComponent
import "../../platforms"
import "../js/storage.js" as Storage

PageWrapper {
    id: campaignScreen
    property int storageIndex: storageDriveIndex
    property int imageResolution: finalImageResolution
    property int timeInterval: autoRefreshTime/(60000)
    property string dateTime: campaignScreen.timeInterval == 60 ? " Hours":" mins"
    property variant cncTermsDialog: null
    property variant loadingDialog: null
    property int transactionId: 0

    width: themeManager.screenWidth
    height: themeManager.screenHeight

    orientationLock: themeManager.pageOrientationPortrait

    Header {
        id: header
        hasBack: true
        anchors.top: parent.top
        onBackClicked: {
            pageStack.pop();
        }
    }

    HeaderBar {
        id: headerCaption
        anchors.top: header.bottom
        text: qsTr("Campaign")
    }

    Flickable {
        id: flickable
        width: parent.width
        contentWidth: parent.width
        contentHeight: campaignScreenItem.height
        anchors.top: headerCaption.bottom
        anchors.bottom: parent.bottom
        interactive: true
        clip: true
        Item {
            id: campaignScreenItem
            width: themeManager.screenWidth
            height: childrenRect.height
            SettingListItemData {
                id: autoRefreshListItem
                anchors.top: parent.top
                text: "Clean&Clear"
                isLast: false
                fieldData: isCleanAndClearCampaignOn === true ? "ON":"OFF"
                onClicked: {
                    if (isCleanAndClearCampaignOn === true) {
                        Storage.setData("isCleanAndClearCampaignOn","0");
                        isCleanAndClearCampaignOn = false
                    } else {
                        campaignScreen.cncTermsDialog = CreateComponent.createCncTermsDialog();
                        campaignScreen.cncTermsDialog.agreed.connect(
                            function(checked) {
                                campaignScreen.loadingDialog = CreateComponent.createLoadingDialog(campaignScreen, "Submitting ....");
                                campaignScreen.loadingDialog.clicked.connect(
                                    function() {
                                        molomeServiceController.cancelTransactionByTransactionID(campaignScreen.transactionId);
                                    }
                                );
                                campaignScreen.transactionId = molomeServiceController.answerTermsCondition("10002", true, campaignScreen.cncTermsDialog.isCheckBoxChecked(), termsAnswerHandler);
                                CreateComponent.destroyComponent(campaignScreen.cncTermsDialog, 0);
                                //login(username,password);
                            }
                        );
                        campaignScreen.cncTermsDialog.notAgreed.connect(
                            function() {
                                CreateComponent.destroyComponent(campaignScreen.cncTermsDialog, 0);
                                //login(username,password);
                            }
                        );
                    }
                }
            }
        }
    }

    MolomeServiceHandler {
        id: termsAnswerHandler
        function onMolomeServiceDataReceived(success, data)
        {
            CreateComponent.destroyComponent(campaignScreen.loadingDialog);
            if (success)
            {
                Storage.setData("isCleanAndClearCampaignOn", "1");
                isCleanAndClearCampaignOn = true;
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(campaignScreen, "", "Error: Please try again later");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.destroyComponent(campaignScreen.loadingDialog);
            var informationDialog = CreateComponent.createInformationDialog(campaignScreen, "", "Error: Please try again later");
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

}

