import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../../util/common.js" as Common
import "../../util/oauth/oauth.js" as OAuthJS
import "../js/createComponent.js" as CreateComponent
import "../../platforms"

PageWrapper {
    id: dropBoxScreen
    width: themeManager.screenWidth
    height: themeManager.screenHeight
    orientationLock: themeManager.pageOrientationPortrait

    property int dropbox_user_id
    property string oauth_token
    property string oauth_token_secret

    property variant dialog: null
    property int transactionId

    Header {
        id: header
        anchors.top: parent.top
        hasBack: true
        onBackClicked: pageStack.pop();
    }
    Flickable {
        id: dropBoxBox
        width: parent.width
        height: parent.height - header.height
        contentWidth: dropBox.contentsSize.width
        contentHeight: dropBox.contentsSize.height
        interactive: true
        clip: true
        anchors.top: header.bottom
        flickableDirection: Flickable.HorizontalAndVerticalFlick

        DropBox {
            id: dropBox
            //tw_oauth_token: oauth_token
            preferredHeight: dropBoxBox.height
            preferredWidth: dropBoxBox.width
            onUser_oauth_tokenChanged: whenUserIsAuthenticated(dropBox.user_uid, dropBox.user_oauth_token);

            LoadingImage {
                id: loadingImage
                anchors.fill: parent
                anchors.centerIn: parent
            }

            Component.onCompleted: nami.clearCookies();

            onLoadStarted: loadingImage.visible = true;
            onLoadFinished: loadingImage.visible = false;
        }
    }

    Component.onCompleted: molomeServiceController.getDropBoxToken(dropBoxTokenHandler);

    MolomeServiceHandler {
        id: dropBoxTokenHandler
        function onMolomeServiceDataReceived(success, data)
        {
            //console.log("Request Token: " + data);
            var param = OAuthJS.OAuth.getParameterMap(OAuthJS.OAuth.decodeForm(data));
            if (param["oauth_token"] !== "")
            {
                dropBox.doAuthorize(param["oauth_token"]);
                dropBoxScreen.oauth_token = param["oauth_token"];
                dropBoxScreen.oauth_token_secret = param["oauth_token_secret"];
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(dropBoxScreen, "", "Error: Please try again later");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(dropBoxScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    MolomeServiceHandler {
        id: updateHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(dropBoxScreen.dialog.getPageId(), 0);
                globalServices.emitDropBoxLoggedInStatusChanged(true);
                userManager.setDropBoxAvailibility(true);
                var informationDialog = CreateComponent.createInformationDialog(dropBoxScreen, "", "Linked to DropBox!");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(dropBoxScreen, "", ret.reason);
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(dropBoxScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    MolomeServiceHandler {
        id: dropBoxAccessTokenHandler
        function onMolomeServiceDataReceived(success, data)
        {
            console.log("data: " + data);
            var param = OAuthJS.OAuth.getParameterMap(OAuthJS.OAuth.decodeForm(data));
            if (param.oauth_token !== "")
            {
                dropBoxScreen.transactionId = molomeServiceController.updateDropBoxProfile(param.uid, param.oauth_token, param.oauth_token_secret, updateHandler);
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(dropBoxScreen, "", "Error: Please try again");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(dropBoxScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    function whenUserIsAuthenticated(user_uid, user_oauth_token) {
        dropBoxScreen.dropbox_user_id = user_uid
        dropBoxScreen.dialog = CreateComponent.createLoadingDialog(dropBoxScreen, "Linking to DropBox ....");
        dropBoxScreen.dialog.clicked.connect(
            function() {
                molomeServiceController.cancelTransactionByTransactionID(dropBoxScreen.transactionId);
                pageStack.pop();
            }
        );
        dropBoxScreen.transactionId = molomeServiceController.getDropBoxAccessToken(user_oauth_token, dropBoxScreen.oauth_token, dropBoxScreen.oauth_token_secret, dropBoxAccessTokenHandler);
    }
}
