import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../js/createComponent.js" as CreateComponent
import "../../platforms"

PageWrapper {
    id: facebookScreen
    width: themeManager.screenWidth
    height: themeManager.screenHeight

    orientationLock: themeManager.pageOrientationPortrait

    property variant dialog: null
    property int transactionId

    Header {
        id: header
        anchors.top: parent.top
        hasBack: true
        onBackClicked: pageStack.pop();
    }

    Flickable {
        id: facebookBox
        width: parent.width
        height: parent.height - header.height
        contentWidth: facebook.width
        contentHeight: facebook.height
        interactive: true
        clip: true
        anchors.top: header.bottom
        Facebook {
            id:facebook
            preferredHeight: facebookBox.height
            preferredWidth: facebookBox.width
            onTokenReady: whenUserIsAuthenticated(token);
            onGettingAccessToken: {

            }

            LoadingImage {
                id: loadingImage
                anchors.fill: parent
                anchors.centerIn: parent
            }

            Component.onCompleted: nami.clearCookies();

            onLoadStarted: loadingImage.visible = true;
            onLoadFinished: loadingImage.visible = false;
        }
    }

    MolomeServiceHandler {
        id: updateHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(facebookScreen.dialog.getPageId(),0);
                var informationDialog = CreateComponent.createInformationDialog(facebookScreen, "", "Linked to Facebook!");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
                globalServices.emitFacebookLoggedInStatusChanged(true);
                userManager.setFacebookAvailibility(true);
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(facebookScreen, "", ret.reason);
                informationDialog.clicked.connect(function() { pageStack.pop(); });
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(facebookScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
            timerDestroyLoadingDialog.start();
        }
    }

    function whenUserIsAuthenticated(user_token) {
        facebookScreen.dialog = CreateComponent.createLoadingDialog(facebookScreen, "Linking to Facebook ....");
        facebookScreen.dialog.clicked.connect(
            function() {
                molomeServiceController.cancelTransactionByTransactionID(facebookScreen.transactionId);
                pageStack.pop();
            }
        );
        facebookScreen.transactionId = molomeServiceController.updateFacebookProfile(user_token, updateHandler);
    }
}
