import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../js/createComponent.js" as CreateComponent
import "../../util/common.js" as Common
import "../../platforms"

PageWrapper {
    id: findFriendScreen
    property int transactionId
    property variant loadingDialog: null
    width: themeManager.screenWidth
    height: themeManager.screenHeight
    orientationLock: themeManager.pageOrientationPortrait

    MouseArea {
        id: screenHit
        anchors.fill: parent
        onClicked: {

        }
    }

    Header {
        id: header
        z: 1
        hasBack: true
        anchors.top: parent.top
        onBackClicked: {
            pageStack.pop();
        }
    }

    HeaderBar {
        id: headerCaption
        anchors.top: header.bottom
        text: "Find Friends"
        z: 1
    }

    Flickable {
        id: flickable
        width: parent.width
        contentWidth: parent.width
        contentHeight: bodyItem.height //<< childId
        anchors.top: headerCaption.bottom
        anchors.bottom: parent.bottom
        interactive: true

        Item {
            id: bodyItem
            width: themeManager.screenWidth
            height: childrenRect.height

            SettingsCaption {
                id: caption
                text: "in Social Network"
            }
            SettingsItem {
                id: facebook
                anchors.top: caption.bottom
                text: "Facebook"
                isLast: false
                onClicked: {
                    if (userManager.isFacebookAvailable())
                        pageStack.push(Qt.resolvedUrl("../Screen/FriendListScreen.qml"), {title: qsTr("Facebook Friends"), isFacebookFriends: true});
                    else
                        logInFacebook();
                }
            }
            SettingsItem {
                id: twitter
                anchors.top: facebook.bottom
                text: "Twitter"
                isLast: true
                onClicked: {
                    if (userManager.isTwitterAvailable())
                        pageStack.push(Qt.resolvedUrl("../Screen/FriendListScreen.qml"), {title: qsTr("Twitter Friends"), isTwitterFriends: true});
                    else
                        logInTwitter();
                }
            }
            SettingsCaption {
                id: caption2
                text: "in MOLOME"
                anchors.top: twitter.bottom
            }
            SettingListItemData {
                id: findFriend
                anchors.top: caption2.bottom
                text: "Search by Username"
                isLast: true
                onClicked: createFindFriendDialog();
            }
        }
    }
    Component.onCompleted: {
        globalServices.facebookLoggedInStatusChanged.connect(onFacebookLoggedInStatusChanged);
        globalServices.twitterLoggedInStatusChanged.connect(onTwitterLoggedInStatusChanged);

        if (isChina)
        {
            facebook.visible = false
            twitter.visible = false
            facebook.height = 0
            twitter.height = 0
        }
    }

    Component.onDestruction: {
        globalServices.facebookLoggedInStatusChanged.disconnect(onFacebookLoggedInStatusChanged);
        globalServices.twitterLoggedInStatusChanged.disconnect(onTwitterLoggedInStatusChanged);
    }

    Timer {
        id: timerDestroyLoadingDialog
        repeat: false
        running: false
        triggeredOnStart: false
        interval: 10
        onTriggered: {
            if (loadingDialog)
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
        }
    }

    function onFacebookLoggedInStatusChanged(isLoggedIn) {
        //facebook.isLoggedIn = isLoggedIn;
    }

    function onTwitterLoggedInStatusChanged(isLoggedIn){
        //twitter.isLoggedIn = isLoggedIn;
    }

    function logInFacebook() {
        pageStack.push(Qt.resolvedUrl("FaceBookScreen.qml"));
    }

    MolomeServiceHandler {
        id: facebookLogoutHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                userManager.setFacebookAvailibility(false);
                globalServices.emitFacebookLoggedInStatusChanged(false);
                CreateComponent.createInformationDialog(findFriendScreen, "", "Unlinked to Facebook!");
            }
            else
            {
                CreateComponent.createInformationDialog(findFriendScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(findFriendScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function logoutFacebook() {
        var confirmationDialog = CreateComponent.createConfirmationDialog("../", findFriendScreen, "Are you sure to unlink to Facebook?");
        confirmationDialog.clicked.connect(
            function() {
                loadingDialog = CreateComponent.createLoadingDialog(findFriendScreen, "Unlinking ....");
                loadingDialog.clicked.connect(
                    function() {
                        molomeServiceController.cancelTransactionByTransactionID(findFriendScreen.transactionId);
                    }
                );
                transactionId = molomeServiceController.updateFacebookProfile("", facebookLogoutHandler);
            }
        );
    }

    function logInTwitter() {
        pageStack.push(Qt.resolvedUrl("TwitterScreen.qml"));
    }

    MolomeServiceHandler {
        id: twitterLogoutHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                userManager.setTwitterAvailibility(false);
                globalServices.emitTwitterLoggedInStatusChanged(false);
                CreateComponent.createInformationDialog(findFriendScreen, "", "Unlinked to Twitter!");
            }
            else
            {
                CreateComponent.createInformationDialog(findFriendScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(findFriendScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function logoutTwitter() {
        var confirmationDialog = CreateComponent.createConfirmationDialog("../",findFriendScreen,"Are you sure to unlink to Twitter?");
        confirmationDialog.clicked.connect(
            function() {
                loadingDialog = CreateComponent.createLoadingDialog(findFriendScreen,"Unlinking ....");
                loadingDialog.clicked.connect(
                    function() {
                        molomeServiceController.cancelTransactionByTransactionID(findFriendScreen.transactionId);
                    }
                );
                transactionId = molomeServiceController.updateTwitterProfile("", "", "", false, twitterLogoutHandler);
            }
        );
    }



    function createFindFriendDialog() {
        var textDialog = CreateComponent.createTextDialog("../",findFriendScreen);
        textDialog.caption = "Username:"
        textDialog.headerText ="Find Friends"
        textDialog.clicked.connect(
            function(text) {
                if (text === "") {
                    CreateComponent.createInformationDialog(findFriendScreen, "", "Please enter your friend's username!");
                } else {
                    textDialog.destroyDialog();
                    pageStack.push(Qt.resolvedUrl("../Screen/FriendListScreen.qml"), {title: qsTr("Find Friends"), userName: text, isSearchUser: true});
                }
            }
        );
    }

}
