import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../../util/common.js" as Common
import "../../util/oauth/oauth.js" as OAuthJS
import "../js/createComponent.js" as CreateComponent
import "../../platforms"

PageWrapper {
    id: flickrScreen
    width: themeManager.screenWidth
    height: themeManager.screenHeight
    orientationLock: themeManager.pageOrientationPortrait

    property string oauth_token
    property string oauth_token_secret

    property variant dialog: null
    property int transactionId

    Header {
        id: header
        anchors.top: parent.top
        hasBack: true
        onBackClicked: pageStack.pop();
    }
    Flickable {
        id: flickrBox
        width: parent.width
        height: parent.height - header.height
        contentWidth: flickr.contentsSize.width
        contentHeight: flickr.contentsSize.height
        interactive: true
        clip: true
        anchors.top: header.bottom
        flickableDirection: Flickable.HorizontalAndVerticalFlick

        Flickr {
            id: flickr
            //tw_oauth_token: oauth_token
            preferredHeight: flickrBox.height
            preferredWidth: flickrBox.width
            onUser_oauth_verifierChanged: whenUserIsAuthenticated(flickr.user_oauth_token, flickr.user_oauth_verifier);

            LoadingImage {
                id: loadingImage
                anchors.fill: parent
                anchors.centerIn: parent
            }

            Component.onCompleted: nami.clearCookies();

            onLoadStarted: loadingImage.visible = true;
            onLoadFinished: loadingImage.visible = false;
        }
    }

    Component.onCompleted: molomeServiceController.getFlickrToken(flickrTokenHandler);

    MolomeServiceHandler {
        id: flickrTokenHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var param = OAuthJS.OAuth.getParameterMap(OAuthJS.OAuth.decodeForm(data));
            if (param["oauth_token"] !== "")
            {
                flickr.doAuthorize(param["oauth_token"]);
                flickrScreen.oauth_token = param["oauth_token"];
                flickrScreen.oauth_token_secret = param["oauth_token_secret"];
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(flickrScreen, "", "Error: Please try again later");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(flickrScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    MolomeServiceHandler {
        id: updateHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(flickrScreen.dialog.getPageId(), 0);
                globalServices.emitFlickrLoggedInStatusChanged(true);
                userManager.setFlickrAvailibility(true);
                var informationDialog = CreateComponent.createInformationDialog(flickrScreen, "", "Linked to Flickr!");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(flickrScreen, "", ret.reason);
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(flickrScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    MolomeServiceHandler {
        id: flickrAccessTokenHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var param = OAuthJS.OAuth.getParameterMap(OAuthJS.OAuth.decodeForm(data));
            if (param.oauth_token !== "")
            {
                flickrScreen.transactionId = molomeServiceController.updateFlickrProfile(param.username, param.oauth_token, param.oauth_token_secret, updateHandler);
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(flickrScreen, "", "Error: Please try again");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(flickrScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    function whenUserIsAuthenticated(user_oauth_token, user_oauth_verifier) {
        flickrScreen.dialog = CreateComponent.createLoadingDialog(flickrScreen, "Linking to Flickr ....");
        flickrScreen.dialog.clicked.connect(
            function() {
                molomeServiceController.cancelTransactionByTransactionID(flickrScreen.transactionId);
                pageStack.pop();
            }
        );
        flickrScreen.transactionId = molomeServiceController.getFlickrAccessToken(user_oauth_token, user_oauth_verifier, flickrScreen.oauth_token, flickrScreen.oauth_token_secret, flickrAccessTokenHandler);
    }
}
