import QtQuick 1.0
import MOLOMELib 1.0
import "../ButtonComponents"
import "../UIComponents"
import "../js/createComponent.js" as CreateComponent
import "../../util/common.js" as Common
import "../../platforms"
import "../Dialog"

PageWrapper {
    id: forgotPasswordScreen
    width: themeManager.screenWidth
    height: themeManager.screenHeight
    property variant loadingDialog
    orientationLock: themeManager.pageOrientationPortrait

    property int forgotPasswordTransactionId

    Header {
        id: header
        hasBack: true
        z: 1
        onBackClicked: pageStack.pop();
    }

    Image {
        id: bg
        anchors.top: header.bottom
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        source: "../res/loginRegisterBG.jpg"
    }

    Flickable {
        id: flickable

        anchors.top: header.bottom
        anchors.topMargin: themeManager.tenPadding * 3
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right

        contentWidth: parent.width
        contentHeight: flickableItem.height

        Item {
            id: flickableItem
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right

            height: childrenRect.height

            Text {
                id: tvForgotPassword
                anchors.left: parent.left
                anchors.leftMargin: themeManager.bigPadding * 2
                text: "Enter your email"
                color: "white"
                font.pixelSize: themeManager.dialogFontSizeMedium
            }

            Image {
                id: textboxArea
                anchors.top: tvForgotPassword.bottom
                anchors.topMargin: themeManager.tenPadding
                anchors.horizontalCenter: parent.horizontalCenter
                source: "../res/forgot_password_box.png"

                TextEdit {
                    id: textEditEmail
                    anchors.left: parent.left
                    anchors.leftMargin: themeManager.bigPadding
                    anchors.right: parent.right
                    anchors.rightMargin: themeManager.bigPadding
                    anchors.top: parent.top
                    anchors.topMargin: (parent.height - height) >> 1
                    width: parent.width
                    height: (parent.height >> 1) - (themeManager.bigPadding * 2)
                    textFormat: TextEdit.PlainText
                    font.capitalization: Font.AllLowercase
                    visible: true
                    font.pixelSize: themeManager.dialogFontSizeMedium
                    color: "gray"
                    wrapMode: TextEdit.NoWrap
                    verticalAlignment: TextEdit.AlignVCenter
                    Text {
                        text: "Email Address"
                        color: "gray"
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.left: parent.left
                        anchors.right: parent.right
                        width: parent.width
                        visible: (textEditEmail.cursorVisible || textEditEmail.text.length > 0) ? false : true
                        font.pixelSize: themeManager.dialogFontSizeMedium
                    }
                }
            }

            Button {
                id: btnOK
                anchors.top: textboxArea.bottom
                anchors.topMargin: themeManager.tenPadding * 2
                bitmap: "../res/darkblue_color_button_long.png"
                bitmap_pressed: "../res/darkblue_color_button_long_click.png"
                text: "OK"
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    if (textEditEmail.text === "")
                        CreateComponent.createInformationDialog(forgotPasswordScreen, "", "Please enter your email account");
                    else
                        forgotPassword(textEditEmail.text);
                }
            }
        }
    }

    Timer {
        id: timerDestroyLoadingDialog
        repeat: false
        running: false
        triggeredOnStart: false
        interval: 10
        onTriggered: {
            if (loadingDialog)
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
        }
    }

    MolomeServiceHandler {
        id: forgotPasswordHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                var dialog = CreateComponent.createInformationDialog(forgotPasswordScreen, "", "Password reset instruction sent. Please check your email.");
                dialog.clicked.connect(instructionSentClicked);
            }
            else
            {
                CreateComponent.createInformationDialog(forgotPasswordScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(forgotPasswordScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function forgotPassword(email) {
        loadingDialog = CreateComponent.createLoadingDialog(forgotPasswordScreen, "Requesting ....");
        loadingDialog.clicked.connect(
            function() {
                molomeServiceController.cancelTransactionByTransactionID(forgotPasswordTransactionId);
            }
        );
        forgotPasswordTransactionId = molomeServiceController.forgotPassword(email, forgotPasswordHandler);
    }

    function instructionSentClicked() {
        pageStack.pop();
    }
}
