import MOLOMELib 1.0
import QtQuick 1.0
import "../UIComponents"
import "../ListItem"
import "../ListDelegate"
import "../ButtonComponents"
import "../../util/constant.js" as Constant
import "../../util/common.js" as Common
import "../js/createComponent.js" as CreateComponent
import "../js/uiUtils.js" as UIUtils
import "../../platforms"

PageWrapper {
    id: friendListScreen
    property int userId
    property string userName
    property string title
    property int friend_per_page: 40
    property int oldestId
    property int newestId
    property int count
    property bool btnLoadMoreActive: true
    property bool isFollower: false
    property bool isFollowing: false
    property bool isSuggestFriend: false
    property bool isSearchUser: false
    property bool isBlockedUser: false
    property bool isFacebookFriends: false
    property bool isTwitterFriends: false
    property bool isNewUser: false
    property variant loadingComponent
    property int loadingTransactionId: 0

    /*
    Text {
        id: usernameNotMatch
        wrapMode: Text.WrapAtWordBoundaryOrAnywhere
        anchors.centerIn: parent
        width: parent.width - themeManager.twentyPadding
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.margins: themeManager.bigPadding
        visible: false
        color: "gray"
        horizontalAlignment: Text.AlignHCenter
    }
    */

    orientationLock: themeManager.pageOrientationPortrait

    onIsNewUserChanged: {
        if (isNewUser)
            createWelcomeDialog();
    }
    onIsFollowerChanged: {
        if (isFollower)
        {
            body.isLoadMoreVisible = true;
            getFollowerListData();
        }
    }
    onIsFollowingChanged:  {
        if (isFollowing)
        {
            body.isLoadMoreVisible = true;
            getFollowingListData();
        }
    }
    onIsSearchUserChanged: {
        if (isSearchUser)
            getSearchUser();
    }

    onIsSuggestFriendChanged: {
        if (isSuggestFriend)
        {
            getSuggestFriendData();
            body.footer = null;
        }
    }

    onIsBlockedUserChanged: {
        if (isBlockedUser)
        {
            body.isLoadMoreVisible = true;
            getBlockedUserListData();
        }
    }

    onIsFacebookFriendsChanged: {
        if (isFacebookFriends)
        {
            getFacebookFriendsData();
            body.footer = null;
        }
    }

    onIsTwitterFriendsChanged: {
        if (isTwitterFriends)
        {
            getTwitterFriendsData();
            body.footer = null;
        }
    }

    width: themeManager.screenWidth
    height: themeManager.screenHeight

    Header {
        id: header
        hasBack: true
        hasNext: true
        btnNextVisible: friendListScreen.isNewUser
        btnBackVisible: !friendListScreen.isNewUser
        z: 1
        anchors.top: parent.top
        onBackClicked: {
            pageStack.pop();
            cancel();
        }
        onNextClicked: pageStack.push(Qt.resolvedUrl("MainScreen.qml"));
        MouseArea {
            id: goToTopHitBox
            anchors.fill: parent
            onClicked: goToTop();
        }
    }

    HeaderBar {
        id: headerCaption
        anchors.top: header.bottom
        z: 1
        text: friendListScreen.title
        isRefreshBtnAcive: isSuggestFriend
        isLoading: false
        onClicked: refresh();
        onCancelClicked: cancel();
    }

    ListView {
        id: body
        property bool isLoading: false
        property bool isLoadMoreVisible: false

        anchors.top: headerCaption.bottom
        width: parent.width
        height: parent.height - (headerCaption.height + header.height)

        model: FriendListModel { id: friendListModel }
        delegate: FriendListDelegate {
            onProfilePictureClicked: UIUtils.openProfileViewScreenByUsername(username);
            onUsernameClicked: UIUtils.openProfileViewScreenByUsername(username);
            onPhotoCountClick: UIUtils.openUserTimelineScreen(username);
            onFollowerCountClicked: UIUtils.openUserFollowerScreen(username);
            onFollowingCountClick: UIUtils.openUserFollowingScreen(username);
            onFollowClicked: {
                molomeServiceController.followUser(username);
                globalServices.emitSetFollowStatus(username, true);
                globalServices.emitClearTimelineRequested();
            }
            onUnfollowClicked: {
                molomeServiceController.unfollowUser(username);
                globalServices.emitSetFollowStatus(username, false);
                globalServices.emitClearTimelineRequested();
            }
        }

        footer: Item {
            width: body.width
            height: body.isLoadMoreVisible ? (themeManager.loadmoreHeight + themeManager.tenPadding * 2) : 0
            LoadMoreButton {
                id: loadMoreButton
                anchors.top: parent.top
                anchors.leftMargin: themeManager.tenPadding
                anchors.topMargin: themeManager.tenPadding
                anchors.bottomMargin: themeManager.tenPadding
                text: isLoading ? "Loading" : "Load More"
                isLoading: body.isLoading
                onClicked: loadMore()
                visible: body.isLoadMoreVisible
            }
            Item10 { anchors.top: loadMoreButton.bottom; }
        }
    }

    MolomeServiceHandler {
        id: friendListLoadingHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var contentY = body.contentY;
            if (isSuggestFriend)
                friendListModel.clear();
            var parseSuccess = friendListModel.parseJSON(data);
            if (!isSuggestFriend)
                body.contentY = contentY;
            if (parseSuccess)
            {
                if (isFacebookFriends)
                {
                    if (friendListModel.getErrorCode() === -1)
                    {
                        pageStack.pop();
                        pageStack.push(Qt.resolvedUrl("../Screen/FacebookScreen.qml"));
                        return;
                    }
                }
                if (isTwitterFriends)
                {
                    if (friendListModel.getErrorCode() === -1)
                    {
                        pageStack.pop();
                        pageStack.push(Qt.resolvedUrl("../Screen/TwitterScreen.qml"));
                        return;
                    }
                }
                if (friendListModel.getLastParsedRowCount() < friend_per_page)
                    body.footer = null;
            }
            headerCaption.isLoading = false;
            body.isLoading = false;
            if (friendListScreen.loadingComponent !== null && typeof friendListScreen.loadingComponent !== "undefined")
            {
                friendListScreen.loadingComponent.visible = false;
                CreateComponent.destroyComponent(friendListScreen.loadingComponent, 0);
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            headerCaption.isLoading = false;
            if (friendListScreen.loadingComponent !== null && typeof friendListScreen.loadingComponent !== "undefined")
            {
                friendListScreen.loadingComponent.visible = false;
                CreateComponent.destroyComponent(friendListScreen.loadingComponent, 0);
            }
        }
    }

    function getFollowerListData()
    {
        if (headerCaption.isLoading)
            return;
        headerCaption.isLoading = true
        body.isLoading = true
        //friendListScreen.loadingComponent = CreateComponent.createLoadingComponent(friendListScreen);
        friendListScreen.loadingTransactionId = molomeServiceController.getFollowers(userName, friend_per_page, 0, 0, friendListLoadingHandler);
    }

    function getFollowingListData()
    {
        if (headerCaption.isLoading)
            return;
        headerCaption.isLoading = true
        body.isLoading = true
        //friendListScreen.loadingComponent = CreateComponent.createLoadingComponent(friendListScreen);
        friendListScreen.loadingTransactionId = molomeServiceController.getFollowing(userName, friend_per_page, 0, 0, friendListLoadingHandler);
    }

    function getBlockedUserListData()
    {
        if (headerCaption.isLoading)
            return;
        headerCaption.isLoading = true
        body.isLoading = true
        //friendListScreen.loadingComponent = CreateComponent.createLoadingComponent(friendListScreen);
        friendListScreen.loadingTransactionId = molomeServiceController.getBlockedUser(friend_per_page, 0, 0, friendListLoadingHandler);
    }

    function getFacebookFriendsData()
    {
        if (headerCaption.isLoading)
            return;
        headerCaption.isLoading = true
        friendListScreen.loadingComponent = CreateComponent.createLoadingComponent(friendListScreen);
        friendListScreen.loadingTransactionId = molomeServiceController.getFacebookFriends(friendListLoadingHandler);
    }

    function getTwitterFriendsData()
    {
        if (headerCaption.isLoading)
            return;
        headerCaption.isLoading = true
        friendListScreen.loadingComponent = CreateComponent.createLoadingComponent(friendListScreen);
        friendListScreen.loadingTransactionId = molomeServiceController.getTwitterFriends(friendListLoadingHandler);
    }

    function getSearchUser()
    {
        if (headerCaption.isLoading)
            return;
        headerCaption.isLoading = true
        friendListScreen.loadingComponent = CreateComponent.createLoadingComponent(friendListScreen);
        friendListScreen.loadingTransactionId = molomeServiceController.getSearchUser(userName, friend_per_page, friendListLoadingHandler);
    }

    function getSuggestFriendData()
    {
        if (headerCaption.isLoading)
            return;
        headerCaption.isLoading = true
        friendListScreen.loadingComponent = CreateComponent.createLoadingComponent(friendListScreen);
        friendListScreen.loadingTransactionId = molomeServiceController.getSuggestFriend(friendListLoadingHandler);
    }

    function createWelcomeDialog(){
        CreateComponent.createInformationDialog(friendListScreen, "../res/molo_alert_face.png", "Welcome To MOLOME!!");
    }

    function refresh() {
        if (isSuggestFriend)
            getSuggestFriendData();
    }

    function cancel() {
        if (headerCaption.isLoading)
        {
            headerCaption.isLoading = false;
            molomeServiceController.cancelTransactionByTransactionID(friendListScreen.loadingTransactionId);
        }
    }

    function loadMore() {
        if (isFollower)
        {
            body.isLoading = true;
            friendListScreen.loadingTransactionId = molomeServiceController.getFollowers(userName, friend_per_page, 0, friendListModel.getOldestId(), friendListLoadingHandler);
        }
        else if (isFollowing)
        {
            body.isLoading = true;
            friendListScreen.loadingTransactionId = molomeServiceController.getFollowing(userName, friend_per_page, 0, friendListModel.getOldestId(), friendListLoadingHandler);
        }
        else if (isBlockedUser)
        {

        }
        else if (isSearchUser)
        {
        }
    }

    function goToTop() {
        body.contentY = 0;
    }

    Component.onCompleted: {
        globalServices.setFollowStatus.connect(friendListScreen.onFollowStatusSet);
        globalServices.blockedStatusChanged.connect(friendListScreen.onBlockedStatusChanged);
    }

    Component.onDestruction: {
        globalServices.setFollowStatus.disconnect(friendListScreen.onFollowStatusSet);
        globalServices.blockedStatusChanged.disconnect(friendListScreen.onBlockedStatusChanged);
    }

    function onFollowStatusSet(username, followed)
    {
        friendListModel.setFollowStatus(username, followed)
    }

    function onBlockedStatusChanged(user_id, blocked)
    {
        friendListModel.setBlockedStatus(user_id, blocked);
    }
}
