import MOLOMELib 1.0
import QtQuick 1.0
import "../UIComponents"
import "../ListItem"
import "../ListDelegate"
import "../ButtonComponents"
import "../../util/constant.js" as Constant
import "../../util/common.js" as Common
import "../js/createComponent.js" as CreateComponent
import "../js/uiUtils.js" as UIUtils
import "../../platforms"

PageWrapper {
    id: friendRequestListScreen
    property string userName
    property string title
    property int request_per_page: 40
    property int oldestId
    property int newestId
    property int count
    property bool btnLoadMoreActive: true
    property variant loadingComponent: null
    property int loadingTransactionId: 0

    orientationLock: themeManager.pageOrientationPortrait

    width: themeManager.screenWidth
    height: themeManager.screenHeight

    Header {
        id: header
        hasBack: true
        hasNext: false
        z: 1
        anchors.top: parent.top
        onBackClicked: {
            pageStack.pop();
            cancel();
        }
        MouseArea {
            id: goToTopHitBox
            anchors.fill: parent
            onClicked: goToTop();
        }
    }

    HeaderBar {
        id: headerCaption
        anchors.top: header.bottom
        z: 1
        text: "Friend Request"
        isRefreshBtnAcive: true
        isLoading: false
        onClicked: refresh();
        onCancelClicked: cancel();
    }

    ListView {
        id: body
        property bool isLoading: false
        property bool isLoadMoreVisible: false

        anchors.top: headerCaption.bottom
        width: parent.width
        height: parent.height - (headerCaption.height + header.height)

        model: FollowRequestListModel { id: followRequestListModel }
        delegate: FollowRequestListDelegate {
        }

        footer: Item {
            width: body.width
            height: body.isLoadMoreVisible ? (themeManager.loadmoreHeight + themeManager.tenPadding * 2) : 0
            LoadMoreButton {
                id: loadMoreButton
                anchors.top: parent.top
                anchors.leftMargin: themeManager.tenPadding
                anchors.topMargin: themeManager.tenPadding
                anchors.bottomMargin: themeManager.tenPadding
                text: isLoading ? "Loading" : "Load More"
                isLoading: body.isLoading
                onClicked: loadMore()
                visible: body.isLoadMoreVisible
            }
            Item10 { anchors.top: loadMoreButton.bottom; }
        }
    }

    function refresh() {
        cancel();
        followRequestListModel.clear();
        headerCaption.isLoading = true;
        friendRequestListScreen.loadingComponent = CreateComponent.createLoadingComponent(friendRequestListScreen);
        friendRequestListScreen.loadingTransactionId = molomeServiceController.getFriendRequest(userManager.getUserId(), friendRequestListScreen.request_per_page, 0, friendListLoadingHandler);
    }

    function cancel() {
        molomeServiceController.cancelTransactionByTransactionID(friendRequestListScreen.loadingTransactionId);
        if (friendRequestListScreen.loadingComponent !== null && typeof friendRequestListScreen.loadingComponent !== "undefined")
        {
            friendRequestListScreen.loadingComponent.visible = false;
            CreateComponent.destroyComponent(friendRequestListScreen.loadingComponent, 0);
        }
    }

    function loadMore() {
        body.isLoading = true;
        friendRequestListScreen.loadingTransactionId = molomeServiceController.getFriendRequest(userManager.getUserId(), friendRequestListScreen.request_per_page, followRequestListModel.getOldestId(), friendListLoadingHandler);
    }

    function goToTop() {
        body.contentY = 0;
    }

    MolomeServiceHandler {
        id: friendListLoadingHandler

        function onMolomeServiceDataReceived(success, data)
        {
            followRequestListModel.parseJSON(data);
            headerCaption.isLoading = false;
            body.isLoading = false;
            if (followRequestListModel.getHasMore())
                body.isLoadMoreVisible = true;
            if (friendRequestListScreen.loadingComponent !== null && typeof friendRequestListScreen.loadingComponent !== "undefined")
            {
                friendRequestListScreen.loadingComponent.visible = false;
                CreateComponent.destroyComponent(friendRequestListScreen.loadingComponent, 0);
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            if (friendRequestListScreen.loadingComponent !== null && typeof friendRequestListScreen.loadingComponent !== "undefined")
            {
                friendRequestListScreen.loadingComponent.visible = false;
                CreateComponent.destroyComponent(friendRequestListScreen.loadingComponent, 0);
            }
        }
    }

    Component.onCompleted: {
        refresh();
    }

}
