import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../../util/common.js" as Common
import "../../util/oauth/oauth.js" as OAuthJS
import "../js/createComponent.js" as CreateComponent
import "../../platforms"

PageWrapper {
    id: gDriveScreen
    width: themeManager.screenWidth
    height: themeManager.screenHeight
    orientationLock: themeManager.pageOrientationPortrait

    property string gdrive_auth_code

    property variant dialog: null
    property int transactionId

    Header {
        id: header
        anchors.top: parent.top
        hasBack: true
        onBackClicked: pageStack.pop();
    }
    Flickable {
        id: gDriveBox
        width: parent.width
        height: parent.height - header.height
        contentWidth: gDrive.contentsSize.width
        contentHeight: gDrive.contentsSize.height
        interactive: true
        clip: true
        anchors.top: header.bottom
        flickableDirection: Flickable.HorizontalAndVerticalFlick

        GDrive {
            id: gDrive
            //tw_oauth_token: oauth_token
            preferredHeight: gDriveBox.height
            preferredWidth: gDriveBox.width
            onCodeChanged: whenUserIsAuthenticated(gDrive.code);

            LoadingImage {
                id: loadingImage
                anchors.fill: parent
                anchors.centerIn: parent
            }

            Component.onCompleted: {
                nami.clearCookies();
                gDrive.startAuthorize();
            }

            onLoadStarted: loadingImage.visible = true;
            onLoadFinished: loadingImage.visible = false;
        }
    }

    //Component.onCompleted: gDrive.startAuthorize();

    MolomeServiceHandler {
        id: gDriveLinkHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(gDriveScreen.dialog.getPageId(), 0);
                globalServices.emitGDriveLoggedInStatusChanged(true);
                userManager.setGDriveAvailibility(true);
                var informationDialog = CreateComponent.createInformationDialog(gDriveScreen, "", "Linked to Google Drive!");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(gDriveScreen, "", ret.reason);
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(gDriveScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    function whenUserIsAuthenticated(auth_code) {
        gDriveScreen.gdrive_auth_code = auth_code

        gDriveScreen.dialog = CreateComponent.createLoadingDialog(gDriveScreen, "Linking to Google Drive ....");
        gDriveScreen.dialog.clicked.connect(
            function() {
                molomeServiceController.cancelTransactionByTransactionID(gDriveScreen.transactionId);
                pageStack.pop();
            }
        );
        gDriveScreen.transactionId = molomeServiceController.linkGDrive(gDriveScreen.gdrive_auth_code, gDriveLinkHandler);
    }
}
