import QtQuick 1.0
import MOLOMELib 1.0
import "../ButtonComponents"
import "../UIComponents"
import "../js/createComponent.js" as CreateComponent
import "../../util/common.js" as Common
import "../../platforms"
import "../Dialog"

PageWrapper {
    id: loginRegisterScreen
    width: themeManager.screenWidth
    height: themeManager.screenHeight
    property variant loadingDialog
    orientationLock: themeManager.pageOrientationPortrait

    property string processingUsername

    property int registerTransactionId
    property int loginTransactionId

    property int tabValue: 0

    onTabValueChanged: {
        console.log("Tab = " + tabValue)
        if (tabValue === 1)
        {
            tabRegister.selected = false
            tabLogin.selected = true
        }
    }

    Header {
        id: header
        hasBack: true
        z: 1
        onBackClicked: pageStack.pop();
    }

    Image {
        id: bg
        anchors.top: header.bottom
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        source: "../res/loginRegisterBG.jpg"
    }

    Flickable {
        id: flickable

        anchors.top: header.bottom
        anchors.topMargin: themeManager.tenPadding * 2
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right

        contentWidth: parent.width
        contentHeight: flickableItem.height

        Item {
            id: flickableItem
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right

            height: childrenRect.height

            Item {
                id: tab
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.right: parent.right

                height: childrenRect.height

                Item {
                    height: childrenRect.height
                    width: childrenRect.width
                    anchors.horizontalCenter: parent.horizontalCenter
                    RadioButton {
                        id: tabRegister
                        bitmap: "../res/tabLogin.png"
                        bitmap_pressed: "../res/tabLoginSelected.png"
                        bitmap_selected: "../res/tabLoginSelected.png"
                        selected: true
                        Text {
                            text: "Join"
                            anchors.centerIn: parent
                            font.family: "Lato Black"
                            font.pixelSize: themeManager.radioButtonFontSize
                            color: "#ffffffff"
                            styleColor: "#4f000000"
                            style: Text.Sunken
                        }
                        onClicked: {
                            tabLogin.selected = false
                            tabRegister.selected = true
                        }
                    }
                    RadioButton {
                        id: tabLogin
                        anchors.left: tabRegister.right
                        bitmap: "../res/tabRegister.png"
                        bitmap_pressed: "../res/tabRegisterSelected.png"
                        bitmap_selected: "../res/tabRegisterSelected.png"
                        Text {
                            text: "Sign in "
                            anchors.centerIn: parent
                            font.family: "Lato Black"
                            font.pixelSize: themeManager.radioButtonFontSize
                            color: "#ffffffff"
                            styleColor: "#4f000000"
                            style: Text.Sunken
                        }
                        onClicked: {
                            tabLogin.selected = true
                            tabRegister.selected = false
                        }
                    }
                }
            }

            Image {
                id: userPassLoginArea
                anchors.top: tab.bottom
                anchors.topMargin: themeManager.tenPadding * 2
                anchors.horizontalCenter: parent.horizontalCenter
                source: "../res/user_pass_box.png"
                visible: tabLogin.selected

                TextEdit {
                    id: textEditUsername
                    anchors.left: parent.left
                    anchors.leftMargin: themeManager.bigPadding
                    anchors.right: parent.right
                    anchors.rightMargin: themeManager.bigPadding
                    anchors.top: parent.top
                    anchors.topMargin: themeManager.bigPadding
                    width: parent.width
                    height: (parent.height >> 1) - (themeManager.bigPadding * 2)
                    textFormat: TextEdit.PlainText
                    font.capitalization: Font.AllLowercase
                    visible: true
                    font.pixelSize: themeManager.dialogFontSizeMedium
                    color: "gray"
                    wrapMode: TextEdit.NoWrap
                    verticalAlignment: TextEdit.AlignVCenter
                    Text {
                        text: "Username"
                        color: "gray"
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.left: parent.left
                        anchors.right: parent.right
                        width: parent.width
                        visible: (textEditUsername.cursorVisible || textEditUsername.text.length > 0) ? false : true
                        font.pixelSize: themeManager.dialogFontSizeMedium
                    }
                }

                TextInput {
                    id: textEditPassword
                    anchors.left: parent.left
                    anchors.leftMargin: themeManager.bigPadding
                    anchors.right: parent.right
                    anchors.rightMargin: themeManager.bigPadding
                    anchors.top: textEditUsername.bottom
                    anchors.topMargin: themeManager.bigPadding * 2
                    width: parent.width
                    height: (parent.height >> 1) - (themeManager.bigPadding * 2)
                    visible: true
                    font.pixelSize: themeManager.dialogFontSizeMedium
                    color: "gray"
                    echoMode: btnLoginShowPasswordCheck.selected ? TextInput.Normal : TextInput.Password
                    Text {
                        text: "Password"
                        color: "gray"
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.left: parent.left
                        anchors.right: parent.right
                        width: parent.width
                        visible: (textEditPassword.cursorVisible || textEditPassword.text.length > 0) ? false : true
                        font.pixelSize: themeManager.dialogFontSizeMedium
                    }
                }
            }

            Item {
                id: checkBoxLoginShowPasswordItem
                width: parent.width
                height: btnLoginShowPasswordCheck.height
                anchors.right: parent.right
                anchors.left: userPassLoginArea.left
                anchors.leftMargin: themeManager.paddingLeftRight * 2
                anchors.top: userPassLoginArea.bottom
                anchors.topMargin: themeManager.tenPadding
                visible: tabLogin.selected
                RadioButton {
                    id: btnLoginShowPasswordCheck
                    text: qsTr("Show Password")
                    textColor: "#FFFFFF"
                    bitmap: "../res/dialog_checkbox_normal.png"
                    bitmap_pressed: "../res/dialog_checkbox_checked.png"
                    bitmap_selected: "../res/dialog_checkbox_checked.png"
                    selected: false
                    onClicked: btnLoginShowPasswordCheck.selected = btnLoginShowPasswordCheck.selected == false ? true : false
                }
            }

            Button {
                id: btnLogin
                anchors.top: checkBoxLoginShowPasswordItem.bottom
                anchors.topMargin: themeManager.tenPadding * 2
                bitmap: "../res/darkblue_color_button_long.png"
                bitmap_pressed: "../res/darkblue_color_button_long_click.png"
                text: "Login"
                anchors.horizontalCenter: parent.horizontalCenter
                visible: tabLogin.selected
                onClicked: {
                    if (textEditUsername.text === "" || textEditPassword.text === "")
                        CreateComponent.createInformationDialog(loginRegisterScreen, "", "Please enter all required fields");
                    else
                        login(textEditUsername.text, textEditPassword.text);
                }
            }

            Image {
                id: userPassRegisterArea
                anchors.top: tab.bottom
                anchors.topMargin: themeManager.tenPadding * 2
                anchors.horizontalCenter: parent.horizontalCenter
                source: "../res/user_pass_register_box.png"
                visible: tabRegister.selected

                TextEdit {
                    id: textEditRegisterUsername
                    anchors.left: parent.left
                    anchors.leftMargin: themeManager.bigPadding
                    anchors.right: parent.right
                    anchors.rightMargin: themeManager.bigPadding
                    anchors.top: parent.top
                    anchors.topMargin: themeManager.bigPadding
                    width: parent.width
                    height: (parent.height >> 2) - (themeManager.bigPadding * 2)
                    textFormat: TextEdit.PlainText
                    font.capitalization: Font.AllLowercase
                    visible: true
                    font.pixelSize: themeManager.dialogFontSizeMedium
                    color: "gray"
                    wrapMode: TextEdit.NoWrap
                    verticalAlignment: TextEdit.AlignVCenter
                    Text {
                        text: "Username"
                        color: "gray"
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.left: parent.left
                        anchors.right: parent.right
                        width: parent.width
                        visible: (textEditRegisterUsername.cursorVisible || textEditRegisterUsername.text.length > 0) ? false : true
                        font.pixelSize: themeManager.dialogFontSizeMedium
                    }
                }

                TextInput {
                    id: textEditRegisterPassword
                    anchors.left: parent.left
                    anchors.leftMargin: themeManager.bigPadding
                    anchors.right: parent.right
                    anchors.rightMargin: themeManager.bigPadding
                    anchors.top: textEditRegisterUsername.bottom
                    anchors.topMargin: themeManager.bigPadding * 2
                    width: parent.width
                    height: (parent.height >> 2) - (themeManager.bigPadding * 2)
                    visible: true
                    font.pixelSize: themeManager.dialogFontSizeMedium
                    color: "gray"
                    echoMode: btnRegisterShowPasswordCheck.selected ? TextInput.Normal : TextInput.Password
                    Text {
                        text: "Password"
                        color: "gray"
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.left: parent.left
                        anchors.right: parent.right
                        width: parent.width
                        visible: (textEditRegisterPassword.cursorVisible || textEditRegisterPassword.text.length > 0) ? false : true
                        font.pixelSize: themeManager.dialogFontSizeMedium
                    }
                }

                TextInput {
                    id: textEditRegisterConfirmPassword
                    anchors.left: parent.left
                    anchors.leftMargin: themeManager.bigPadding
                    anchors.right: parent.right
                    anchors.rightMargin: themeManager.bigPadding
                    anchors.top: textEditRegisterPassword.bottom
                    anchors.topMargin: themeManager.bigPadding * 2
                    width: parent.width
                    height: (parent.height >> 2) - (themeManager.bigPadding * 2)
                    visible: true
                    font.pixelSize: themeManager.dialogFontSizeMedium
                    color: "gray"
                    echoMode: btnRegisterShowPasswordCheck.selected ? TextInput.Normal : TextInput.Password
                    Text {
                        text: "Confirm Password"
                        color: "gray"
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.left: parent.left
                        anchors.right: parent.right
                        width: parent.width
                        visible: (textEditRegisterConfirmPassword.cursorVisible || textEditRegisterConfirmPassword.text.length > 0) ? false : true
                        font.pixelSize: themeManager.dialogFontSizeMedium
                    }
                }

                TextInput {
                    id: textEditRegisterEmail
                    anchors.left: parent.left
                    anchors.leftMargin: themeManager.bigPadding
                    anchors.right: parent.right
                    anchors.rightMargin: themeManager.bigPadding
                    anchors.top: textEditRegisterConfirmPassword.bottom
                    anchors.topMargin: themeManager.bigPadding * 2
                    width: parent.width
                    height: (parent.height >> 2) - (themeManager.bigPadding * 2)
                    font.capitalization: Font.AllLowercase
                    visible: true
                    font.pixelSize: themeManager.dialogFontSizeMedium
                    color: "gray"
                    Text {
                        text: "Email"
                        color: "gray"
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.left: parent.left
                        anchors.right: parent.right
                        width: parent.width
                        visible: (textEditRegisterEmail.cursorVisible || textEditRegisterEmail.text.length > 0) ? false : true
                        font.pixelSize: themeManager.dialogFontSizeMedium
                    }
                }
            }

            Item {
                id: checkBoxRegisterShowPasswordItem
                width: parent.width
                height: btnRegisterShowPasswordCheck.height
                anchors.right: parent.right
                anchors.left: userPassRegisterArea.left
                anchors.leftMargin: themeManager.paddingLeftRight * 2
                anchors.top: userPassRegisterArea.bottom
                anchors.topMargin: themeManager.tenPadding
                visible: tabRegister.selected
                RadioButton {
                    id: btnRegisterShowPasswordCheck
                    text: qsTr("Show Password")
                    textColor: "#FFFFFF"
                    bitmap: "../res/dialog_checkbox_normal.png"
                    bitmap_pressed: "../res/dialog_checkbox_checked.png"
                    bitmap_selected: "../res/dialog_checkbox_checked.png"
                    selected: false
                    onClicked: btnRegisterShowPasswordCheck.selected = btnRegisterShowPasswordCheck.selected == false ? true : false
                }
            }

            Button {
                id: btnRegister
                anchors.top: checkBoxRegisterShowPasswordItem.bottom
                anchors.topMargin: themeManager.tenPadding * 2
                bitmap: "../res/darkblue_color_button_long.png"
                bitmap_pressed: "../res/darkblue_color_button_long_click.png"
                text: "Register"
                anchors.horizontalCenter: parent.horizontalCenter
                visible: tabRegister.selected
                onClicked: {
                    if (textEditRegisterUsername.text === "" || textEditRegisterPassword.text === "" || textEditRegisterConfirmPassword.text === "" || textEditRegisterEmail.text === "")
                        CreateComponent.createInformationDialog(loginRegisterScreen, "", "Please enter all required fields");
                    else if (textEditRegisterPassword.text !== textEditRegisterConfirmPassword.text)
                        CreateComponent.createInformationDialog(loginRegisterScreen, "", "Passwords mismatched.");
                    else
                        register(textEditRegisterUsername.text, textEditRegisterPassword.text, textEditRegisterEmail.text);
                }
            }

            Text {
                id: privacyPolicyText
                anchors.top: btnLogin.visible ? btnLogin.bottom : btnRegister.bottom
                anchors.topMargin: themeManager.paddingLeftRight
                text: "<a href='http://molo.me/privacy' style='color: black'>Privacy Policy</a>"
                color: "#F0F0F0"
                font.pixelSize: themeManager.radioButtonFontSize
                anchors.horizontalCenter: parent.horizontalCenter
                MouseArea {
                    anchors.fill: parent
                    onClicked: Qt.openUrlExternally("http://molo.me/privacy")
                }
            }

            Item {
                id: remarkBox
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: privacyPolicyText.bottom
                anchors.leftMargin: themeManager.paddingLeftRight
                anchors.rightMargin: themeManager.paddingLeftRight
                anchors.topMargin: themeManager.paddingLeftRight
                height: remarkText.height + themeManager.paddingLeftRight * 2

                Text {
                    id: remarkText
                    anchors.left: parent.left
                    anchors.right: parent.right
                    anchors.top: parent.top
                    text: "* <u>Remark</u> : Your password will NOT be stored anywhere neither local on your phone nor on server. So please feel safe to enter those login information."
                    color: "#F0F0F0"
                    font.pixelSize: themeManager.radioButtonFontSize
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                }
            }
        }
    }


    Timer {
        id: timerDestroyLoadingDialog
        repeat: false
        running: false
        triggeredOnStart: false
        interval: 10
        onTriggered: {
            if (loadingDialog)
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
        }
    }

    MolomeServiceHandler {
        id: loginHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                userManager.setLoggedUserInformation(ret.user_id, processingUsername, ret.oauth_token, ret.oauth_token_secret);
                userManager.loadLoggedInAccount();
                // To MainScreen
                pageStack.clear();
                pageStack.push(Qt.resolvedUrl("MainScreen.qml"),{isLogInFromWelComeScreen: true})
            }
            else
            {
                CreateComponent.createInformationDialog(loginRegisterScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(loginRegisterScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function login(username, password) {
        processingUsername = username;
        loadingDialog = CreateComponent.createLoadingDialog(loginRegisterScreen, "Logging in ....");
        loadingDialog.clicked.connect(
            function() {
                molomeServiceController.cancelTransactionByTransactionID(loginTransactionId);
            }
        );
        loginTransactionId = molomeServiceController.loginUser(username, password, loginHandler);
    }


    MolomeServiceHandler {
        id: registerHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                userManager.setLoggedUserInformation(ret.user_id, processingUsername, ret.oauth_token, ret.oauth_token_secret);
                userManager.loadLoggedInAccount();
                // To MainScreen
                pageStack.pop();
                pageStack.push(Qt.resolvedUrl("../Screen/FriendListScreen.qml"), {title: qsTr("Suggested Friends"), isSuggestFriend: true, btnLoadMoreActive: false, isNewUser : true});
            }
            else
            {
                CreateComponent.createInformationDialog(loginRegisterScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(loginRegisterScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function register(username, password, email) {
        processingUsername = username;
        loadingDialog = CreateComponent.createLoadingDialog(loginRegisterScreen, "Registering ....");
        loadingDialog.clicked.connect(
            function() {
                molomeServiceController.cancelTransactionByTransactionID(registerTransactionId);
            }
        );
        registerTransactionId = molomeServiceController.registerUser(username, password, email, registerHandler);
    }


}
