import MOLOMELib 1.0
import QtQuick 1.0
import "../ButtonComponents"
import "../DialogComponents"
import "../UIComponents"
import "../ListItem"
import "../ListDelegate"
import "../"
import "../js/createComponent.js" as CreateComponent
import "../../util/common.js" as Common
import "../../util/constant.js" as Constant
import "../../platforms"
import "../js/storage.js" as Storage

PageWrapper {
    id: mainScreen
    width: themeManager.screenWidth
    height: themeManager.screenHeight

    orientationLock: themeManager.pageOrientationPortrait

    property string currentTimelineTab: "Timeline"
    property string currentMeTab: "Notifications"

    property bool isLogInFromWelComeScreen: false
    property int userId: userManager.getUserId();

    property string currentState: "TimelineTab"
    property bool isTimelineTab: currentState === "TimelineTab"
    property bool isPopularTab: currentState === "PopularTab"
    property bool isNotificationTab: currentState === "NotificationsTab"
    property bool isProfileTab: currentState === "ProfilesTab"
    property bool isSettingTab: currentState === "SettingsTab"

    property int photoCount: 30
    property int notificationCount: 20

    property int getHomeTimelineRefreshTransactionId: 0
    property int getHomeTimelineLoadMoreTransactionId: 0
    property int getPopularTransactionId: 0
    property int getNotificationRefreshTransactionId: 0
    property int getNotificationLoadMoreTransactionId: 0
    property int getProfileTransactionId: 0
    property int getHomeTimelinePhotoSummaryTransactionId: 0

    property variant popularLoading: null

    onIsLogInFromWelComeScreenChanged: if (mainScreen.isLogInFromWelComeScreen == true) createWelcomeDialog();

    Header {
        id: header
        hasNext: true
        nextText: "Exit"
        anchors.top: parent.top
        z: 2
        onNextClicked: Qt.quit()
        MouseArea {
            id: goToTopHitbox
            anchors.fill: parent
            onClicked: goToTop();
        }
    }

    /* Timeline Tab Holder */
    Rectangle {
        id: timelineTabHolder
        anchors.top: header.bottom
        anchors.bottom: footer.top

        HeaderMenu {
            id: timelineHeaderMenu
            z: 1
            onClicked: refresh();
            onCancelClicked: cancel();
            isRefreshBtnAcive: true
            isLoading: timelinePage.visible ? timelineModel.isRefreshing : popularModel.isRefreshing
            HeaderMenuButton {
                id: btnTabTimeline
                x: themeManager.timelineBtnX
                y: themeManager.tabHolderBtnY
                text: qsTr("Timeline")
                selected: true
                onClicked: switchToTab("TimelineTab")
            }
            HeaderMenuButton {
                id: btnTabPopular
                x: themeManager.popularBtnX
                y: themeManager.tabHolderBtnY
                text: qsTr("Popular")
                onClicked: switchToTab("PopularTab")
            }
        }

        Item {
            id: timelinePage
            anchors.top: timelineHeaderMenu.bottom
            anchors.bottom: parent.bottom
            anchors.left: parent.left
            width: themeManager.screenWidth

            Image {
                id: uploadingListBar
                source: "../res/uploading_tab_bar_bg.png"
                width: parent.width
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.right: parent.right
                z: 1
                height: 0
                visible: false

                Flow {
                    anchors.left: parent.left
                    anchors.right: parent.right
                    anchors.top: parent.top
                    anchors.bottom: parent.bottom
                    anchors.leftMargin: themeManager.uploadQueueComponentAreaX
                    anchors.rightMargin: themeManager.bigPadding

                    Repeater {
                        id: repeater
                        model: uploaderQueueModel
                        delegate: Item {
                            height: uploadingListBar.height
                            width: uploadingListBar.height - themeManager.smallPadding
                            Image {
                                y: themeManager.smallPadding >> 1
                                height: parent.width
                                width: parent.width
                                source: uploaderQueueModel.getQueueMiniImagePath(folder_code)
                            }
                        }
                    }
                }

                MouseArea {
                    anchors.fill: parent
                    onClicked: pageStack.push(Qt.resolvedUrl("../Screen/UploadingQueueScreen.qml"));
                }
            }

            GridView {
                id: timelineView

                anchors.top: uploadingListBar.bottom
                anchors.left: parent.left
                anchors.leftMargin: themeManager.bigPadding
                anchors.bottom: parent.bottom
                width: parent.width - themeManager.bigPadding

                model: timelineModel
                cellWidth: themeManager.photoComponentWidth + 5
                cellHeight: themeManager.photoComponentHeight + 5
                delegate: PhotoComponentDelegate { cacheMode: ImageCacheMode.CacheThumbnail }

                header: Item10 {}
                footer: Item {
                    width: timelineView.width
                    height: childrenRect.height
                    LoadMoreButton {
                        id: loadMoreButton
                        text: isLoading ? "Loading" : "Load More"
                        anchors.leftMargin: 0
                        isLoading: timelineModel.isLoadingMore
                        onClicked: loadMoreTimeline();
                    }
                    Item10 { anchors.top: loadMoreButton.bottom }
                }

                cacheBuffer: timelineView.height * 2

                Component.onCompleted: timelineView.contentY = 0

                MolomeServiceHandler {
                    id: getHomeTimelineHandler
                    function onMolomeServiceDataReceived(success, data)
                    {
                        var contentY = timelineView.contentY;
                        var timelineModelCount = timelineModel.getCount();
                        var parseSuccess = timelineModel.parseJSON(data);
                        timelineView.contentY = contentY;
                        timelineModel.isRefreshing = false
                        if (timelineModelCount === 0)
                            timelineModel.isLoadingMore = false
                    }
                    function onMolomeServiceError(statusCode, message)
                    {
                        var timelineModelCount = timelineModel.getCount();
                        timelineModel.isRefreshing = false
                        if (timelineModelCount === 0)
                            timelineModel.isLoadingMore = false
                    }
                }

                MolomeServiceHandler {
                    id: getHomeTimelineLoadMoreHandler
                    function onMolomeServiceDataReceived(success, data)
                    {
                        var contentY = timelineView.contentY;
                        var parseSuccess = timelineModel.parseJSON(data, true);
                        timelineView.contentY = contentY;
                        timelineModel.isLoadingMore = false
                        //if (timelineModel.getLastParsedRowCount() < photoCount)
                        //    timelineView.footer = null;
                    }
                    function onMolomeServiceError(statusCode, message)
                    {
                        timelineModel.isLoadingMore = false
                    }
                }

                MolomeServiceHandler {
                    id: getHomeTimelinePhotoSummaryHandler
                    function onMolomeServiceDataReceived(success, data)
                    {
                        //var contentY = timelineView.contentY;
                        var parseSuccess = timelineModel.parsePhotoSummaryJSON(data);
                        //timelineView.contentY = contentY;
                        getHomeTimelinePhotoSummaryTransactionId = 0;
                    }
                    function onMolomeServiceError(statusCode, message)
                    {
                        getHomeTimelinePhotoSummaryTransactionId = 0;
                    }
                }
            }
        }

        GridView {
            id: popularPage
            visible: false
            anchors.top: timelineHeaderMenu.bottom
            anchors.bottom: parent.bottom
            anchors.left: parent.left
            anchors.leftMargin: themeManager.bigPadding
            width: themeManager.screenWidth
            model: popularModel
            cellWidth: themeManager.photoComponentWidth + 5
            cellHeight: themeManager.photoComponentHeight + 5
            delegate: PhotoComponentDelegate {}

            header: Item10 {}

            cacheBuffer: popularPage.height * 2

            MolomeServiceHandler {
                id: getPopularTimelineHandler
                function onMolomeServiceDataReceived(success, data)
                {
                    var parseSuccess = popularModel.parseJSON(data);
                    popularModel.isRefreshing = false
                    if (mainScreen.popularLoading !== null && typeof mainScreen.popularLoading !== "undefined")
                    {
                        mainScreen.popularLoading.visible = false;
                        CreateComponent.destroyComponent(mainScreen.popularLoading.getPageId(), 0);
                    }
                }
                function onMolomeServiceError(statusCode, message)
                {
                    popularModel.isRefreshing = false
                    if (mainScreen.popularLoading !== null && typeof mainScreen.popularLoading !== "undefined")
                    {
                        mainScreen.popularLoading.visible = false;
                        CreateComponent.destroyComponent(mainScreen.popularLoading.getPageId(), 0);
                    }
                }
            }
        }
    }

    /* Me Tab Holder */
    Image {
        id: meTabHolder
        anchors.top: header.bottom
        anchors.bottom: footer.top
        visible: false
        width: parent.width

        fillMode: Image.Tile
        source: "../res/timeline_bg.jpg"

        HeaderMenu {
            id: meHeaderMenu
            z: 2
            onClicked: refresh();
            onCancelClicked: cancel();
            isLoading: (notificationPage.visible ? notificationModel.isRefreshing : (profilesPage.visible ? profileViewTab.manager.isRefreshing : false))

            HeaderMenuButton {
                id: btnTabNotifications
                x: themeManager.notificationBtnX
                y: themeManager.tabHolderBtnY
                text: qsTr("Notifications")
                selected: true
                onClicked: switchToTab("NotificationsTab")
            }

            HeaderMenuButton {
                id: btnTabProfiles
                x: themeManager.profileBtnX
                y: themeManager.tabHolderBtnY
                text: qsTr("Profiles")
                onClicked: {
                    if (currentState === "NotificationsTab")
                        notificationListView.markAllAsRead();
                    switchToTab("ProfilesTab")
                }
            }

            HeaderMenuButton {
                id: btnTabSettings
                x: themeManager.settingBtnX
                y: themeManager.tabHolderBtnY
                text: qsTr("Settings")
                onClicked: {
                    if (currentState === "NotificationsTab")
                        notificationListView.markAllAsRead();
                    switchToTab("SettingsTab")
                }
            }
        }

        Item {
            id: notificationPage
            anchors.top: meHeaderMenu.bottom
            width: parent.width
            height: parent.height - meHeaderMenu.height
            visible: false

            property bool isLoading: false
            property bool isRefreshLoading: false

            property int __currentTab: Constant.NOTIFICATION_TAB_ALL

            property int tid

            Item {
                id: notificationMenuTabBar
                width: parent.width
                height: childrenRect.height
                z: 2

                NotificationTabButton {
                    id: btnNotificationAll
                    iconSource: "../res/notification_tab_icon_all.png"
                    selected: true
                    onClicked: {
                        notificationMenuTabBar.clearSelection()
                        selected = true
                        notificationPage.__currentTab = Constant.NOTIFICATION_TAB_ALL;
                        notificationModel.switchListIndex(0, notificationListView.contentY);
                        notificationListView.contentY = notificationModel.getContentY(0);
                    }
                }
                NotificationTabButton {
                    id: btnNotificationLove
                    anchors.left: btnNotificationAll.right
                    iconSource: "../res/notification_tab_icon_love.png"
                    selected: false
                    onClicked: {
                        notificationMenuTabBar.clearSelection()
                        selected = true
                        notificationPage.__currentTab = Constant.NOTIFICATION_TAB_LOVE;
                        notificationModel.switchListIndex(1, notificationListView.contentY);
                        notificationListView.contentY = notificationModel.getContentY(1);
                    }
                }
                NotificationTabButton {
                    id: btnNotificationComment
                    anchors.left: btnNotificationLove.right
                    iconSource: "../res/notification_tab_icon_comment.png"
                    selected: false
                    onClicked: {
                        notificationMenuTabBar.clearSelection()
                        selected = true
                        notificationPage.__currentTab = Constant.NOTIFICATION_TAB_COMMENT;
                        notificationModel.switchListIndex(2, notificationListView.contentY);
                        notificationListView.contentY = notificationModel.getContentY(2);
                    }
                }
                NotificationTabButton {
                    id: btnNotificationBadged
                    anchors.left: btnNotificationComment.right
                    iconSource: "../res/notification_tab_icon_badged.png"
                    selected: false
                    onClicked: {
                        notificationMenuTabBar.clearSelection()
                        selected = true
                        notificationPage.__currentTab = Constant.NOTIFICATION_TAB_BADGED;
                        notificationModel.switchListIndex(3, notificationListView.contentY);
                        notificationListView.contentY = notificationModel.getContentY(3);
                    }
                }
                NotificationTabButton {
                    id: btnNotificationFollowed
                    anchors.left: btnNotificationBadged.right
                    iconSource: "../res/notification_tab_icon_follow.png"
                    selected: false
                    onClicked: {
                        notificationMenuTabBar.clearSelection()
                        selected = true
                        notificationPage.__currentTab = Constant.NOTIFICATION_TAB_FOLLOW;
                        notificationModel.switchListIndex(4, notificationListView.contentY);
                        notificationListView.contentY = notificationModel.getContentY(4);
                    }
                }

                function clearSelection() {
                    btnNotificationAll.selected = false
                    btnNotificationLove.selected = false
                    btnNotificationComment.selected = false
                    btnNotificationBadged.selected = false
                    btnNotificationFollowed.selected = false
                }
            }

            Item {
                id: loadingNotificationArea
                anchors.top: notificationMenuTabBar.bottom
                anchors.bottom: parent.bottom
                width: parent.width

                property variant loadingImage: null

                function createLoadingImage()
                {
                    loadingNotificationArea.loadingImage = CreateComponent.createLoadingComponent(loadingNotificationArea);
                }

                function destroyLoadingImage()
                {
                    if (loadingNotificationArea.loadingImage !== null && typeof loadingNotificationArea.loadingImage !== "undefined")
                    {
                        loadingNotificationArea.loadingImage.visible = false;
                        CreateComponent.destroyComponent(loadingNotificationArea.loadingImage.getPageId(), 0);
                    }
                }
            }

            ListView {
                id: notificationListView
                anchors.top: notificationMenuTabBar.bottom
                anchors.bottom: parent.bottom
                width: parent.width

                property bool footerVisible: false

                model: notificationModel
                delegate: NotificationItemDelegate {}
                highlightFollowsCurrentItem: true
                cacheBuffer: notificationListView.height * 2
                footer: Item {
                    id: notificationListViewLoadMoreArea
                    width: notificationListView.width
                    height: visible ? childrenRect.height + themeManager.bigPadding : 0
                    visible: notificationListView.footerVisible
                    LoadMoreButton {
                        id: notificationLoadMoreButton
                        text: isLoading ? "Loading" : "Load More"
                        anchors.top: parent.top
                        anchors.topMargin: themeManager.bigPadding
                        isLoading: notificationModel.isLoadingMore
                        onClicked: loadMoreNotification();
                    }
                    Item10 { anchors.top: notificationLoadMoreButton.bottom }
                }

                function markAllAsRead()
                {
                    notificationModel.markAllAsRead();
                    btnNotificationAll.text = notificationModel.getStats("total_count");
                    btnNotificationLove.text = notificationModel.getStats("love_count");
                    btnNotificationComment.text = notificationModel.getStats("comment_count");
                    btnNotificationBadged.text = notificationModel.getStats("badge_count");
                    btnNotificationFollowed.text = notificationModel.getStats("follow_count");
                    Storage.setData("notification_last_read_id", notificationModel.lastReadNotificationId);
                }

                MolomeServiceHandler {
                    id: getNotificationHandler
                    function onMolomeServiceDataReceived(success, data)
                    {
                        notificationModel.isRefreshing = false
                        var contentY = notificationListView.contentY;
                        var contentHeight = notificationListView.contentHeight;
                        var parseSuccess = notificationModel.parseJSON(data);
                        if (parseSuccess)
                        {
                            btnNotificationAll.text = notificationModel.getStats("total_count");
                            btnNotificationLove.text = notificationModel.getStats("love_count");
                            btnNotificationComment.text = notificationModel.getStats("comment_count");
                            btnNotificationBadged.text = notificationModel.getStats("badge_count");
                            btnNotificationFollowed.text = notificationModel.getStats("follow_count");

                            notificationListView.footerVisible = true
                            loadingNotificationArea.destroyLoadingImage()
                        }
                        if (contentHeight > 0)
                            notificationListView.contentY = notificationListView.contentHeight - contentHeight + contentY;
                    }
                    function onMolomeServiceError(statusCode, message)
                    {
                        notificationModel.isRefreshing = false
                        loadingNotificationArea.destroyLoadingImage()
                    }
                }

                MolomeServiceHandler {
                    id: getNotificationLoadMoreHandler
                    function onMolomeServiceDataReceived(success, data)
                    {
                        notificationModel.isLoadingMore = false
                        var contentY = notificationListView.contentY;
                        var parseSuccess = notificationModel.parseJSON(data, true);
                        if (parseSuccess)
                        {
                        }
                        notificationListView.contentY = contentY;
                    }
                    function onMolomeServiceError(statusCode, message)
                    {
                        notificationModel.isRefreshing = false
                    }
                }
            }
        }

        Item {
            id: profilesPage
            anchors.top: meHeaderMenu.bottom
            width: parent.width
            height: parent.height - meHeaderMenu.height
            visible: false

            Item {
                width: parent.width
                height: parent.height
                ProfileViewComponent {
                    id: profileViewTab
                    width: parent.width
                    height: parent.height
                    visible: profilesPage.visible
                    userId: userManager.getUserId()
                    onBadgeClicked: showBadgeDescripion(badgeSource,badgeName,description,badge_id);
                }
            }
        }

        Item {
            id: settingsPage
            anchors.top: meHeaderMenu.bottom
            width: parent.width
            height: parent.height - meHeaderMenu.height
            visible: false

            Flickable {
                id: setting
                width: parent.width
                height: parent.height
                contentWidth: parent.width
                contentHeight: settingComponent.height
                SettingComponent {
                    id: settingComponent
                    onFindFriendClicked: {
                        pageStack.push(Qt.resolvedUrl("../Screen/FindFriendsScreen.qml"));
                    }
                    //onFindFriendClicked: createFindFriendDialog();
                }
            }
        }
    }
    Image {
        id: footer
        anchors.bottom: parent.bottom
        source: "../res/main_screen_bottom_menu.png"

        RadioButton {
            id: btnTimeline
            x: themeManager.timelineFooterBtnX
            y: themeManager.btnFooterY
            bitmap: "../res/bottom_menu_slider_blank.png"
            bitmap_pressed: "../res/bottom_menu_slider_highlighted.png"
            bitmap_selected: "../res/bottom_menu_slider_selected.png"
            text: ""
            selected: true
            onClicked: {
                if (currentState == "NotificationsTab")
                    notificationListView.markAllAsRead();

                if (currentTimelineTab == "Timeline")
                    switchToTab("TimelineTab")
                else
                    switchToTab("PopularTab")
            }
        }

        RadioButton {
            id: btnShare
            x: themeManager.shareFooterBtnX
            y: themeManager.btnFooterY
            bitmap: "../res/bottom_menu_slider_blank.png"
            bitmap_pressed: "../res/bottom_menu_slider_highlighted.png"
            bitmap_selected: "../res/bottom_menu_slider_selected.png"
            text: ""
            selected: false
            onClicked: {
                var photoSourceDialog = CreateComponent.createPhotoSourceDialog(mainScreen);
                photoSourceDialog.bottomMargin = footer.height;
                photoSourceDialog.fromTakePhotoClicked.connect(
                    function() {
                        if (themeManager.platform === "meego")
                            pageStack.push(Qt.resolvedUrl("CaptureScreen.qml"), null, true);
                        else
                            pageStack.push(Qt.resolvedUrl("CaptureScreen.qml"), null, true);
                    }
                );
                photoSourceDialog.fromGalleryClicked.connect(
                    function() {
                        if (themeManager.platform === "meego")
                            pageStack.push(Qt.resolvedUrl("PhotoPickerScreenM.qml"), null, true);
                        else
                            pageStack.push(Qt.resolvedUrl("PhotoPickerScreen.qml"), null, true);
                    }
                );
            }
        }

        RadioButton {
            id: btnMe
            x: themeManager.notificationFooterBtnX
            y: themeManager.btnFooterY
            bitmap: "../res/bottom_menu_slider_blank.png"
            bitmap_pressed: "../res/bottom_menu_slider_highlighted.png"
            bitmap_selected: "../res/bottom_menu_slider_selected.png"
            text: ""
            selected: false
            onClicked: {
                if (currentMeTab == "Notifications")
                    switchToTab("NotificationsTab")
                else if (currentMeTab == "Profiles")
                    switchToTab("ProfilesTab")
                else
                    switchToTab("SettingsTab")
            }

            Rectangle {
                id: notifAlert
                anchors.top: parent.top
                anchors.right: parent.right
                anchors.topMargin: themeManager.smallPadding
                anchors.rightMargin: themeManager.paddingLeftRight
                visible: btnNotificationAll.text !== "0"

                Image {
                    id: notifLeft
                    source: "../res/notification_badge_left.png"
                    anchors.right: notifMid.left
                }
                Image {
                    id: notifMid
                    source: "../res/notification_badge_center.png"
                    width: childrenRect.width
                    anchors.right: notifRight.left

                    Text {
                        id: notifTotalCount
                        text: btnNotificationAll.text
                        font.pixelSize: themeManager.notificationBadgeFontSize
                        font.bold: true
                        color: "#BB491E"
                        styleColor:"#FFCA6F"
                        style: Text.Raised
                    }
                }
                Image {
                    id: notifRight
                    source: "../res/notification_badge_right.png"
                    anchors.right: parent.right
                }
            }
        }
    }

    Component.onCompleted: {
        globalServices.goToTimelineTab.connect(switchToTimeLineTab);
        globalServices.refreshRequested.connect(autoRefresh);
        globalServices.timelineRefreshRequested.connect(onTimelineRefreshRequested);
        globalServices.profileRefreshRequested.connect(onProfileRefreshRequested);
        globalServices.setLovedCommentedData.connect(mainScreen.onLovedCommentedDataSet);
        globalServices.setFollowStatus.connect(mainScreen.onFollowStatusSet);
        globalServices.uploadingQueueChanged.connect(onUploadingQueueChanged);
        globalServices.clearTimelineRequested.connect(clearTimeline);
        globalServices.pictureDeleted.connect(onPictureDeleted);
        globalServices.imageCaptionChanged.connect(onImageCaptionChanged);
        globalServices.accessLevelSaltChanged.connect(onAccessLevelSaltChanged);
        timer.start();
        uploaderQueueModel.loadQueues();

        notificationModel.lastReadNotificationId = Storage.getDataWithDefaultValue("notification_last_read_id", 0);
    }
    Component.onDestruction: {
        timer.stop();
        if (currentState === "NotificationsTab")
            notificationListView.markAllAsRead()
        globalServices.goToTimelineTab.disconnect(switchToTimeLineTab);
        globalServices.refreshRequested.disconnect(autoRefresh);
        globalServices.timelineRefreshRequested.disconnect(onTimelineRefreshRequested);
        globalServices.profileRefreshRequested.disconnect(onProfileRefreshRequested);
        globalServices.setLovedCommentedData.disconnect(mainScreen.onLovedCommentedDataSet);
        globalServices.setFollowStatus.disconnect(mainScreen.onFollowStatusSet);
        globalServices.uploadingQueueChanged.disconnect(onUploadingQueueChanged);
        globalServices.clearTimelineRequested.disconnect(clearTimeline);
        globalServices.pictureDeleted.disconnect(onPictureDeleted);
        globalServices.imageCaptionChanged.disconnect(onImageCaptionChanged);
        globalServices.accessLevelSaltChanged.disconnect(onAccessLevelSaltChanged);

        molomeServiceController.cancelTransactionByTransactionID(mainScreen.getHomeTimelineRefreshTransactionId);
        molomeServiceController.cancelTransactionByTransactionID(mainScreen.getPopularTransactionId);
        molomeServiceController.cancelTransactionByTransactionID(mainScreen.getNotificationRefreshTransactionId);
    }

    // Loved Commented Data Changed

    function onLovedCommentedDataSet(picture_id, love_count, done_love, comment_count, done_comment)
    {
        timelineModel.setLovedCommentedData(picture_id, love_count, done_love, comment_count, done_comment);
        popularModel.setLovedCommentedData(picture_id, love_count, done_love, comment_count, done_comment);
        notificationModel.setLovedCommentedData(picture_id, love_count, done_love, comment_count, done_comment);
        profileViewTab.manager.setLovedCommentedData(picture_id, love_count, done_love, comment_count, done_comment);
    }

    function onFollowStatusSet(username, followed)
    {
        var contentY = notificationListView.contentY
        notificationModel.setFollow(username, followed);
        notificationListView.contentY = contentY
    }

    function onUploadingQueueChanged()
    {
        if (uploaderQueueModel.getQueueCount() > 0)
        {
            uploadingListBar.visible = true;
            uploadingListBar.height = uploadingListBar.sourceSize.height;
        }
        else
        {
            uploadingListBar.visible = false;
            uploadingListBar.height = 0;
        }
    }

    function onTimelineRefreshRequested()
    {
        refreshTimeline();
        refreshTimelinePhotoSummary();
    }

    function onProfileRefreshRequested()
    {
        profileViewTab.refresh();
    }

    Timer {
        id: timer
        interval: 500
        repeat: false
        running: false
        onTriggered: {
            refreshTimeline();
            refreshTimelinePhotoSummary();
            refreshPopular();
            refreshNotification();
            profileViewTab.addDataProfileWhenOffine();
            profileViewTab.refresh();

            //var listModel = Qt.createQmlObject("import QtQuick 1.0; ListModel{id:listModel}", mainScreen, "");
            //listModel.append({'imageLoaderManager': imageLoaderManager});
            //workerStart.sendMessage(listModel);

            timer.stop();
        }
    }

//    WorkerScript {
//        id: workerStart
//        source: "../js/firstRunMainScreen.js"
//        onMessage: {
//            //console.log("Done: " + messageObject.reply);
//        }
//    }

    function refreshTimeline() {
        if (timelineModel.isRefreshing)
            return;

        timelineModel.isRefreshing = true
        if (timelineModel.getCount() === 0)
            timelineModel.isLoadingMore = true
        mainScreen.getHomeTimelineRefreshTransactionId = molomeServiceController.getHomeTimeline(userManager.getUserId(), 1, photoCount, timelineModel.getNewestId(), 0, getHomeTimelineHandler);
    }

    function loadMoreTimeline() {
        if (timelineModel.getCount() === 0)
        {
            refreshTimeline();
            refreshTimelinePhotoSummary();
            return;
        }

        if (timelineModel.isLoadingMore)
            return;
        timelineModel.isLoadingMore = true
        mainScreen.getHomeTimelineLoadMoreTransactionId = molomeServiceController.getHomeTimeline(userManager.getUserId(), 1, photoCount, 0, timelineModel.getOldestId(), getHomeTimelineLoadMoreHandler);
    }

    function refreshTimelinePhotoSummary() {
        // Already Refreshing
        if (getHomeTimelinePhotoSummaryTransactionId != 0)
            return;

        var pictureIds = timelineModel.getPictureIds();
        if (pictureIds === "")
            return;

        mainScreen.getHomeTimelinePhotoSummaryTransactionId = molomeServiceController.getPhotoSummary(pictureIds, getHomeTimelinePhotoSummaryHandler);
    }

    function clearTimeline() {
        timelineModel.isRefreshing = false
        timelineModel.isLoadingMore = false
        molomeServiceController.cancelTransactionByTransactionID(mainScreen.getHomeTimelineRefreshTransactionId);
        molomeServiceController.cancelTransactionByTransactionID(mainScreen.getHomeTimelineLoadMoreTransactionId);

        timelineModel.clear();

        refreshTimeline();
    }

    function onPictureDeleted(pictureId) {
        timelineModel.removePictureById(pictureId)
        popularModel.removePictureById(pictureId)
        profileViewTab.refresh()
    }

    function onImageCaptionChanged(picture_id, caption) {
        timelineModel.setPhotoName(picture_id, caption);
        popularModel.setPhotoName(picture_id, caption);
        notificationModel.setPhotoName(picture_id, caption);
        profileViewTab.manager.setPhotoName(picture_id, caption);
    }

    function onAccessLevelSaltChanged(picture_id, access_level, salt) {
        timelineModel.setAccessLevelSalt(picture_id, access_level, salt);
        profileViewTab.manager.setAccessLevelSalt(picture_id, access_level, salt);
    }

    function refreshPopular() {
        if (popularModel.isRefreshing)
            return;
        popularModel.isRefreshing = true
        if (popularModel.getCount() === 0)
            mainScreen.popularLoading = CreateComponent.createLoadingComponent(popularPage);
        mainScreen.getPopularTransactionId = molomeServiceController.getPopularTimeline(getPopularTimelineHandler);
    }

    function refreshNotification() {
        if (notificationModel.isRefreshing)
            return;
        notificationModel.isRefreshing = true
        mainScreen.getNotificationRefreshTransactionId = molomeServiceController.getNotifications(notificationCount, notificationModel.getNewestId("all"), 0,
                                                                    notificationModel.getNewestId("loved"), 0,
                                                                    notificationModel.getNewestId("commented"), 0,
                                                                    notificationModel.getNewestId("badged"), 0,
                                                                    notificationModel.getNewestId("followed"), 0,
                                                                    notificationModel.lastReadNotificationId,
                                                                    getNotificationHandler);
        if (!notificationListView.footerVisible)
            loadingNotificationArea.createLoadingImage();
    }

    function loadMoreNotification() {
        if (notificationModel.isLoadingMore)
            return;
        notificationModel.isLoadingMore = true
        mainScreen.getNotificationLoadMoreTransactionId = molomeServiceController.getNotifications(notificationCount, 0, notificationModel.getOldestId("all"),
                                                                    0, notificationModel.getOldestId("loved"),
                                                                    0, notificationModel.getOldestId("commented"),
                                                                    0, notificationModel.getOldestId("badged"),
                                                                    0, notificationModel.getOldestId("followed"),
                                                                    notificationModel.lastReadNotificationId,
                                                                    getNotificationLoadMoreHandler);
    }

    function refresh() {
        if (mainScreen.isTimelineTab == true)
        {
            refreshTimeline();
            refreshTimelinePhotoSummary();
        }
        else if (mainScreen.isPopularTab)
            refreshPopular();
        else if (mainScreen.isNotificationTab)
            refreshNotification();
        else if (mainScreen.isProfileTab)
            profileViewTab.refresh();
    }

    function showBadgeDescripion(bagdeSource,badgeName,bagdeDescription,badge_id) {
         CreateComponent.createBadgeDialog("../",mainScreen,bagdeSource,badgeName,bagdeDescription,badge_id);
    }

    function createFindFriendDialog() {
        var textDialog = CreateComponent.createTextDialog("../",mainScreen);
        textDialog.caption = "Username:"
        textDialog.headerText ="Find Friends"
        textDialog.clicked.connect(
            function(text) {
                if (text === "") {
                    CreateComponent.createInformationDialog(mainScreen, "", "Please enter your friend's username!");
                } else {
                    textDialog.destroyDialog();
                    pageStack.push(Qt.resolvedUrl("../Screen/FriendListScreen.qml"), {title: qsTr("Find Friends"), userName: text, isSearchUser: true});
                }
            }
        );
    }
    function autoRefresh() {
        refreshTimeline();
        refreshTimelinePhotoSummary();
        refreshPopular();
        refreshNotification();
    }
    function uploadFinishTimelineChange() {
        refreshTimeline();
        refreshTimelinePhotoSummary();

    }
    function uploadFinishProfileChange() {
        profileViewTab.refresh();
    }
    function cancel() {
        if (mainScreen.isTimelineTab == true) {
            timelineModel.isRefreshing = false
            if (timelineModel.getCount() === 0)
                timelineModel.isLoadingMore = false
            molomeServiceController.cancelTransactionByTransactionID(mainScreen.getHomeTimelineRefreshTransactionId);
        } else if (mainScreen.isPopularTab) {
            popularModel.isRefreshing = false
            if (mainScreen.popularLoading !== null && typeof mainScreen.popularLoading !== "undefined")
            {
                mainScreen.popularLoading.visible = false;
                CreateComponent.destroyComponent(mainScreen.popularLoading.getPageId(), 0);
            }
            molomeServiceController.cancelTransactionByTransactionID(mainScreen.getPopularTransactionId);
        } else if (mainScreen.isNotificationTab) {
            notificationModel.isRefreshing = false
            loadingNotificationArea.destroyLoadingImage()
            molomeServiceController.cancelTransactionByTransactionID(mainScreen.getNotificationRefreshTransactionId);
        } else if (mainScreen.isProfileTab) {
            profileViewTab.cancel();
        }
    }

    function createWelcomeDialog(){
        var information = CreateComponent.createInformationDialog(mainScreen, "../res/molo_alert_face.png" ,"Welcome Back!!");
    }

    function goToTop() {
        if (mainScreen.isTimelineTab)
            timelineView.contentY = 0;
        else if (mainScreen.isPopularTab)
            popularPage.contentY = 0;
        else if (mainScreen.isNotificationTab)
            notificationListView.contentY = 0;
        else if (mainScreen.isProfileTab)
            profileViewTab.goToTop();
        else if (mainScreen.isSettingTab)
            setting.contentY = 0;
    }

    function switchToTab(tab)
    {
        currentState = tab;
        if (tab === "TimelineTab")
        {
            timelineTabHolder.visible = true
            meTabHolder.visible = false
            btnTimeline.selected = true
            btnShare.selected = false
            btnMe.selected = false
            btnTabTimeline.selected = true
            btnTabPopular.selected = false
            timelinePage.visible = true
            popularPage.visible = false
            mainScreen.currentTimelineTab = "Timeline"
            timelineHeaderMenu.isRefreshBtnAcive = true
            //timelineHeaderMenu.isLoading = ?
        }
        else if (tab === "PopularTab")
        {
            timelineTabHolder.visible = true
            meTabHolder.visible = false
            btnTimeline.selected = true
            btnShare.selected = false
            btnMe.selected = false
            btnTabTimeline.selected = false
            btnTabPopular.selected = true
            timelinePage.visible = false
            popularPage.visible = true
            mainScreen.currentTimelineTab = "Popular"
            timelineHeaderMenu.isRefreshBtnAcive = true
            //timelineHeaderMenu.isLoading = ?
        }
        else if (tab === "NotificationsTab")
        {
            timelineTabHolder.visible = false
            meTabHolder.visible = true
            btnTimeline.selected = false
            btnShare.selected = false
            btnMe.selected = true
            btnTabNotifications.selected = true
            btnTabProfiles.selected = false
            btnTabSettings.selected = false
            notificationPage.visible = true
            profilesPage.visible = false
            settingsPage.visible = false
            mainScreen.currentMeTab = "Notifications"
            meHeaderMenu.isRefreshBtnAcive = true
            //meHeaderMenu.isLoading = ?
        }
        else if (tab === "ProfilesTab")
        {
            timelineTabHolder.visible = false
            meTabHolder.visible = true
            btnTimeline.selected = false
            btnShare.selected = false
            btnMe.selected = true
            btnTabNotifications.selected = false
            btnTabProfiles.selected = true
            btnTabSettings.selected = false
            notificationPage.visible = false
            profilesPage.visible = true
            settingsPage.visible = false
            mainScreen.currentMeTab = "Profiles"
            meHeaderMenu.isRefreshBtnAcive = true
            //meHeaderMenu.isLoading = ?
        }
        else if (tab === "SettingsTab")
        {
            timelineTabHolder.visible = false
            meTabHolder.visible = true
            btnTimeline.selected = false
            btnShare.selected = false
            btnMe.selected = true
            btnTabNotifications.selected = false
            btnTabProfiles.selected = false
            btnTabSettings.selected = true
            notificationPage.visible = false
            profilesPage.visible = false
            settingsPage.visible = true
            mainScreen.currentMeTab = "Settings"
            meHeaderMenu.isRefreshBtnAcive = false
        }
    }

    function switchToTimeLineTab() {
        switchToTab("TimelineTab");
    }
}
