/*
 * Copyright (c) 2011 Petru Motrescu <petru.motrescu@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

import QtQuick 1.0
import PhotoPicker 1.0
import "../UIComponents"
import "../../platforms"

PageWrapper {
    id: photoPickerScreen

    width: themeManager.screenWidth
    height: themeManager.screenHeight

    orientationLock: themeManager.pageOrientationPortrait

    Header {
        id: header
        hasBack: true
        anchors.top: parent.top
        onBackClicked: {
            pageStack.pop();
        }
        MouseArea {
            id: goToTopHitBox
            anchors.fill: parent
            onClicked: {
                goToTop();
            }
        }
    }

    HeaderBar {
        id: headerCaption
        anchors.top: header.bottom
        text: qsTr("Select from Gallery")
    }

    GridView {
        id: view
        clip: true
        width: parent.width
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: headerCaption.bottom
        anchors.bottom: parent.bottom
        model: photomodel
        cellWidth: 160
        cellHeight: 160
        cacheBuffer: 1600
        pressDelay: 100
        maximumFlickVelocity: 3500

        delegate: PhotoItem {
            id: item
            url: model.url
            pressed: mouseArea.pressed
            MouseArea {
                id: mouseArea
                anchors.fill: parent
                onClicked: {
                    pageStack.pop(photoPickerScreen, true);
                    var urlLocal = item.url.toString();
                    urlLocal = urlLocal.replace('file://', '');
                    pageStack.push(Qt.resolvedUrl("ZoomCropScreen.qml"), {file: urlLocal}, true);
                }
            }
        }
    }

    Component.onCompleted: {

    }
}

