import MOLOMELib 1.0
import QtQuick 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../ListDelegate"
import "../js/createComponent.js" as CreateComponent
import "../../util/common.js" as Common
import "../../util/constant.js" as Constant
import "../../platforms"
import "../js/uiUtils.js" as UIUtils

PageWrapper {
    id: photoViewScreen
    property bool isFlickableVisible: themeManager.isPortrait
    property variant loading : null
    property bool commentDialogActive: false
    property bool facebookLoggedIn: userManager.isFacebookAvailable();
    property bool twitterLoggedIn: userManager.isTwitterAvailable();
    property bool tumblrLoggedIn: userManager.isTumblrAvailable();
    property bool weiboLoggedIn: userManager.isWeiboAvailable();
    property bool flickrLoggedIn: userManager.isFlickrAvailable();
    property bool vkLoggedIn: userManager.isVkAvailable();
    property bool dropBoxLoggedIn: userManager.isDropBoxAvailable();
    property bool gDriveLoggedIn: userManager.isGDriveAvailable();
    property bool picasaLoggedIn: userManager.isPicasaAvailable();
    property string ads_url
    property int user_id_
    property int love_count
    property int comment_count
    property string picture_name
    property string picture_code:""
    property string profile_picture_code
    property string access_level: ""
    property string salt: ""
    property int view_count
    property string username_
    property string create_time
    property int commentPerPage: 15
    property bool done_love
    property string commentText: ""
    property variant pictureInfo: null
    property int commentListTransactionId: 0
    property variant commentPostTransactionId
    property variant deleteCommentTransactionId
    property variant flagForReviewTransactionId
    property variant editCaptionTransactionId
    property variant makeProfilePictureTransactionId
    property variant deletePictureTransactionId
    property variant reshareTransactionId
    property int changeAccessLevelTransactionId

    property int accessLevel: 0

    property string newCaption
    property int processingCommentId

    property real downloadPercentage: 0

    property bool forceLoveStatus: false

    property variant reshareDialog: null
    property variant loadingDialog: null
    property variant textDialog: null
    property variant flagForreviewDialog: null

    orientationLock: themeManager.pageOrientationPortrait

    onPictureInfoChanged: {
        if (pictureInfo !== null && typeof pictureInfo !== "undefined")
            reloadCommentList();
    }
    onCommentDialogActiveChanged: showPostCommentDialog("", 0);

    width: themeManager.screenWidth
    height: themeManager.screenHeight

    Header {
        id: header
        hasBack: true
        anchors.top: parent.top
        onBackClicked: pageStack.pop();
        MouseArea {
            id: goToTopHitBox
            anchors.fill: parent
            onClicked: goToTop();
        }
    }

    PhotoViewHeaderBar {
        id: headerbase
        profilePictureSource: photoViewScreen.profile_picture_code
        username: photoViewScreen.username_
        timeStamp: dateTimeModel.setDateTime(photoViewScreen.create_time,Constant.FORMAT_DATE_TIME);
        onClicked: UIUtils.openProfileViewScreenByUsername(photoViewScreen.username_);
        onUsernameClicked: UIUtils.openProfileViewScreenByUsername(photoViewScreen.username_);
    }

    CommentListModel {
        id: commentListModel
    }
    ListView {
        id: photoViewListView
        width: parent.width
        height: parent.height
        anchors.top: headerbase.bottom
        anchors.bottom: parent.bottom
        interactive: true
        clip: true

        property bool isLoading: false
        property string text: ""
        property bool isLoadMoreVisible: true

        delegate: PhotoViewDelegate {
            onActionClicked: createCommentActionDialog(username, comment_id, user_id)
            onProfilePictureClicked: UIUtils.openProfileViewScreenByUsername(username);
            onUsernameClicked: UIUtils.openProfileViewScreenByUsername(username);
        }
        model: commentListModel
        footer: Item {
            width: photoViewListView.width
            height: photoViewListView.isLoadMoreVisible ? (themeManager.loadmoreHeight + themeManager.tenPadding * 2) : 0
            LoadMoreButton {
                id: loadMoreButton
                anchors.top: parent.top
                anchors.leftMargin: themeManager.tenPadding
                anchors.topMargin: themeManager.tenPadding
                anchors.bottomMargin: themeManager.tenPadding
                isLoading: photoViewListView.isLoading
                text: photoViewListView.text
                visible: photoViewListView.isLoadMoreVisible
                onClicked: {
                    if (photoViewListView.isLoading == false)
                        loadMoreCommentList()
                }
            }
            Item10 { anchors.top: loadMoreButton.bottom; }
        }
    }

    Timer {
        id: timerDestroyLoadingDialog
        repeat: false
        running: false
        triggeredOnStart: false
        interval: 10
        onTriggered: {
            if (loadingDialog)
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
        }
    }

    /* Dialog */
    function createPictureActionDialog() {
        var isShareToTwitterActive = photoViewScreen.twitterLoggedIn;
        var isShareToFacebookActive = photoViewScreen.facebookLoggedIn;
        var isShareToTumblrActive = photoViewScreen.tumblrLoggedIn;
        var isShareToFlickrActive = photoViewScreen.flickrLoggedIn;
        var isShareToWeiboActive = photoViewScreen.weiboLoggedIn;
        var isShareToVkActive = photoViewScreen.vkLoggedIn;
        var isShareToDropBoxActive = photoViewScreen.dropBoxLoggedIn;
        var isShareToGDriveActive = photoViewScreen.gDriveLoggedIn;
        var isShareToPicasaActive = photoViewScreen.picasaLoggedIn;
        var isReshareActive = isShareToTwitterActive || isShareToFacebookActive || isShareToTumblrActive || isShareToVkActive;// || isShareToWeiboActive;
        var isFlagForReviewActive = true;
        var isReplyThisCommentActive = false;
        var isViewProfileActive = false;
        var isBlockUserActive = false;
        var isDeletePictureActive = true;
        var isReadMoreActive = photoViewScreen.ads_url == "" ? false : true;
        var isEditCaptionActive = true;
        var isMakeProfilePictureActive = true;
        var isChangeAccessLevelActive = true;
        if (photoViewScreen.user_id_ === userManager.getUserId()) {
            var isUser = CreateComponent.createPhotoContextDialog(photoViewScreen, isReshareActive, false
                                                                             , isReplyThisCommentActive, isViewProfileActive, isBlockUserActive, isDeletePictureActive
                                                                             , isReadMoreActive, isEditCaptionActive, isMakeProfilePictureActive, isChangeAccessLevelActive);
            //isUser.twitterClicked.connect(function(){shareToTwitter();});
            //isUser.facebookClicked.connect(function(){shareToFacebook();});
            isUser.deleteClicked.connect(function(){deletePicture();});
            isUser.readMoreClicked.connect(function(){readMore();});
            isUser.editCaptionClicked.connect(function(){showEditCaptionDialog();}); //finish
            isUser.makeProfilePictureClicked.connect(function(){makeProfilePicture();}); //finish
            isUser.reshareClicked.connect(function(){launchReshareDialog();});
            isUser.changeAccessLevelClicked.connect(function(){launchChangeAccessLevelDialog();});
        } else {
            var isNotUser = CreateComponent.createPhotoContextDialog(photoViewScreen, isReshareActive, isFlagForReviewActive
                                                                             , false, false, false, false
                                                                             , false, false, false, false);
            isNotUser.flagForReviewClicked.connect(function(){showFlagsForReviewDialog();}); // finish
            //isNotUser.twitterClicked.connect(function(){shareToTwitter();});
            //isNotUser.facebookClicked.connect(function(){shareToFacebook();});
            isNotUser.reshareClicked.connect(function(){launchReshareDialog();});
        }
    }

    function createCommentActionDialog(username, comment_id, user_id) {
        if (photoViewScreen.user_id_ === userManager.getUserId() || user_id === userManager.getUserId()) {
            var userCanDelete = CreateComponent.createPhotoContextDialog(photoViewScreen, false, false, true, true, userManager.getUserId() !== user_id, true, false, false, false, false);
            userCanDelete.replyCommentClicked.connect(function(){ showPostCommentDialog("@"+username+" ", comment_id); });
            userCanDelete.viewProfileClicked.connect(function(){ UIUtils.openProfileViewScreenByUsername(username); });
            userCanDelete.blockUserClicked.connect(function(){ blockUser(user_id) });
            userCanDelete.deleteClicked.connect(function(){ deleteComment(comment_id) });
        } else {
            var userCannotDelete = CreateComponent.createPhotoContextDialog(photoViewScreen, false, false, true, true, userManager.getUserId() !== user_id, false, false, false, false, false);
            userCannotDelete.replyCommentClicked.connect(function(){ showPostCommentDialog("@"+username+" ", comment_id); });
            userCannotDelete.viewProfileClicked.connect(function(){ UIUtils.openProfileViewScreenByUsername(username); });
            userCannotDelete.blockUserClicked.connect(function(){ blockUser(user_id) });
        }
    }

    /* Edit Caption */
    MolomeServiceHandler {
        id: editCaptionHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                if (photoViewScreen.textDialog !== null && typeof photoViewScreen.textDialog !== "undefined")
                {
                    CreateComponent.destroyComponent(photoViewScreen.textDialog, 0);
                    photoViewScreen.textDialog = null;
                }
                CreateComponent.createInformationDialog(photoViewScreen, "", "Caption Changed");
                globalServices.emitImageCaptionChanged(photoViewScreen.pictureInfo.picture_id, newCaption);
            }
            else
                CreateComponent.createInformationDialog(photoViewScreen, "", ret.reason);
            timerDestroyLoadingDialog.start();
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(photoViewScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function showEditCaptionDialog()
    {
        photoViewScreen.textDialog = CreateComponent.createTextDialog("../", photoViewScreen);
        photoViewScreen.textDialog.text = photoViewScreen.picture_name
        photoViewScreen.textDialog.headerText = "Caption"
        photoViewScreen.textDialog.clicked.connect(
            function (text) {
                newCaption = text
                if (pictureInfo !== null && typeof pictureInfo !== "undefined")
                {
                    loadingDialog = CreateComponent.createLoadingDialog(photoViewScreen, "Editing Caption ...");
                    loadingDialog.clicked.connect(
                        function() {
                            molomeServiceController.cancelTransactionByTransactionID(photoViewScreen.editCaptionTransactionId);
                        }
                    );
                    photoViewScreen.editCaptionTransactionId = molomeServiceController.editCaption(photoViewScreen.pictureInfo.picture_id, text, editCaptionHandler);
                }
            }
        );
    }

    /* Change Access Level */
    function launchChangeAccessLevelDialog()
    {
        var sprite = CreateComponent.createChooseAccessLevelDiadlog("../", photoViewScreen);
        if (access_level === "friends")
            sprite.selectedIndex = 1
        else if (access_level === "only me")
            sprite.selectedIndex = 2
        else
            sprite.selectedIndex = 0

        sprite.selected.connect(
            function (id) {
                loadingDialog = CreateComponent.createLoadingDialog(photoViewScreen, "Changing Access Level ...");
                loadingDialog.clicked.connect(
                    function() {
                        molomeServiceController.cancelTransactionByTransactionID(photoViewScreen.changeAccessLevelTransactionId);
                    }
                );
                photoViewScreen.accessLevel = id;
                photoViewScreen.changeAccessLevelTransactionId = molomeServiceController.changePhotoAccessLevel(photoViewScreen.pictureInfo.picture_id, id, changeAccessLevelHandler);
            }
        );
    }

    MolomeServiceHandler {
        id: changeAccessLevelHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.createInformationDialog(photoViewScreen, "", "Access Level Changed");
            }
            else
            {
                if (ret.reason !== "")
                    CreateComponent.createInformationDialog(photoViewScreen, "", ret.reason);
                else
                    CreateComponent.createInformationDialog(photoViewScreen, "", "Error Occurred");
            }
            timerDestroyLoadingDialog.start();
        }
        function onMolomeServiceError(statusCode, message)
        {
            if (message !== "")
                CreateComponent.createInformationDialog(photoViewScreen, "", message);
            else
                CreateComponent.createInformationDialog(photoViewScreen, "", "Error Occurred");
            timerDestroyLoadingDialog.start();
        }
    }

    /* Reshare */

    function launchReshareDialog() {
        photoViewScreen.reshareDialog = CreateComponent.createReshareDialog(photoViewScreen);
        photoViewScreen.reshareDialog.isShareToTwitterActive = photoViewScreen.twitterLoggedIn
        photoViewScreen.reshareDialog.isShareToFacebookActive = photoViewScreen.facebookLoggedIn
        photoViewScreen.reshareDialog.isShareToTumblrActive = photoViewScreen.tumblrLoggedIn
        photoViewScreen.reshareDialog.isShareToVKActive = photoViewScreen.vkLoggedIn
        photoViewScreen.reshareDialog.isShareToWeiboActive = photoViewScreen.weiboLoggedIn

        photoViewScreen.reshareDialog.twitterClicked.connect(function(){shareToTwitter();});
        photoViewScreen.reshareDialog.facebookClicked.connect(function(){shareToFacebook();});
        photoViewScreen.reshareDialog.tumblrClicked.connect(function(){shareToTumblr();});
        photoViewScreen.reshareDialog.vkClicked.connect(function(){shareToVK();});
        photoViewScreen.reshareDialog.weiboClicked.connect(function(){shareToWeibo();});
    }

    MolomeServiceHandler {
        id: reshareHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                if (photoViewScreen.textDialog !== null && typeof photoViewScreen.textDialog !== "undefined")
                {
                    CreateComponent.destroyComponent(photoViewScreen.textDialog, 0);
                    photoViewScreen.textDialog = null;
                }
                CreateComponent.createInformationDialog(photoViewScreen, "", "Reshared");
            }
            else
                CreateComponent.createInformationDialog(photoViewScreen, "", ret.reason);
            timerDestroyLoadingDialog.start();
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(photoViewScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function showReshareDialog(toTwitter, toFacebook, toTumblr, toVK, toWeibo)
    {
        if (!toTwitter && !toFacebook && !toTumblr && !toVK && !toWeibo)
            return;
        var socialNetworkName = "Twitter";
        if (toTwitter)
            socialNetworkName = "Twitter";
        else if (toFacebook)
            socialNetworkName = "Facebook";
        else if (toTumblr)
            socialNetworkName = "Tumblr";
        else if (toVK)
            socialNetworkName = "VK";
        else if (toWeibo)
            socialNetworkName = "Weibo";
        photoViewScreen.textDialog = CreateComponent.createTextDialog("../", photoViewScreen);
        photoViewScreen.textDialog.caption = "Caption:"
        photoViewScreen.textDialog.headerText = "Share To " + socialNetworkName
        photoViewScreen.textDialog.clicked.connect(
            function (text) {
                loadingDialog = CreateComponent.createLoadingDialog(photoViewScreen, "Resharing to " + socialNetworkName + " ....");
                loadingDialog.clicked.connect(
                    function() {
                        molomeServiceController.cancelTransactionByTransactionID(photoViewScreen.reshareTransactionId);
                    }
                );
                photoViewScreen.reshareTransactionId = molomeServiceController.reshare(photoViewScreen.pictureInfo.picture_id, text, toTwitter, toFacebook, toTumblr, toVK, toWeibo, reshareHandler);
            }
        );
    }

    function shareToTwitter()
    {
        showReshareDialog(true, false, false, false, false);
    }

    function shareToFacebook()
    {
        showReshareDialog(false, true, false, false, false);
    }

    function shareToTumblr()
    {
        showReshareDialog(false, false, true, false, false);
    }

    function shareToVK()
    {
        showReshareDialog(false, false, false, true, false);
    }

    function shareToWeibo()
    {
        showReshareDialog(false, false, false, false, true);
    }

    /* Delete Picture */
    MolomeServiceHandler {
        id: deletePictureHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                var infoDialog = CreateComponent.createInformationDialog(photoViewScreen, "", "Photo Deleted");
                infoDialog.clicked.connect(
                    function () {
                        globalServices.emitPictureDeleted(pictureInfo.picture_id)
                        pageStack.pop();
                    }
                );
            }
            else
                CreateComponent.createInformationDialog(photoViewScreen, "", ret.reason);
            timerDestroyLoadingDialog.start();
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(photoViewScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function deletePicture() {
        var confirmDialog = CreateComponent.createConfirmationDialog("../", photoViewScreen, "Are you sure to delete this photo?");
        confirmDialog.clicked.connect(
             function () {
                  loadingDialog = CreateComponent.createLoadingDialog(photoViewScreen, "Deleting ....");
                  loadingDialog.clicked.connect(
                      function() {
                          molomeServiceController.cancelTransactionByTransactionID(photoViewScreen.deletePictureTransactionId);
                      }
                  );
                  photoViewScreen.deletePictureTransactionId = molomeServiceController.deletePicture(photoViewScreen.pictureInfo.picture_id, deletePictureHandler);
            }
        );
    }

    /* Post Comment */
    MolomeServiceHandler {
        id: commentPictureHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                if (photoViewScreen.textDialog !== null && typeof photoViewScreen.textDialog !== "undefined")
                {
                    CreateComponent.destroyComponent(photoViewScreen.textDialog, 0);
                    photoViewScreen.textDialog = null;
                }
                //CreateComponent.createInformationDialog(photoViewScreen, "", "Comment Posted");
                //commentBox.getTextEdit().text = "";
                photoViewScreen.commentText = ""
                photoViewScreen.comment_count += 1;
                globalServices.emitSetLovedCommentedData(photoViewScreen.pictureInfo.picture_id, photoViewScreen.love_count, photoViewScreen.done_love, photoViewScreen.comment_count, false);
                reloadCommentList();
            }
            else
                CreateComponent.createInformationDialog(photoViewScreen, "", ret.reason);
            timerDestroyLoadingDialog.start();
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(photoViewScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function postComment(text, pictureId, inReplyToId) {
        if (text !== "") {
            loadingDialog = CreateComponent.createLoadingDialog(photoViewScreen, "Posting Comment ...");
            loadingDialog.clicked.connect(
                function() {
                    molomeServiceController.cancelTransactionByTransactionID(photoViewScreen.commentPostTransactionId);
                }
            );
            photoViewScreen.commentPostTransactionId = molomeServiceController.postComment(text, pictureId, inReplyToId, commentPictureHandler);
        } else{
            CreateComponent.createInformationDialog(photoViewScreen, "", "Please enter text to comment!");
        }
    }

    function showPostCommentDialog(startText, inReplyToId) {
        photoViewScreen.textDialog = CreateComponent.createTextDialog("../",photoViewScreen);
        photoViewScreen.textDialog.text = startText
        photoViewScreen.textDialog.headerText = "Comment"
        photoViewScreen.textDialog.moveCursorToEnd()
        photoViewScreen.textDialog.clicked.connect(
            function(text) {
                if (text !== "") {
                    if (pictureInfo !== null && typeof pictureInfo !== "undefined")
                        postComment(text, photoViewScreen.pictureInfo.picture_id, inReplyToId);
                } else {
                    CreateComponent.createInformationDialog(photoViewScreen,"","Please enter text to comment!");
                }
            }
        );
    }

    /* Block User */

    function blockUser(userId) {
        molomeServiceController.blockUser(userId, blockUserHandler);
    }
    MolomeServiceHandler {
        id: blockUserHandler
        function onMolomeServiceDataReceived(success, data)
        {
            reloadCommentList();
        }
        function onMolomeServiceError(statusCode, message)
        {
        }
    }

    /* Delete Comment */
    MolomeServiceHandler {
        id: deleteCommentHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.createInformationDialog(photoViewScreen, "", "Comment Deleted");
                globalServices.emitCommentDeleted(processingCommentId);
                photoViewScreen.comment_count -= 1;
                globalServices.emitSetLovedCommentedData(photoViewScreen.pictureInfo.picture_id, photoViewScreen.love_count, photoViewScreen.done_love, photoViewScreen.comment_count, false);
            }
            else
                CreateComponent.createInformationDialog(photoViewScreen, "", ret.reason);
            timerDestroyLoadingDialog.start();
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(photoViewScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function deleteComment(commentId) {
        var confirmDialog = CreateComponent.createConfirmationDialog("../", photoViewScreen, "Are you sure to delete this comment");
        confirmDialog.clicked.connect(
            function() {
                loadingDialog = CreateComponent.createLoadingDialog(photoViewScreen,"Deleting Comment ....");
                loadingDialog.clicked.connect(
                    function() {
                        molomeServiceController.cancelTransactionByTransactionID(photoViewScreen.deleteCommentTransactionId);
                    }
                );
                photoViewScreen.processingCommentId = commentId
                photoViewScreen.deleteCommentTransactionId = molomeServiceController.deleteComment(commentId, deleteCommentHandler);
            }
        );
    }

    /* Comment List */
    MolomeServiceHandler {
        id: commentListLoadingHandler
        function onMolomeServiceDataReceived(success, data)
        {
            commentListTransactionId = 0;
            var parseSuccess = commentListModel.parseJSON(data);
            if (parseSuccess)
            {
                if (commentListModel.getLoveCountFromStats() !== photoViewScreen.love_count
                        || commentListModel.getCommentCountFromStats() !== photoViewScreen.comment_count
                        || commentListModel.getIsLoveFromStats() !== photoViewScreen.done_love)
                {
                    photoViewScreen.love_count = commentListModel.getLoveCountFromStats()
                    photoViewScreen.comment_count = commentListModel.getCommentCountFromStats()
                    if (!photoViewScreen.forceLoveStatus)
                        photoViewScreen.done_love = commentListModel.getIsLoveFromStats()
                    globalServices.emitSetLovedCommentedData(photoViewScreen.pictureInfo.picture_id, photoViewScreen.love_count, photoViewScreen.done_love, photoViewScreen.comment_count, false);
                }
                if (!commentListModel.getHasMore())
                    photoViewListView.isLoadMoreVisible = false;
            }
            else
            {
                if (commentListModel.getErrorCode() === 22)
                {
                    photoViewListView.isLoadMoreVisible = false;
                }
            }

            photoViewListView.text = "Load More";
            photoViewListView.isLoading = false;
        }
        function onMolomeServiceError(statusCode, message)
        {
            commentListTransactionId = 0;
            photoViewListView.text = "Load More";
            photoViewListView.isLoading = false;
        }
    }

    function reloadCommentList() {
        if (photoViewListView.isLoading)
            return;

        photoViewListView.text = "Loading...";
        photoViewListView.isLoading = true;
        photoViewListView.isLoadMoreVisible = true;

        commentListModel.clear();

        commentListTransactionId = molomeServiceController.getCommentList(photoViewScreen.pictureInfo.picture_id, 0, commentPerPage, 0, 0, commentListLoadingHandler);
    }

    function loadMoreCommentList() {
        if (photoViewListView.isLoading)
            return;

        photoViewListView.text = "Loading...";
        photoViewListView.isLoading = true;
        photoViewListView.isLoadMoreVisible = true;

        var oldestCommentId = commentListModel.getOldestId();

        commentListTransactionId = molomeServiceController.getCommentList(photoViewScreen.pictureInfo.picture_id, 0, commentPerPage, 0, oldestCommentId, commentListLoadingHandler);
    }

    /* Sharing */


    /* Flags for Review */
    MolomeServiceHandler {
        id: flagForReviewLoadingHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                photoViewScreen.flagForreviewDialog.destroyDialog();
                CreateComponent.createInformationDialog(photoViewScreen, "", "Picture Flagged!");
            }
            timerDestroyLoadingDialog.start();
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(photoViewScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function showFlagsForReviewDialog() {
        photoViewScreen.flagForreviewDialog = CreateComponent.createTextDialog("../", photoViewScreen);
        photoViewScreen.flagForreviewDialog.caption = "Reason:"
        photoViewScreen.flagForreviewDialog.headerText = "Flag for review"
        photoViewScreen.flagForreviewDialog.clicked.connect(
            function (text) {
                loadingDialog = CreateComponent.createLoadingDialog(photoViewScreen, "Flagging ....");
                loadingDialog.clicked.connect(
                    function() {
                        molomeServiceController.cancelTransactionByTransactionID(photoViewScreen.flagForReviewTransactionId);
                    }
                );
                photoViewScreen.flagForReviewTransactionId = molomeServiceController.flagPicture(photoViewScreen.pictureInfo.picture_id, text, flagForReviewLoadingHandler)
            }
        );
    }

    /* Make Profile Picture */
    MolomeServiceHandler {
        id: makeProfilePictureHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                photoViewScreen.profile_picture_code = photoViewScreen.picture_code
                CreateComponent.createInformationDialog(photoViewScreen, "", "Your profile picture is now changed");
            }
            else
                CreateComponent.createInformationDialog(photoViewScreen, "", ret.reason);
            timerDestroyLoadingDialog.start();
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(photoViewScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function makeProfilePicture() {
        var confirmDialog = CreateComponent.createConfirmationDialog("../", photoViewScreen, "Make this photo as your profile picture?");
        confirmDialog.clicked.connect(
            function () {
                loadingDialog = CreateComponent.createLoadingDialog(photoViewScreen, "Setting Profile Picture ....");
                loadingDialog.clicked.connect(
                    function() {
                        molomeServiceController.cancelTransactionByTransactionID(photoViewScreen.makeProfilePictureTransactionId);
                    }
                );
                photoViewScreen.makeProfilePictureTransactionId = molomeServiceController.makeProfilePicture(photoViewScreen.picture_code, makeProfilePictureHandler);
            }
        );
    }

    /* Read Ads */
    function readMore() {
        Qt.openUrlExternally(ads_url);
    }

    Component.onCompleted: {
        //checkIsPortrait();
        globalServices.setLovedCommentedData.connect(photoViewScreen.onLovedCommentedDataSet);
        globalServices.facebookLoggedInStatusChanged.connect(onFacebookLoggedInStatusChanged);
        globalServices.twitterLoggedInStatusChanged.connect(onTwitterLoggedInStatusChanged);
        globalServices.tumblrLoggedInStatusChanged.connect(onTumblrLoggedInStatusChanged);
        globalServices.weiboLoggedInStatusChanged.connect(onWeiboLoggedInStatusChanged);
        globalServices.flickrLoggedInStatusChanged.connect(onFlickrLoggedInStatusChanged);
        globalServices.vkLoggedInStatusChanged.connect(onVkLoggedInStatusChanged);
        globalServices.dropBoxLoggedInStatusChanged.connect(onDropBoxLoggedInStatusChanged);
        globalServices.gDriveLoggedInStatusChanged.connect(onGDriveLoggedInStatusChanged);
        globalServices.picasaLoggedInStatusChanged.connect(onPicasaLoggedInStatusChanged);
        globalServices.commentDeleted.connect(onCommentDeleted);
        globalServices.imageCaptionChanged.connect(onImageCaptionChanged);
    }

    Component.onDestruction: {
        molomeServiceController.cancelTransactionByTransactionID(commentListTransactionId);
        molomeServiceController.cancelTransactionByTransactionID(commentPostTransactionId);
        globalServices.setLovedCommentedData.disconnect(photoViewScreen.onLovedCommentedDataSet);
        globalServices.facebookLoggedInStatusChanged.disconnect(onFacebookLoggedInStatusChanged);
        globalServices.twitterLoggedInStatusChanged.disconnect(onTwitterLoggedInStatusChanged);
        globalServices.tumblrLoggedInStatusChanged.disconnect(onTumblrLoggedInStatusChanged);
        globalServices.weiboLoggedInStatusChanged.disconnect(onWeiboLoggedInStatusChanged);
        globalServices.flickrLoggedInStatusChanged.disconnect(onFlickrLoggedInStatusChanged);
        globalServices.vkLoggedInStatusChanged.disconnect(onVkLoggedInStatusChanged);
        globalServices.dropBoxLoggedInStatusChanged.disconnect(onDropBoxLoggedInStatusChanged);
        globalServices.gDriveLoggedInStatusChanged.disconnect(onGDriveLoggedInStatusChanged);
        globalServices.picasaLoggedInStatusChanged.disconnect(onPicasaLoggedInStatusChanged);
        globalServices.commentDeleted.disconnect(onCommentDeleted);
        globalServices.imageCaptionChanged.disconnect(onImageCaptionChanged);
    }

    function onFacebookLoggedInStatusChanged(isLoggedIn) {
        photoViewScreen.facebookLoggedIn = isLoggedIn;
    }

    function onTwitterLoggedInStatusChanged(isLoggedIn) {
        photoViewScreen.twitterLoggedIn = isLoggedIn;
    }

    function onTumblrLoggedInStatusChanged(isLoggedIn) {
        photoViewScreen.tumblrLoggedIn = isLoggedIn;
    }

    function onWeiboLoggedInStatusChanged(isLoggedIn) {
        photoViewScreen.weiboLoggedIn = isLoggedIn;
    }

    function onFlickrLoggedInStatusChanged(isLoggedIn) {
        photoViewScreen.flickrLoggedIn = isLoggedIn;
    }

    function onVkLoggedInStatusChanged(isLoggedIn) {
        photoViewScreen.vkLoggedIn = isLoggedIn;
    }

    function onDropBoxLoggedInStatusChanged(isLoggedIn) {
        photoViewScreen.dropBoxLoggedIn = isLoggedIn;
    }

    function onGDriveLoggedInStatusChanged(isLoggedIn) {
        photoViewScreen.gDriveLoggedIn = isLoggedIn;
    }

    function onPicasaLoggedInStatusChanged(isLoggedIn) {
        photoViewScreen.picasaLoggedIn = isLoggedIn;
    }

    function onLovedCommentedDataSet(picture_id, love_count, done_love, comment_count, done_comment)
    {
        if (picture_id === photoViewScreen.pictureInfo.picture_id)
        {
            photoViewScreen.love_count = love_count;
            photoViewScreen.done_love = done_love;
            photoViewScreen.comment_count = comment_count;
            if (photoViewScreen.comment_count !== comment_count)
                if (comment_count > photoViewScreen.comment_count)
                    reloadCommentList();
        }
    }

    function onCommentDeleted(commentId) {
        var contentY = photoViewListView.contentY
        commentListModel.deleteComment(commentId);
        photoViewListView.contentY = contentY
    }

    function onImageCaptionChanged(picture_id, caption) {
        if (photoViewScreen.pictureInfo.picture_id === picture_id)
            photoViewScreen.picture_name = caption;
    }

    function goToTop() {
        photoViewListView.positionViewAtBeginning()
    }
}
