import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../../util/common.js" as Common
import "../../util/oauth/oauth.js" as OAuthJS
import "../js/createComponent.js" as CreateComponent
import "../../platforms"

PageWrapper {
    id: picasaScreen
    width: themeManager.screenWidth
    height: themeManager.screenHeight
    orientationLock: themeManager.pageOrientationPortrait

    property string picasa_auth_code

    property variant dialog: null
    property int transactionId

    Header {
        id: header
        anchors.top: parent.top
        hasBack: true
        onBackClicked: pageStack.pop();
    }
    Flickable {
        id: picasaBox
        width: parent.width
        height: parent.height - header.height
        contentWidth: picasa.contentsSize.width
        contentHeight: picasa.contentsSize.height
        interactive: true
        clip: true
        anchors.top: header.bottom
        flickableDirection: Flickable.HorizontalAndVerticalFlick

        Picasa {
            id: picasa
            //tw_oauth_token: oauth_token
            preferredHeight: picasaBox.height
            preferredWidth: picasaBox.width
            onCodeChanged: whenUserIsAuthenticated(picasa.code);

            LoadingImage {
                id: loadingImage
                anchors.fill: parent
                anchors.centerIn: parent
            }

            Component.onCompleted: {
                nami.clearCookies();
                picasa.startAuthorize();
            }

            onLoadStarted: loadingImage.visible = true;
            onLoadFinished: loadingImage.visible = false;
        }
    }

    //Component.onCompleted: picasa.startAuthorize();

    MolomeServiceHandler {
        id: picasaLinkHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(picasaScreen.dialog.getPageId(), 0);
                globalServices.emitPicasaLoggedInStatusChanged(true);
                userManager.setPicasaAvailibility(true);
                var informationDialog = CreateComponent.createInformationDialog(picasaScreen, "", "Linked to Picasa!");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(picasaScreen, "", ret.reason);
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(picasaScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    function whenUserIsAuthenticated(auth_code) {
        picasaScreen.picasa_auth_code = auth_code

        picasaScreen.dialog = CreateComponent.createLoadingDialog(picasaScreen, "Linking to Picasa ....");
        picasaScreen.dialog.clicked.connect(
            function() {
                molomeServiceController.cancelTransactionByTransactionID(picasaScreen.transactionId);
                pageStack.pop();
            }
        );
        picasaScreen.transactionId = molomeServiceController.linkPicasa(picasaScreen.picasa_auth_code, picasaLinkHandler);
    }
}
