import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../js/createComponent.js" as CreateComponent
import "../../util/constant.js" as Constant
import "../js/storage.js" as Storage
import "../../platforms"

PageWrapper {
    id: profileSettingScreen
    width: themeManager.screenWidth
    height: themeManager.screenHeight
    orientationLock: themeManager.pageOrientationPortrait

    property string username: userManager.getUsername()
    property string bio: userManager.getBio()
    property string email: userManager.getEmail()
    property int updateBasicProfileTransactionId
    property int changePasswordTransactionId

    property variant loadingDialog: null
    property variant changePasswordDialog: null
    property string processingEmail
    property string processingBio
    property bool processingProtected

    property bool protectedChangeAccessLevel: false

    Header {
        id: header
        hasBack: true
        anchors.top: parent.top
        z: 1
        onBackClicked: pageStack.pop();
    }

    HeaderBar {
        id: headerCaption
        anchors.top: header.bottom
        text: qsTr("Profile Setting")
        z: 1
    }

    Flickable {
        id: flickable
        width: parent.width
        contentWidth: parent.width
        contentHeight: profileSettingScreenItem.height //<< childId
        anchors.top: headerCaption.bottom
        anchors.bottom: parent.bottom
        interactive: true
        Item {
            id: profileSettingScreenItem
            width: themeManager.screenWidth
            height: childrenRect.height
            Item10 {
                id: headerBox
                anchors.top: parent.top
            }
            Text {
                id: txtUsername
                anchors.top: headerBox.bottom
                anchors.left: parent.left
                anchors.leftMargin: themeManager.bigPadding
                text: "Name : " + profileSettingScreen.username
                font.bold: true
                font.pixelSize: themeManager.mediumProfileSetiingFontSize
            }
            Item10 {
                id: betweenTxtUsernameAndTxtUrlProfilebox
                anchors.top: txtUsername.bottom
            }
            Text {
                id: txtUrlProfile
                anchors.top: betweenTxtUsernameAndTxtUrlProfilebox.bottom
                x: themeManager.publicUrlX
                text: "Your Public Profile : http://molo.me/"+profileSettingScreen.username
                font.pixelSize: themeManager.smallProfileSettingFontSize
            }
            Item10 {
                id: betweenTxtUrlProfileAndTxtEmail
                anchors.top: txtUrlProfile.bottom
            }
            Text {
                id: txtEmail
                anchors.left: parent.left
                anchors.leftMargin: themeManager.bigPadding
                anchors.top: betweenTxtUrlProfileAndTxtEmail.bottom
                text: qsTr("Email :")
                font.pixelSize: themeManager.bigProfileSettingFontSize
            }
            Item10 {
                id: betweenTxtEmailAndTxtEditEmail
                anchors.top: txtEmail.bottom
            }
            GroupTextEdit {
                id: txtEditEmail
                isMultiLine: false
                anchors.top: betweenTxtEmailAndTxtEditEmail.bottom
                anchors.left: parent.left
                anchors.leftMargin: themeManager.bigPadding
                anchors.right: parent.right
                anchors.rightMargin: themeManager.bigPadding
                text: profileSettingScreen.email
            }
            Item10 {
                id: betweenTxtEditEmailAndTxtBio
                anchors.top: txtEditEmail.bottom
            }
            Text {
                id: txtBio
                anchors.left: parent.left
                anchors.leftMargin: themeManager.bigPadding
                anchors.top: betweenTxtEditEmailAndTxtBio.bottom
                text: qsTr("Bio :")
                font.pixelSize: themeManager.bigProfileSettingFontSize
            }
            Item10 {
                id: betweenTxtBioAndTxtEditBio
                anchors.top: txtBio.bottom
            }
            GroupTextEdit {
                id: txtEditBio
                isMultiLine: true
                anchors.left: parent.left
                anchors.leftMargin: themeManager.bigPadding
                anchors.right: parent.right
                anchors.rightMargin: themeManager.bigPadding
                anchors.top: betweenTxtBioAndTxtEditBio.bottom
                text: profileSettingScreen.bio
            }
            Item10  {
                id: betweenTxtEditBioAndPrivacyOptions
                anchors.top: txtEditBio.bottom
                height: themeManager.tenPadding * 2
            }
            RadioButton {
                id: privacyOptionsCheck
                anchors.left: parent.left
                anchors.leftMargin: themeManager.bigPadding
                anchors.right: parent.right
                anchors.rightMargin: themeManager.bigPadding
                anchors.top: betweenTxtEditBioAndPrivacyOptions.bottom
                bitmap: "../res/dialog_checkbox_normal.png"
                bitmap_pressed: "../res/dialog_checkbox_checked.png"
                bitmap_selected: "../res/dialog_checkbox_checked.png"
                text: qsTr("Protect account")
                textColor: "#808080"
                selected: userManager.getProtected()
                onClicked: {
                    privacyOptionsCheck.selected = !privacyOptionsCheck.selected
                    if (privacyOptionsCheck.selected && !userManager.getProtected())
                    {
                        var informationDialog = CreateComponent.createInformationDialog(profileSettingScreen, "", "Protecting your profile will cause the following:\n\n1) People except follower will not able to see your photo list\n2) Your 'public' photo will still be visible to public\n3) If anyone want to follow you, you must accept the friend request first");
                        informationDialog.horizontalAlignmentMode = Text.AlignLeft
                        informationDialog.fontSizeMode = 0
                        informationDialog.clicked.connect(
                            function() {
                                protectedChangeAccessLevel = false;
                                var dialog = CreateComponent.createConfirmationDialog("../", profileSettingScreen, "Do you want to change the visibility of your 'public' photos to 'only follower'?");
                                dialog.clicked.connect(
                                    function() {
                                        protectedChangeAccessLevel = true;
                                    }
                                );
                            }
                        );
                    }
                    else if (!privacyOptionsCheck.selected && userManager.getProtected())
                    {
                        protectedChangeAccessLevel = false;
                        var dialog = CreateComponent.createConfirmationDialog("../", profileSettingScreen, "Do you want to change the visibility of your 'only follower' photos to 'public'?");
                        dialog.clicked.connect(
                            function() {
                                protectedChangeAccessLevel = true;
                            }
                        );
                    }

                    //passwordTextBox.mode = btnCheck.selected === true ? TextInput.Normal : TextInput.Password
                    //confirmPasswordTextBox.mode = btnCheck.selected === true ? TextInput.Normal : TextInput.Password
                }
            }
            Item10  {
                id: betweenTxtEditBioAndBtnOk
                anchors.top: privacyOptionsCheck.bottom
                height: themeManager.tenPadding * 2
            }
            MediumButton {
                id: btnOK
                text: "OK"
                anchors.top: betweenTxtEditBioAndBtnOk.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                property variant loadingDialog
                onClicked: {
                    if (userManager.getEmail() === txtEditEmail.getTextEdit().text  && userManager.getBio() === txtEditBio.getTextEdit().text && userManager.getProtected() === privacyOptionsCheck.selected)
                        pageStack.pop();
                    else
                        changedUpdateBasicProfile(txtEditEmail.getTextEdit().text,txtEditBio.getTextEdit().text,privacyOptionsCheck.selected);
                }
            }
            Item10  {
                id: betweenBtnOkAndPasswordCaption
                anchors.top: btnOK.bottom
            }
            SettingsCaption {
                id: passwordCaption
                text: "Password"
                anchors.top: betweenBtnOkAndPasswordCaption.bottom
            }
            SettingsItem {
                id: changePasswordSettingList
                text: "Change Password"
                isLast: true
                anchors.left:  parent.left
                anchors.right: parent.right
                anchors.top: passwordCaption.bottom
                onClicked: showChangePasswordDialog();
            }
            Item10  {
                id: betweenChangePasswordSettingListAndBtnSignOut
                anchors.top: changePasswordSettingList.bottom
            }
            MediumButton {
                id: btnSignOut
                color: Constant.COLOR_GRAY
                text: "Sign Out"
                anchors.top: betweenChangePasswordSettingListAndBtnSignOut.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: logout();
            }
            Item10 {
                id: bottomBox
                anchors.top: btnSignOut.bottom
            }
        }

    }

    Timer {
        id: timerDestroyLoadingDialog
        repeat: false
        running: false
        triggeredOnStart: false
        interval: 10
        onTriggered: {
            if (loadingDialog)
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
        }
    }

    MolomeServiceHandler {
        id: changedUpdateBasicProfileHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                CreateComponent.createInformationDialog(profileSettingScreen, "", "Profile Updated");
                globalServices.emitBioChanged(userManager.getUserId(), processingBio);
                userManager.setProfileDetails(processingBio, processingEmail);
                userManager.setProtected(processingProtected);
                globalServices.emitUserProtectedChanged(userManager.getUserId(), processingProtected);
                globalServices.emitProfileRefreshRequested();
            }
            else
            {
                CreateComponent.createInformationDialog(profileSettingScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(profileSettingScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function changedUpdateBasicProfile(email, bio, is_protected) {
        loadingDialog = CreateComponent.createLoadingDialog(profileSettingScreen, "Updating Profile ....");
        loadingDialog.clicked.connect(
            function() {
                molomeServiceController.cancelTransactionByTransactionID(updateBasicProfileTransactionId);
            }
        );
        processingEmail = email
        processingBio = bio
        processingProtected = is_protected
        updateBasicProfileTransactionId = molomeServiceController.updateBasicProfile(email, bio, is_protected, protectedChangeAccessLevel, changedUpdateBasicProfileHandler);
    }

    MolomeServiceHandler {
        id: changePasswordHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                changePasswordDialog.destroy();
                CreateComponent.createInformationDialog(profileSettingScreen, "", "Password changed");
            }
            else
            {
                CreateComponent.createInformationDialog(profileSettingScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(profileSettingScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function showChangePasswordDialog() {
        changePasswordDialog = CreateComponent.createChangePasswordDialog("../",profileSettingScreen);
        changePasswordDialog.clicked.connect(
            function () {
                var currentPassword = changePasswordDialog.getCurrentPassword();
                var newPassword = changePasswordDialog.getNewPassword();
                var confirmNewPassword = changePasswordDialog.getConfirmNewPassword();
                if (currentPassword === "" || newPassword === "" || confirmNewPassword === "") {
                    CreateComponent.createInformationDialog(profileSettingScreen, "", "Please fill all required fields.");
                } else if (newPassword === confirmNewPassword) {
                    loadingDialog = CreateComponent.createLoadingDialog(profileSettingScreen, "Changing Password ....");
                    loadingDialog.z = 999;
                    loadingDialog.clicked.connect(
                        function() {
                            molomeServiceController.cancelTransactionByTransactionID(changePasswordTransactionId);
                        }
                    );
                    changePasswordTransactionId = molomeServiceController.changePassword(currentPassword, newPassword, changePasswordHandler);
                } else {
                    CreateComponent.createInformationDialog(profileSettingScreen,"","Password mismatched!");
                }
            }
        );
    }

    function logout() {
         var dialog = CreateComponent.createConfirmationDialog("../", profileSettingScreen, "Do you want to sign out?");
         dialog.clicked.connect(
            function() {
                CreateComponent.createLoadingDialog(profileSettingScreen, "Signing Out...");
                Storage.initialize();
                Storage.deleteDatabase();
                Storage.setData("notification_last_read_id", 0);
                commonCPP.clearCache();
                //getMolomeService().cancelAllTransactions();
                uploaderQueueModel.removeAllQueues();
                timelineModel.clear();
                popularModel.clear();
                notificationModel.clear();
                userManager.logout();
                pageStack.clear();
                pageStack.push(Qt.resolvedUrl("WelcomeScreen.qml"))
            }
        );
    }
}
