import QtQuick 1.0
import "../UIComponents"
import "../js/createComponent.js" as CreateComponent
import "../../platforms"
import "../js/storage.js" as Storage

PageWrapper {
    id: settingScreen
    property int storageIndex: storageDriveIndex
    property int imageResolution: finalImageResolution
    property bool isAutoReFreshOn: isAutoRefreshOn
    property int timeInterval: autoRefreshTime/(60000)
    property string dateTime: settingScreen.timeInterval == 60 ? " Hours":" mins"
    width: themeManager.screenWidth
    height: themeManager.screenHeight

    orientationLock: themeManager.pageOrientationPortrait

    Header {
        id: header
        hasBack: true
        anchors.top: parent.top
        onBackClicked: {
            pageStack.pop();
        }
    }

    HeaderBar {
        id: headerCaption
        anchors.top: header.bottom
        text: qsTr("Setting")
    }

    Flickable {
        id: flickable
        width: parent.width
        contentWidth: parent.width
        contentHeight: settingScreenItem.height
        anchors.top: headerCaption.bottom
        anchors.bottom: parent.bottom
        interactive: true
        clip: true
        Item {
            id: settingScreenItem
            width: themeManager.screenWidth
            height: childrenRect.height
            Item10 {
                id: headerBox
                anchors.top: parent.top
            }
            SettingsCaption {
                id: autoRefreshCaption
                anchors.top: headerBox.bottom
                text: "Auto Refresh"
            }
            SettingListItemData {
                id: autoRefreshListItem
                anchors.top: autoRefreshCaption.bottom
                text: "Auto Refresh"
                isLast: false
                fieldData: settingScreen.isAutoReFreshOn == true ? "ON":"OFF"
                onClicked: {
                    if (settingScreen.isAutoReFreshOn == true) {
                        autoRefreshOff();
                        Storage.setData("isAutoRefreshOn","0");
                        settingScreen.isAutoReFreshOn = false
                        isAutoRefreshOn = false;
                    }else{
                        settingScreen.isAutoReFreshOn = true
                        autoRefreshOn();
                        Storage.setData("isAutoRefreshOn","1");
                        isAutoRefreshOn = true;
                    }
                }
            }
            SettingListItemData {
                id: interval
                anchors.top: autoRefreshListItem.bottom
                isLast: true
                text: "Interval"
                fieldData: (settingScreen.timeInterval == 60 ? 1 : settingScreen.timeInterval) + settingScreen.dateTime
                onClicked: {
                    var sprite = CreateComponent.createChooseIntervalDiadlog("../");
                    sprite.selected.connect(
                        function(id) {
                            settingScreen.timeInterval = id;
                            changeAutoReFresh(id);
                            Storage.setData("timeInterval",id);
                        }
                    );
                }
            }
            SettingsCaption {
                id: advanceCaption
                anchors.top: interval.bottom
                text: "Advance"
            }
            SettingListItemData {
                id: imageResolution
                anchors.top: advanceCaption.bottom
                isLast: false
                text: "Image Resolution"
                fieldData: finalImageResolution === 600 ? "600x600" : "800x800"
                onClicked: {
                    var chooseImageResolutionDialog = CreateComponent.createChooseImageResolutionDialog(settingScreen);
                    chooseImageResolutionDialog.clicked.connect(
                        function (id)
                        {
                            finalImageResolution = id;
                            filter.setFinalImageResolution(finalImageResolution)
                            Storage.setData("finalImageResolution",id);
                        }
                    );
                }
            }
            SettingListItemData {
                id: storage
                anchors.top: imageResolution.bottom
                isLast: false
                text: "Storage"
                visible: themeManager.platform === "meego" ? false : true
                onClicked: {
                    var chooseStorageDialog = CreateComponent.createChooseStorageDialog(settingScreen);
                    chooseStorageDialog.clicked.connect(
                        function (id)
                        {
                            settingScreen.storageIndex = id;
                            fromWhrerChange(id);
                            Storage.setData("storageDriveIndex",id);
                            refreshStorageValue()
                        }
                    );
                }
                Component.onCompleted: {
                    refreshStorageValue()
                }
            }
            SettingListItemData {
                id: clearcache
                anchors.top: storage.bottom
                isLast: true
                text: "Clear Cache"
                fieldData: ""
                onClicked: {
                    var confirmationDialog = CreateComponent.createConfirmationDialog("../",settingScreen,"Clear All Cache?");
                    confirmationDialog.clicked.connect(
                        function ()
                        {
                            commonCPP.clearCache();
                            globalServices.emitClearTimelineRequested();
                            CreateComponent.createInformationDialog(settingScreen,"","All caches cleared.");
                        }
                    );
                }
            }
        }
    }

    function refreshStorageValue() {
        if (storageManager.isMemoryCardAvailable() === true){
            if(settingScreen.storageIndex == 0){
                storage.fieldData = "Phone's Memory";
            } else if (settingScreen.storageIndex == 1){
                storage.fieldData = "Memory Card";
            }
        } else {
            storage.fieldData = "Phone's Memory";
        }
    }
}

