import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../js/createComponent.js" as CreateComponent
import "../../util/common.js" as Common
import "../../platforms"

PageWrapper {
    id: shareScreen
    width: parent.width
    height: parent.height
    property string filterName: ""
    property int filterId: 0
    property int accessLevel: 0
    property variant darkAreas: null
    property bool twitterShare: false
    property bool facebookShare: false
    property bool tumblrShare: false
    property bool flickrShare: false
    property bool weiboShare: false
    property bool vkShare: false
    property bool dropBoxShare: false
    property bool gDriveShare: false
    property bool picasaShare: false
    property string filepathLarge:""

    orientationLock: themeManager.pageOrientationPortrait

    MouseArea {
        anchors.fill: parent
    }

    Header {
        id: header
        hasBack: true
        anchors.top: parent.top
        onBackClicked: {
            pageStack.pop();
        }
        MouseArea {
            id: goToTopHitBox
            anchors.fill: parent
            onClicked: {
                goToTop();
            }
        }
    }

    HeaderBar {
        id: headerCaption
        anchors.top: header.bottom
        text: qsTr("Share")
    }
    Flickable {
        id: flickable
        anchors.top: headerCaption.bottom
        clip: true
        width: parent.width
        height: parent.height - (header.height + headerCaption.height + btnShare.height)
        contentWidth: parent.width
        contentHeight: shareScreenArea.height
        Item {
            id: shareScreenArea
            width: parent.width
            height: childrenRect.height
            anchors.top: parent.top
            SettingsCaption {
                id: captionText
                text: "Caption"
                anchors.top: parent.top
            }
            Item10 {
                id: betweenCaptionTextAndCaptionBox
                anchors.top: captionText.bottom
            }
            GroupTextEdit {
                id: caption
                anchors.top: betweenCaptionTextAndCaptionBox.bottom
                isMultiLine: true
                anchors.right: parent.right
                anchors.rightMargin: themeManager.bigPadding
                anchors.left: parent.left
                anchors.leftMargin: themeManager.bigPadding
            }
            Item10 {
                id: betweenCaptionBoxAndShareCaption
                anchors.top: caption.bottom
            }
            SettingsCaption {
                id: shareText
                text: "Share"
                anchors.top: betweenCaptionBoxAndShareCaption.bottom
            }
            Item10 {
                id: betweenShareTextAndHeaderShareBox
                anchors.top: shareText.bottom
            }
            Image {
                id: headerShareBox
                width: parent.width
                anchors.right: parent.right
                anchors.rightMargin: themeManager.bigPadding
                anchors.left: parent.left
                anchors.leftMargin: themeManager.bigPadding
                anchors.top: betweenShareTextAndHeaderShareBox.bottom
                source: "../res/groupbox_top_bg.png"
            }
            Image {
                id: bodyShareBox
                anchors.top: headerShareBox.bottom
                width: parent.width
                anchors.right: parent.right
                anchors.rightMargin: themeManager.bigPadding
                anchors.left: parent.left
                anchors.leftMargin: themeManager.bigPadding
                source:  "../res/groupbox_body_bg.png"
                height: childrenRect.height - topBodyShareBox.height
                Item10{
                    id: topBodyShareBox
                    anchors.top: parent.top
                }
                ShareItem {
                    id: twitter
                    text: "Twitter"
                    isLoggedIn: userManager.isTwitterAvailable();
                    anchors.top: topBodyShareBox.bottom
                    onShareOnClicked: shareScreen.twitterShare = shareStatus;
                    onSignInClicked: logInTwitter();
                }
                ShareItem {
                    id: facebook
                    text: "Facebook"
                    isLoggedIn: userManager.isFacebookAvailable();
                    anchors.top: twitter.bottom
                    onShareOnClicked: shareScreen.facebookShare = shareStatus;
                    onSignInClicked: logInFacebook();
                }
                ShareItem {
                    id: tumblr
                    text: "Tumblr"
                    isLoggedIn: userManager.isTumblrAvailable();
                    anchors.top: facebook.bottom
                    onShareOnClicked: shareScreen.tumblrShare = shareStatus;
                    onSignInClicked: logInTumblr();
                }
                ShareItem {
                    id: flickr
                    text: "Flickr"
                    isLoggedIn: userManager.isFlickrAvailable();
                    anchors.top: tumblr.bottom
                    onShareOnClicked: shareScreen.flickrShare = shareStatus;
                    onSignInClicked: logInFlickr();
                }
                ShareItem {
                    id: picasa
                    text: "Picasa"
                    isLoggedIn: userManager.isPicasaAvailable();
                    anchors.top: flickr.bottom
                    onShareOnClicked: shareScreen.picasaShare = shareStatus;
                    onSignInClicked: logInPicasa();
                }
                ShareItem {
                    id: weibo
                    visible: false
                    height: 0
                    text: "Weibo"
                    isLoggedIn: userManager.isWeiboAvailable();
                    anchors.top: picasa.bottom
                    onShareOnClicked: shareScreen.weiboShare = shareStatus;
                    onSignInClicked: logInWeibo();
                }
                ShareItem {
                    id: vk
                    text: "VK"
                    isLoggedIn: userManager.isVkAvailable();
                    anchors.top: weibo.bottom
                    onShareOnClicked: shareScreen.vkShare = shareStatus;
                    onSignInClicked: logInVk();
                }
                ShareItem {
                    id: dropBox
                    text: "Dropbox"
                    isLoggedIn: userManager.isDropBoxAvailable();
                    anchors.top: vk.bottom
                    onShareOnClicked: shareScreen.dropBoxShare = shareStatus;
                    onSignInClicked: logInDropBox();
                }
                ShareItem {
                    id: gDrive
                    text: "Google Drive"
                    isLoggedIn: userManager.isGDriveAvailable();
                    anchors.top: dropBox.bottom
                    onShareOnClicked: shareScreen.gDriveShare = shareStatus;
                    onSignInClicked: logInGDrive();
                }
            }
            Image {
                id: bottomShareBox
                width: parent.width
                anchors.right: parent.right
                anchors.rightMargin: themeManager.bigPadding
                anchors.left: parent.left
                anchors.leftMargin: themeManager.bigPadding
                anchors.top: bodyShareBox.bottom
                source:  "../res/groupbox_bottom_bg.png"
            }
            Item10 {
                id: spaceBetweenShareAndPrivacyLevel
                anchors.top: bottomShareBox.bottom
            }
            SettingsCaption {
                id: privacyLevelText
                text: "Privacy"
                anchors.top: spaceBetweenShareAndPrivacyLevel.bottom
            }
            SettingListItemData {
                id: privacyLevel
                anchors.top: privacyLevelText.bottom
                isLast: true
                text: "Who can see this"
                fieldData: "Anyone"
                onClicked: {
                    var sprite = CreateComponent.createChooseAccessLevelDiadlog("../", shareScreen);
                    sprite.selected.connect(
                        function(id) {
                            shareScreen.accessLevel = id;
                            switch (id)
                            {
                            case 0:
                                privacyLevel.fieldData = "Anyone";
                                break;
                            case 1:
                                privacyLevel.fieldData = "Follower";
                                break;
                            case 2:
                                privacyLevel.fieldData = "Only Me";
                                break;
                            }
                        }
                    );
                }
            }
            Item10 {
                id: bottomBox
                anchors.top: privacyLevel.bottom
            }
        }
    }

    BigFooterButton {
        id: btnShare
        anchors.bottom: parent.bottom
        text: "Share"
        onClicked: {
            globalServices.emitGoToTimelineTab();
            pageStack.pop(shareScreen,true);
            pageStack.pop();
            shareImage(shareScreen.filepathLarge);
        }
    }
    Component.onCompleted: {
        globalServices.facebookLoggedInStatusChanged.connect(onFacebookLoggedInStatusChanged);
        globalServices.twitterLoggedInStatusChanged.connect(onTwitterLoggedInStatusChanged);
        globalServices.tumblrLoggedInStatusChanged.connect(onTumblrLoggedInStatusChanged);
        globalServices.weiboLoggedInStatusChanged.connect(onWeiboLoggedInStatusChanged);
        globalServices.flickrLoggedInStatusChanged.connect(onFlickrLoggedInStatusChanged);
        globalServices.vkLoggedInStatusChanged.connect(onVkLoggedInStatusChanged);
        globalServices.dropBoxLoggedInStatusChanged.connect(onDropBoxLoggedInStatusChanged);
        globalServices.gDriveLoggedInStatusChanged.connect(onGDriveLoggedInStatusChanged);
        globalServices.picasaLoggedInStatusChanged.connect(onPicasaLoggedInStatusChanged);

        if (isChina)
        {
            facebook.visible = false
            twitter.visible = false
            facebook.height = 0
            twitter.height = 0
        }
    }
    Component.onDestruction: {
        globalServices.facebookLoggedInStatusChanged.disconnect(onFacebookLoggedInStatusChanged);
        globalServices.twitterLoggedInStatusChanged.disconnect(onTwitterLoggedInStatusChanged);
        globalServices.tumblrLoggedInStatusChanged.disconnect(onTumblrLoggedInStatusChanged);
        globalServices.weiboLoggedInStatusChanged.disconnect(onWeiboLoggedInStatusChanged);
        globalServices.flickrLoggedInStatusChanged.disconnect(onFlickrLoggedInStatusChanged);
        globalServices.vkLoggedInStatusChanged.disconnect(onVkLoggedInStatusChanged);
        globalServices.dropBoxLoggedInStatusChanged.disconnect(onDropBoxLoggedInStatusChanged);
        globalServices.gDriveLoggedInStatusChanged.disconnect(onGDriveLoggedInStatusChanged);
        globalServices.picasaLoggedInStatusChanged.disconnect(onPicasaLoggedInStatusChanged);
    }

    function onFacebookLoggedInStatusChanged(isLoggedIn){
        facebook.isLoggedIn = isLoggedIn;
    }
    function onTwitterLoggedInStatusChanged(isLoggedIn){
        twitter.isLoggedIn = isLoggedIn;
    }
    function onTumblrLoggedInStatusChanged(isLoggedIn){
        tumblr.isLoggedIn = isLoggedIn;
    }
    function onWeiboLoggedInStatusChanged(isLoggedIn){
        weibo.isLoggedIn = isLoggedIn;
    }
    function onFlickrLoggedInStatusChanged(isLoggedIn){
        flickr.isLoggedIn = isLoggedIn;
    }
    function onVkLoggedInStatusChanged(isLoggedIn){
        vk.isLoggedIn = isLoggedIn;
    }
    function onDropBoxLoggedInStatusChanged(isLoggedIn){
        dropBox.isLoggedIn = isLoggedIn;
    }
    function onGDriveLoggedInStatusChanged(isLoggedIn){
        gDrive.isLoggedIn = isLoggedIn;
    }
    function onPicasaLoggedInStatusChanged(isLoggedIn){
        picasa.isLoggedIn = isLoggedIn;
    }

    function logInFacebook() {
        pageStack.push(Qt.resolvedUrl("FaceBookScreen.qml"));
    }
    function logInTwitter() {
        pageStack.push(Qt.resolvedUrl("TwitterScreen.qml"));
    }
    function logInTumblr() {
        pageStack.push(Qt.resolvedUrl("TumblrScreen.qml"));
    }
    function logInFlickr() {
        pageStack.push(Qt.resolvedUrl("FlickrScreen.qml"));
    }
    function logInWeibo() {
        pageStack.push(Qt.resolvedUrl("WeiboScreen.qml"));
    }
    function logInVk() {
        pageStack.push(Qt.resolvedUrl("VKScreen.qml"));
    }
    function logInDropBox() {
        pageStack.push(Qt.resolvedUrl("DropBoxScreen.qml"));
    }
    function logInGDrive() {
        pageStack.push(Qt.resolvedUrl("GDriveScreen.qml"));
    }
    function logInPicasa() {
        pageStack.push(Qt.resolvedUrl("PicasaScreen.qml"));
    }

    function shareImage(path) {
        var imageInfo = {"imageName": caption.getTextEdit().text
                        ,"imageDescription":""
                        ,"geoLocationLat":0.0
                        ,"geoLocationLong":0.0
                        ,"effectFilterType":shareScreen.filterId
                        ,"imageSource":1
                        ,"shareToTwitter": shareScreen.twitterShare
                        ,"shareToFacebook": shareScreen.facebookShare
                        ,"shareToTumblr": shareScreen.tumblrShare
                        ,"shareToWeibo": shareScreen.weiboShare
                        ,"shareToFlickr": shareScreen.flickrShare
                        ,"shareToVk": shareScreen.vkShare
                        ,"shareToDropBox": shareScreen.dropBoxShare
                        ,"shareToGDrive": shareScreen.gDriveShare
                        ,"shareToPicasa": shareScreen.picasaShare
                        ,"accessLevel":shareScreen.accessLevel
                        };

        uploaderQueueModel.appendImageFileToQueue(path,imageInfo);
    }
    function goToTop() {
        flickable.contentY = 0;
    }
}

