import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../js/createComponent.js" as CreateComponent
import "../../util/common.js" as Common
import "../../platforms"

PageWrapper {
    id: socialNetworkSettingScreen
    property int transactionId
    property variant loadingDialog: null
    width: themeManager.screenWidth
    height: themeManager.screenHeight
    orientationLock: themeManager.pageOrientationPortrait

    MouseArea {
        id: screenHit
        anchors.fill: parent
        onClicked: {

        }
    }

    Header {
        id: header
        z: 1
        hasBack: true
        anchors.top: parent.top
        onBackClicked: {
            pageStack.pop();
        }
    }

    HeaderBar {
        id: headerCaption
        anchors.top: header.bottom
        text: "Social Network Settings"
        z: 1
    }

    Flickable {
        id: flickable
        width: parent.width
        contentWidth: parent.width
        contentHeight: bodyItem.height //<< childId
        anchors.top: headerCaption.bottom
        anchors.bottom: parent.bottom
        interactive: true

        Item {
            id: bodyItem
            width: themeManager.screenWidth
            height: childrenRect.height

            SettingsCaption {
                id: caption
                text: "Social Network"
            }
            SocialNetworkItem {
                id: facebook
                text: "Facebook"
                anchors.top: caption.bottom
                isLoggedIn: userManager.isFacebookAvailable();
                onClicked: {
                    if (facebook.isLoggedIn)
                        logoutFacebook();
                    else
                        logInFacebook();
                }
            }
            SocialNetworkItem {
                id: twitter
                anchors.top: facebook.bottom
                text: "Twitter"
                isLoggedIn: userManager.isTwitterAvailable();
                onClicked: {
                    if (twitter.isLoggedIn)
                        logoutTwitter();
                    else
                        logInTwitter();
                }
            }
            SocialNetworkItem {
                id: tumblr
                anchors.top: twitter.bottom
                text: "Tumblr"
                isLoggedIn: userManager.isTumblrAvailable();
                onClicked: {
                    if (tumblr.isLoggedIn)
                        logoutTumblr();
                    else
                        logInTumblr();
                }
            }
            SocialNetworkItem {
                id: flickr
                anchors.top: tumblr.bottom
                text: "Flickr"
                isLoggedIn: userManager.isFlickrAvailable();
                onClicked: {
                    if (flickr.isLoggedIn)
                        logoutFlickr();
                    else
                        logInFlickr();
                }
            }
            SocialNetworkItem {
                id: picasa
                anchors.top: flickr.bottom
                text: "Picasa"
                isLoggedIn: userManager.isPicasaAvailable();
                onClicked: {
                    if (picasa.isLoggedIn)
                        logoutPicasa();
                    else
                        logInPicasa();
                }
            }
            SocialNetworkItem {
                id: weibo
                visible: false
                height: 0
                anchors.top: picasa.bottom
                text: "Weibo"
                isLoggedIn: userManager.isWeiboAvailable();
                onClicked: {
                    if (weibo.isLoggedIn)
                        logoutWeibo();
                    else
                        logInWeibo();
                }
            }
            SocialNetworkItem {
                id: vk
                anchors.top: weibo.bottom
                text: "VK"
                isLoggedIn: userManager.isVkAvailable();
                onClicked: {
                    if (vk.isLoggedIn)
                        logoutVk();
                    else
                        logInVk();
                }
            }
            SocialNetworkItem {
                id: dropBox
                anchors.top: vk.bottom
                text: "Dropbox"
                isLoggedIn: userManager.isDropBoxAvailable();
                onClicked: {
                    if (dropBox.isLoggedIn)
                        logoutDropBox();
                    else
                        logInDropBox();
                }
            }
            SocialNetworkItem {
                id: gDrive
                anchors.top: dropBox.bottom
                text: "Google Drive"
                isLoggedIn: userManager.isGDriveAvailable();
                onClicked: {
                    if (gDrive.isLoggedIn)
                        logoutGDrive();
                    else
                        logInGDrive();
                }
            }
        }
    }
    Component.onCompleted: {
        globalServices.facebookLoggedInStatusChanged.connect(onFacebookLoggedInStatusChanged);
        globalServices.twitterLoggedInStatusChanged.connect(onTwitterLoggedInStatusChanged);
        globalServices.tumblrLoggedInStatusChanged.connect(onTumblrLoggedInStatusChanged);
        globalServices.weiboLoggedInStatusChanged.connect(onWeiboLoggedInStatusChanged);
        globalServices.flickrLoggedInStatusChanged.connect(onFlickrLoggedInStatusChanged);
        globalServices.vkLoggedInStatusChanged.connect(onVkLoggedInStatusChanged);
        globalServices.dropBoxLoggedInStatusChanged.connect(onDropBoxLoggedInStatusChanged);
        globalServices.gDriveLoggedInStatusChanged.connect(onGDriveLoggedInStatusChanged);
        globalServices.picasaLoggedInStatusChanged.connect(onPicasaLoggedInStatusChanged);

        if (isChina)
        {
            facebook.visible = false
            twitter.visible = false
            facebook.height = 0
            twitter.height = 0
        }
    }

    Component.onDestruction: {
        globalServices.facebookLoggedInStatusChanged.disconnect(onFacebookLoggedInStatusChanged);
        globalServices.twitterLoggedInStatusChanged.disconnect(onTwitterLoggedInStatusChanged);
        globalServices.tumblrLoggedInStatusChanged.disconnect(onTumblrLoggedInStatusChanged);
        globalServices.weiboLoggedInStatusChanged.disconnect(onWeiboLoggedInStatusChanged);
        globalServices.flickrLoggedInStatusChanged.disconnect(onFlickrLoggedInStatusChanged);
        globalServices.vkLoggedInStatusChanged.disconnect(onVkLoggedInStatusChanged);
        globalServices.dropBoxLoggedInStatusChanged.disconnect(onDropBoxLoggedInStatusChanged);
        globalServices.gDriveLoggedInStatusChanged.disconnect(onGDriveLoggedInStatusChanged);
        globalServices.picasaLoggedInStatusChanged.disconnect(onPicasaLoggedInStatusChanged);
    }

    Timer {
        id: timerDestroyLoadingDialog
        repeat: false
        running: false
        triggeredOnStart: false
        interval: 10
        onTriggered: {
            if (loadingDialog)
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
        }
    }

    function onFacebookLoggedInStatusChanged(isLoggedIn) {
        facebook.isLoggedIn = isLoggedIn;
    }

    function onTwitterLoggedInStatusChanged(isLoggedIn){
        twitter.isLoggedIn = isLoggedIn;
    }

    function onTumblrLoggedInStatusChanged(isLoggedIn) {
        tumblr.isLoggedIn = isLoggedIn;
    }

    function onWeiboLoggedInStatusChanged(isLoggedIn) {
        weibo.isLoggedIn = isLoggedIn;
    }

    function onFlickrLoggedInStatusChanged(isLoggedIn) {
        flickr.isLoggedIn = isLoggedIn;
    }

    function onVkLoggedInStatusChanged(isLoggedIn) {
        vk.isLoggedIn = isLoggedIn;
    }

    function onDropBoxLoggedInStatusChanged(isLoggedIn) {
        dropBox.isLoggedIn = isLoggedIn;
    }

    function onGDriveLoggedInStatusChanged(isLoggedIn) {
        gDrive.isLoggedIn = isLoggedIn;
    }

    function onPicasaLoggedInStatusChanged(isLoggedIn) {
        picasa.isLoggedIn = isLoggedIn;
    }

    function logInFacebook() {
        pageStack.push(Qt.resolvedUrl("FaceBookScreen.qml"));
    }

    MolomeServiceHandler {
        id: facebookLogoutHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                userManager.setFacebookAvailibility(false);
                globalServices.emitFacebookLoggedInStatusChanged(false);
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", "Unlinked to Facebook!");
            }
            else
            {
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function logoutFacebook() {
        var confirmationDialog = CreateComponent.createConfirmationDialog("../", socialNetworkSettingScreen, "Are you sure to unlink to Facebook?");
        confirmationDialog.clicked.connect(
            function() {
                loadingDialog = CreateComponent.createLoadingDialog(socialNetworkSettingScreen, "Unlinking ....");
                loadingDialog.clicked.connect(
                    function() {
                        molomeServiceController.cancelTransactionByTransactionID(socialNetworkSettingScreen.transactionId);
                    }
                );
                transactionId = molomeServiceController.updateFacebookProfile("", facebookLogoutHandler);
            }
        );
    }

    function logInTwitter() {
        pageStack.push(Qt.resolvedUrl("TwitterScreen.qml"));
    }

    MolomeServiceHandler {
        id: twitterLogoutHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                userManager.setTwitterAvailibility(false);
                globalServices.emitTwitterLoggedInStatusChanged(false);
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", "Unlinked to Twitter!");
            }
            else
            {
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function logoutTwitter() {
        var confirmationDialog = CreateComponent.createConfirmationDialog("../",socialNetworkSettingScreen,"Are you sure to unlink to Twitter?");
        confirmationDialog.clicked.connect(
            function() {
                loadingDialog = CreateComponent.createLoadingDialog(socialNetworkSettingScreen,"Unlinking ....");
                loadingDialog.clicked.connect(
                    function() {
                        molomeServiceController.cancelTransactionByTransactionID(socialNetworkSettingScreen.transactionId);
                    }
                );
                transactionId = molomeServiceController.updateTwitterProfile("", "", "", false, twitterLogoutHandler);
            }
        );
    }


    function logInTumblr() {
        pageStack.push(Qt.resolvedUrl("TumblrScreen.qml"));
    }

    MolomeServiceHandler {
        id: tumblrLogoutHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                userManager.setTumblrAvailibility(false);
                globalServices.emitTumblrLoggedInStatusChanged(false);
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", "Unlinked to Tumblr!");
            }
            else
            {
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function logoutTumblr() {
        var confirmationDialog = CreateComponent.createConfirmationDialog("../",socialNetworkSettingScreen,"Are you sure to unlink to Tumblr?");
        confirmationDialog.clicked.connect(
            function() {
                loadingDialog = CreateComponent.createLoadingDialog(socialNetworkSettingScreen,"Unlinking ....");
                loadingDialog.clicked.connect(
                    function() {
                        molomeServiceController.cancelTransactionByTransactionID(socialNetworkSettingScreen.transactionId);
                    }
                );
                transactionId = molomeServiceController.updateTumblrProfile("", "", "", tumblrLogoutHandler);
            }
        );
    }


    function logInWeibo() {
        pageStack.push(Qt.resolvedUrl("WeiboScreen.qml"));
    }

    MolomeServiceHandler {
        id: weiboLogoutHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                userManager.setWeiboAvailibility(false);
                globalServices.emitWeiboLoggedInStatusChanged(false);
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", "Unlinked to Weibo!");
            }
            else
            {
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function logoutWeibo() {
        var confirmationDialog = CreateComponent.createConfirmationDialog("../",socialNetworkSettingScreen,"Are you sure to unlink to Weibo?");
        confirmationDialog.clicked.connect(
            function() {
                loadingDialog = CreateComponent.createLoadingDialog(socialNetworkSettingScreen,"Unlinking ....");
                loadingDialog.clicked.connect(
                    function() {
                        molomeServiceController.cancelTransactionByTransactionID(socialNetworkSettingScreen.transactionId);
                    }
                );
                transactionId = molomeServiceController.updateWeiboProfile("", "", weiboLogoutHandler);
            }
        );
    }


    function logInFlickr() {
        pageStack.push(Qt.resolvedUrl("FlickrScreen.qml"));
    }

    MolomeServiceHandler {
        id: flickrLogoutHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                userManager.setFlickrAvailibility(false);
                globalServices.emitFlickrLoggedInStatusChanged(false);
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", "Unlinked to Flickr!");
            }
            else
            {
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function logoutFlickr() {
        var confirmationDialog = CreateComponent.createConfirmationDialog("../",socialNetworkSettingScreen,"Are you sure to unlink to Flickr?");
        confirmationDialog.clicked.connect(
            function() {
                loadingDialog = CreateComponent.createLoadingDialog(socialNetworkSettingScreen,"Unlinking ....");
                loadingDialog.clicked.connect(
                    function() {
                        molomeServiceController.cancelTransactionByTransactionID(socialNetworkSettingScreen.transactionId);
                    }
                );
                transactionId = molomeServiceController.updateFlickrProfile("", "", flickrLogoutHandler);
            }
        );
    }



    function logInVk() {
        pageStack.push(Qt.resolvedUrl("VKScreen.qml"));
    }

    MolomeServiceHandler {
        id: vkLogoutHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                userManager.setVkAvailibility(false);
                globalServices.emitVkLoggedInStatusChanged(false);
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", "Unlinked to VK!");
            }
            else
            {
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function logoutVk() {
        var confirmationDialog = CreateComponent.createConfirmationDialog("../",socialNetworkSettingScreen,"Are you sure to unlink to VK?");
        confirmationDialog.clicked.connect(
            function() {
                loadingDialog = CreateComponent.createLoadingDialog(socialNetworkSettingScreen,"Unlinking ....");
                loadingDialog.clicked.connect(
                    function() {
                        molomeServiceController.cancelTransactionByTransactionID(socialNetworkSettingScreen.transactionId);
                    }
                );
                transactionId = molomeServiceController.updateVkProfile("", "", "", vkLogoutHandler);
            }
        );
    }


    function logInDropBox() {
        pageStack.push(Qt.resolvedUrl("DropBoxScreen.qml"));
    }

    MolomeServiceHandler {
        id: dropBoxLogoutHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                userManager.setDropBoxAvailibility(false);
                globalServices.emitDropBoxLoggedInStatusChanged(false);
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", "Unlinked to DropBox!");
            }
            else
            {
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function logoutDropBox() {
        var confirmationDialog = CreateComponent.createConfirmationDialog("../",socialNetworkSettingScreen,"Are you sure to unlink to DropBox?");
        confirmationDialog.clicked.connect(
            function() {
                loadingDialog = CreateComponent.createLoadingDialog(socialNetworkSettingScreen,"Unlinking ....");
                loadingDialog.clicked.connect(
                    function() {
                        molomeServiceController.cancelTransactionByTransactionID(socialNetworkSettingScreen.transactionId);
                    }
                );
                transactionId = molomeServiceController.updateDropBoxProfile(0, "", "", dropBoxLogoutHandler);
            }
        );
    }


    function logInGDrive() {
        pageStack.push(Qt.resolvedUrl("GDriveScreen.qml"));
    }

    MolomeServiceHandler {
        id: gDriveLogoutHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                userManager.setGDriveAvailibility(false);
                globalServices.emitGDriveLoggedInStatusChanged(false);
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", "Unlinked to Google Drive!");
            }
            else
            {
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function logoutGDrive() {
        var confirmationDialog = CreateComponent.createConfirmationDialog("../",socialNetworkSettingScreen,"Are you sure to unlink to Google Drive?");
        confirmationDialog.clicked.connect(
            function() {
                loadingDialog = CreateComponent.createLoadingDialog(socialNetworkSettingScreen,"Unlinking ....");
                loadingDialog.clicked.connect(
                    function() {
                        molomeServiceController.cancelTransactionByTransactionID(socialNetworkSettingScreen.transactionId);
                    }
                );
                transactionId = molomeServiceController.unlinkGDrive(gDriveLogoutHandler);
            }
        );
    }


    function logInPicasa() {
        pageStack.push(Qt.resolvedUrl("PicasaScreen.qml"));
    }

    MolomeServiceHandler {
        id: picasaLogoutHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                userManager.setPicasaAvailibility(false);
                globalServices.emitPicasaLoggedInStatusChanged(false);
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", "Unlinked to Picasa!");
            }
            else
            {
                CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(socialNetworkSettingScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function logoutPicasa() {
        var confirmationDialog = CreateComponent.createConfirmationDialog("../",socialNetworkSettingScreen,"Are you sure to unlink to Picasa?");
        confirmationDialog.clicked.connect(
            function() {
                loadingDialog = CreateComponent.createLoadingDialog(socialNetworkSettingScreen,"Unlinking ....");
                loadingDialog.clicked.connect(
                    function() {
                        molomeServiceController.cancelTransactionByTransactionID(socialNetworkSettingScreen.transactionId);
                    }
                );
                transactionId = molomeServiceController.unlinkPicasa(picasaLogoutHandler);
            }
        );
    }
}
