import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../../util/common.js" as Common
import "../../util/oauth/oauth.js" as OAuthJS
import "../js/createComponent.js" as CreateComponent
import "../../platforms"

PageWrapper {
    id: tumblrScreen
    width: themeManager.screenWidth
    height: themeManager.screenHeight
    orientationLock: themeManager.pageOrientationPortrait

    property variant dialog: null
    property int transactionId

    Header {
        id: header
        anchors.top: parent.top
        hasBack: true
        onBackClicked: pageStack.pop();
    }

    Rectangle {
        id: loginArea
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: header.bottom
        anchors.bottom: parent.bottom
        color: "#2f4d6a"

        Item20 {
            id: gap1
        }

        Image {
            id: logo
            anchors.top: gap1.bottom
            anchors.horizontalCenter: parent.horizontalCenter
            source: "../res/tumblr_logo.png"
        }

        Item20 {
            id: gap2
            anchors.top: logo.bottom
        }

        Image {
            id: userPassArea
            anchors.top: gap2.bottom
            anchors.horizontalCenter: parent.horizontalCenter
            source: "../res/user_pass_box.png"

            TextEdit {
                id: textEditUsername
                anchors.left: parent.left
                anchors.leftMargin: themeManager.bigPadding
                anchors.right: parent.right
                anchors.rightMargin: themeManager.bigPadding
                anchors.top: parent.top
                anchors.topMargin: themeManager.bigPadding
                width: parent.width
                height: (parent.height >> 1) - (themeManager.bigPadding * 2)
                textFormat: TextEdit.PlainText
                font.capitalization: Font.AllLowercase
                visible: true
                font.pixelSize: themeManager.dialogFontSizeMedium
                color: "gray"
                wrapMode: TextEdit.NoWrap
                verticalAlignment: TextEdit.AlignVCenter
                Text {
                    text: "Username (Email)"
                    color: "gray"
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.left: parent.left
                    anchors.right: parent.right
                    width: parent.width
                    visible: (textEditUsername.cursorVisible || textEditUsername.text.length > 0) ? false : true
                    font.pixelSize: themeManager.dialogFontSizeMedium
                }
            }

            TextInput {
                id: textEditPassword
                anchors.left: parent.left
                anchors.leftMargin: themeManager.bigPadding
                anchors.right: parent.right
                anchors.rightMargin: themeManager.bigPadding
                anchors.top: textEditUsername.bottom
                anchors.topMargin: themeManager.bigPadding * 2
                width: parent.width
                height: (parent.height >> 1) - (themeManager.bigPadding * 2)
                visible: true
                font.pixelSize: themeManager.dialogFontSizeMedium
                color: "gray"
                echoMode: TextInput.Password
                Text {
                    text: "Password"
                    color: "gray"
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.left: parent.left
                    anchors.right: parent.right
                    width: parent.width
                    visible: (textEditPassword.cursorVisible || textEditPassword.text.length > 0) ? false : true
                    font.pixelSize: themeManager.dialogFontSizeMedium
                }
            }
        }

        Item20 {
            id: gap3
            anchors.top: userPassArea.bottom
        }

        Button {
            id: btnLogin
            anchors.top: gap3.bottom
            bitmap: "../res/darkblue_color_button_long.png"
            bitmap_pressed: "../res/darkblue_color_button_long_click.png"
            text: "Login"
            //height: photoContextDialog.isShareToFacebookActive  == true ? themeManager.photoContexDialogBtnHeight : 0
            anchors.horizontalCenter: parent.horizontalCenter
            onClicked: {
                if (textEditUsername.text === "" || textEditPassword.text === "")
                    CreateComponent.createInformationDialog(tumblrScreen, "", "Please enter all required fields");
                else
                    linkTumblr();
            }
        }

        Rectangle {
            id: remarkBox
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: btnLogin.bottom
            anchors.leftMargin: themeManager.paddingLeftRight
            anchors.rightMargin: themeManager.paddingLeftRight
            anchors.topMargin: themeManager.paddingLeftRight
            radius: themeManager.bigPadding
            height: remarkText.height + themeManager.bigPadding * 2
            border.color: "#B0B0B0"
            border.width: 1

            Text {
                id: remarkText
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: parent.top
                anchors.margins: themeManager.bigPadding
                text: "* <u>Remark</u> : Your username and password will be sent to server via https to authenticate using xAuth method and will NOT be kept anywhere. So please feel safe to enter those login information."
                color: "#B0B0B0"
                font.pixelSize: themeManager.radioButtonFontSize
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            }
        }
    }

    MolomeServiceHandler {
        id: linkTumblrHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(tumblrScreen.dialog.getPageId(), 0);
                globalServices.emitTumblrLoggedInStatusChanged(true);
                userManager.setTumblrAvailibility(true);
                var informationDialog = CreateComponent.createInformationDialog(tumblrScreen, "", "Linked to Tumblr!");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
            else
            {
                CreateComponent.destroyComponent(tumblrScreen.dialog.getPageId(), 0);
                var informationDialog = CreateComponent.createInformationDialog(tumblrScreen, "", ret.reason);
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.destroyComponent(tumblrScreen.dialog.getPageId(), 0);
            var informationDialog = CreateComponent.createInformationDialog(tumblrScreen, "", message);
        }
    }

    function linkTumblr() {
        tumblrScreen.dialog = CreateComponent.createLoadingDialog(tumblrScreen, "Linking to Tumblr ....");
        tumblrScreen.dialog.clicked.connect(
            function() {
                molomeServiceController.cancelTransactionByTransactionID(tumblrScreen.transactionId);
            }
        );
        tumblrScreen.transactionId = molomeServiceController.linkTumblr(textEditUsername.text, textEditPassword.text, linkTumblrHandler);
    }
}
