import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../../util/common.js" as Common
import "../../util/oauth/oauth.js" as OAuthJS
import "../js/createComponent.js" as CreateComponent
import "../../platforms"

PageWrapper {
    id: tumblrScreen
    width: themeManager.screenWidth
    height: themeManager.screenHeight
    orientationLock: themeManager.pageOrientationPortrait

    property string oauth_token
    property string oauth_token_secret

    property variant dialog: null
    property int transactionId

    Header {
        id: header
        anchors.top: parent.top
        hasBack: true
        onBackClicked: pageStack.pop();
    }
    Flickable {
        id: tumblrBox
        width: parent.width
        height: parent.height - header.height
        contentWidth: tumblr.contentsSize.width
        contentHeight: tumblr.contentsSize.height
        interactive: true
        clip: true
        anchors.top: header.bottom
        flickableDirection: Flickable.HorizontalAndVerticalFlick

        Tumblr {
            id: tumblr
            //tw_oauth_token: oauth_token
            preferredHeight: tumblrBox.height
            preferredWidth: tumblrBox.width
            onUser_oauth_verifierChanged: whenUserIsAuthenticated(tumblr.user_oauth_token, tumblr.user_oauth_verifier);

            LoadingImage {
                id: loadingImage
                anchors.fill: parent
                anchors.centerIn: parent
            }

            Component.onCompleted: nami.clearCookies();

            onLoadStarted: loadingImage.visible = true;
            onLoadFinished: loadingImage.visible = false;
        }
    }

    Component.onCompleted: molomeServiceController.getTumblrToken(tumblrTokenHandler);

    MolomeServiceHandler {
        id: tumblrTokenHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var param = OAuthJS.OAuth.getParameterMap(OAuthJS.OAuth.decodeForm(data));
            if (param["oauth_token"] !== "")
            {
                tumblr.doAuthorize(param["oauth_token"]);
                tumblrScreen.oauth_token = param["oauth_token"];
                tumblrScreen.oauth_token_secret = param["oauth_token_secret"];
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(tumblrScreen, "", "Error: Please try again later");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(tumblrScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    MolomeServiceHandler {
        id: updateHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(tumblrScreen.dialog.getPageId(), 0);
                globalServices.emitTumblrLoggedInStatusChanged(true);
                userManager.setTumblrAvailibility(true);
                var informationDialog = CreateComponent.createInformationDialog(tumblrScreen, "", "Linked to Tumblr!");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(tumblrScreen, "", ret.reason);
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(tumblrScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    MolomeServiceHandler {
        id: tumblrAccessTokenHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var param = OAuthJS.OAuth.getParameterMap(OAuthJS.OAuth.decodeForm(data));
            if (param.oauth_token !== "")
            {
                tumblrScreen.transactionId = molomeServiceController.updateTumblrProfile(param.screen_name, param.oauth_token, param.oauth_token_secret, updateHandler);
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(tumblrScreen, "", "Error: Please try again");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(tumblrScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    function whenUserIsAuthenticated(user_oauth_token, user_oauth_verifier) {
        tumblrScreen.dialog = CreateComponent.createLoadingDialog(tumblrScreen, "Linking to Tumblr ....");
        tumblrScreen.dialog.clicked.connect(
            function() {
                molomeServiceController.cancelTransactionByTransactionID(tumblrScreen.transactionId);
                pageStack.pop();
            }
        );
        tumblrScreen.transactionId = molomeServiceController.getTumblrAccessToken(user_oauth_token, user_oauth_verifier, tumblrScreen.oauth_token, tumblrScreen.oauth_token_secret, tumblrAccessTokenHandler);
    }
}
