import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../../util/common.js" as Common
import "../../util/oauth/oauth.js" as OAuthJS
import "../js/createComponent.js" as CreateComponent
import "../../platforms"

PageWrapper {
    id: twitterScreen
    width: themeManager.screenWidth
    height: themeManager.screenHeight
    orientationLock: themeManager.pageOrientationPortrait

    property string oauth_token

    property variant dialog: null
    property int transactionId

    Header {
        id: header
        anchors.top: parent.top
        hasBack: true
        onBackClicked: pageStack.pop();
    }

    Rectangle {
        id: loginArea
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: header.bottom
        anchors.bottom: followBox.top
        color: "#c0deed"

        Item20 {
            id: gap1
        }

        Image {
            id: logo
            anchors.top: gap1.bottom
            anchors.horizontalCenter: parent.horizontalCenter
            source: "../res/twitter_logo.png"
        }

        Item20 {
            id: gap2
            anchors.top: logo.bottom
        }

        Image {
            id: userPassArea
            anchors.top: gap2.bottom
            anchors.horizontalCenter: parent.horizontalCenter
            source: "../res/user_pass_box.png"

            TextEdit {
                id: textEditUsername
                anchors.left: parent.left
                anchors.leftMargin: themeManager.bigPadding
                anchors.right: parent.right
                anchors.rightMargin: themeManager.bigPadding
                anchors.top: parent.top
                anchors.topMargin: themeManager.bigPadding
                width: parent.width
                height: (parent.height >> 1) - (themeManager.bigPadding * 2)
                textFormat: TextEdit.PlainText
                font.capitalization: Font.AllLowercase
                visible: true
                font.pixelSize: themeManager.dialogFontSizeMedium
                color: "gray"
                wrapMode: TextEdit.NoWrap
                verticalAlignment: TextEdit.AlignVCenter
                Text {
                    text: "Username"
                    color: "gray"
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.left: parent.left
                    anchors.right: parent.right
                    width: parent.width
                    visible: (textEditUsername.cursorVisible || textEditUsername.text.length > 0) ? false : true
                    font.pixelSize: themeManager.dialogFontSizeMedium
                }
            }

            TextInput {
                id: textEditPassword
                anchors.left: parent.left
                anchors.leftMargin: themeManager.bigPadding
                anchors.right: parent.right
                anchors.rightMargin: themeManager.bigPadding
                anchors.top: textEditUsername.bottom
                anchors.topMargin: themeManager.bigPadding * 2
                width: parent.width
                height: (parent.height >> 1) - (themeManager.bigPadding * 2)
                visible: true
                font.pixelSize: themeManager.dialogFontSizeMedium
                color: "gray"
                echoMode: TextInput.Password
                Text {
                    text: "Password"
                    color: "gray"
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.left: parent.left
                    anchors.right: parent.right
                    width: parent.width
                    visible: (textEditPassword.cursorVisible || textEditPassword.text.length > 0) ? false : true
                    font.pixelSize: themeManager.dialogFontSizeMedium
                }
            }
        }

        Item20 {
            id: gap3
            anchors.top: userPassArea.bottom
        }

        Button {
            id: btnLogin
            anchors.top: gap3.bottom
            bitmap: "../res/darkblue_color_button_long.png"
            bitmap_pressed: "../res/darkblue_color_button_long_click.png"
            text: "Login"
            //height: photoContextDialog.isShareToFacebookActive  == true ? themeManager.photoContexDialogBtnHeight : 0
            anchors.horizontalCenter: parent.horizontalCenter
            onClicked: {
                if (textEditUsername.text === "" || textEditPassword.text === "")
                    CreateComponent.createInformationDialog(twitterScreen, "", "Please enter all required fields");
                else
                    linkTwitter();
            }
        }

        Rectangle {
            id: remarkBox
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: btnLogin.bottom
            anchors.leftMargin: themeManager.paddingLeftRight
            anchors.rightMargin: themeManager.paddingLeftRight
            anchors.topMargin: themeManager.paddingLeftRight
            radius: themeManager.bigPadding
            height: remarkText.height + themeManager.bigPadding * 2
            border.color: "#B0B0B0"
            border.width: 1

            Text {
                id: remarkText
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: parent.top
                anchors.margins: themeManager.bigPadding
                text: "* <u>Remark</u> : Your username and password will be sent to server via https to authenticate using xAuth method and will NOT be kept anywhere. So please feel safe to enter those login information."
                color: "#B0B0B0"
                font.pixelSize: themeManager.radioButtonFontSize
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            }
        }
    }

    Image {
        id: followBox
        source: "../res/twitter_bt_bar.png"
        anchors.bottom: parent.bottom
        width: parent.width
        height: themeManager.followBoxHeight
        MouseArea {
            id: hitBox
            anchors.fill: parent
            onClicked: ;
        }
        RadioButton {
            id: btnCheck
            y: themeManager.followCheckBoxY
            width: themeManager.followCheckBoxWidthHeight
            height: themeManager.followCheckBoxWidthHeight
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
            anchors.margins: themeManager.smallPadding
            bitmap: "../res/dialog_checkbox_normal.png"
            bitmap_pressed: "../res/dialog_checkbox_checked.png"
            bitmap_selected: "../res/dialog_checkbox_checked.png"
            text: "Follow @MOLOME"
            anchors.leftMargin: themeManager.bigPadding
            selected: true
            onClicked: btnCheck.selected = !btnCheck.selected
        }
    }

    MolomeServiceHandler {
        id: linkTwitterHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(twitterScreen.dialog.getPageId(), 0);
                globalServices.emitTwitterLoggedInStatusChanged(true);
                userManager.setTwitterAvailibility(true);
                var informationDialog = CreateComponent.createInformationDialog(twitterScreen, "", "Linked to Twitter!");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
            else
            {
                CreateComponent.destroyComponent(twitterScreen.dialog.getPageId(), 0);
                var informationDialog = CreateComponent.createInformationDialog(twitterScreen, "", ret.reason);
                //informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.destroyComponent(twitterScreen.dialog.getPageId(), 0);
            var informationDialog = CreateComponent.createInformationDialog(twitterScreen, "", message);
            //informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    function linkTwitter() {
        twitterScreen.dialog = CreateComponent.createLoadingDialog(twitterScreen, "Linking to Twitter ....");
        twitterScreen.dialog.clicked.connect(
            function() {
                molomeServiceController.cancelTransactionByTransactionID(twitterScreen.transactionId);
            }
        );
        twitterScreen.transactionId = molomeServiceController.linkTwitter(textEditUsername.text, textEditPassword.text, btnCheck.selected, linkTwitterHandler);
    }

    /*
    Flickable {
        id: twitterBox
        width: parent.width
        height: parent.height - (header.height + followBox.height)
        contentWidth: twitter.width
        contentHeight: twitter.height
        interactive: true
        clip: true
        anchors.top: header.bottom
        anchors.bottom: followBox.top

        Twitter {
            id: twitter
            tw_oauth_token: oauth_token
            preferredHeight: twitterBox.height
            preferredWidth: twitterBox.width
            onUrlChanged: twitterScreen.checkBoxActive = false
            onUser_oauth_verifierChanged: whenUserIsAuthenticated(twitter.user_oauth_token, twitter.user_oauth_verifier);

            LoadingImage {
                id: loadingImage
                anchors.fill: parent
                anchors.centerIn: parent
            }

            Component.onCompleted: nami.clearCookies();

            onLoadStarted: loadingImage.visible = true;
            onLoadFinished: loadingImage.visible = false;
        }

    }
    Image {
        id: followBox
        source: "../res/twitter_bt_bar.png"
        anchors.bottom: parent.bottom
        width: parent.width
        height: themeManager.followBoxHeight
        MouseArea {
            id: hitBox
            anchors.fill: parent
            onClicked: ;
        }
        RadioButton {
            id: btnCheck
            y: themeManager.followCheckBoxY
            width: themeManager.followCheckBoxWidthHeight
            height: themeManager.followCheckBoxWidthHeight
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
            anchors.margins: themeManager.smallPadding
            bitmap: "../res/dialog_checkbox_normal.png"
            bitmap_pressed: "../res/dialog_checkbox_checked.png"
            bitmap_selected: "../res/dialog_checkbox_checked.png"
            text: "Follow @MOLOME"
            anchors.leftMargin: themeManager.bigPadding
            selected: twitterScreen.follow_molome
            onClicked: {
                btnCheck.selected = btnCheck.selected == false ? true : false
                twitterScreen.follow_molome = btnCheck.selected == true ? true: false
            }
        }
    }
    Component.onCompleted: molomeServiceController.getTwitterToken(twitterTokenHandler);

    MolomeServiceHandler {
        id: twitterTokenHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var param = OAuthJS.OAuth.getParameterMap(OAuthJS.OAuth.decodeForm(data));
            if (param["oauth_token"] !== "")
            {
                twitterScreen.oauth_token = param["oauth_token"];
                twitterScreen.checkBoxActive = true;
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(twitterScreen, "", "Error: Please try again later");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(twitterScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    MolomeServiceHandler {
        id: updateHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(twitterScreen.dialog.getPageId(), 0);
                globalServices.emitTwitterLoggedInStatusChanged(true);
                userManager.setTwitterAvailibility(true);
                var informationDialog = CreateComponent.createInformationDialog(twitterScreen, "", "Linked to Twitter!");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(twitterScreen, "", ret.reason);
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(twitterScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    MolomeServiceHandler {
        id: twitterAccessTokenHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var param = OAuthJS.OAuth.getParameterMap(OAuthJS.OAuth.decodeForm(data));
            if (param.oauth_token !== "")
            {
                twitterScreen.transactionId = molomeServiceController.updateTwitterProfile(param.screen_name, param.oauth_token, param.oauth_token_secret, twitterScreen.follow_molome, updateHandler);
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(twitterScreen, "", "Error: Please try again");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(twitterScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    function whenUserIsAuthenticated(user_oauth_token, user_oauth_verifier) {
        twitterScreen.dialog = CreateComponent.createLoadingDialog(twitterScreen, "Linking to Twitter ....");
        twitterScreen.dialog.clicked.connect(
            function() {
                molomeServiceController.cancelTransactionByTransactionID(twitterScreen.transactionId);
                pageStack.pop();
            }
        );
        twitterScreen.transactionId = molomeServiceController.getTwitterAccessToken(user_oauth_token, user_oauth_verifier, twitterAccessTokenHandler);
    }
    */
}
