import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../../util/common.js" as Common
import "../../platforms"
import "../js/createComponent.js" as CreateComponent

PageWrapper {
    id: uploadingQueueScreen
    width: themeManager.screenWidth
    height: themeManager.screenHeight
    orientationLock: themeManager.pageOrientationPortrait
    MouseArea {
        anchors.fill: parent
    }

    Header {
        id: header
        hasBack: true
        anchors.top: parent.top
        onBackClicked: pageStack.pop();
        z: 1
        MouseArea {
            id: goToTopHitBox
            anchors.fill: parent
            onClicked: goToTop();
        }
    }

    HeaderBar {
        id: headerCaption
        anchors.top: header.bottom
        text: qsTr("Uploading Queue")
        z: 1
    }

    GridView {
        id: body
        anchors.top: headerCaption.bottom
        width: parent.width
        height: parent.height - (header.height + headerCaption.height)
        anchors.left: parent.left
        anchors.leftMargin: themeManager.fifteenPadding
        cellWidth: (themeManager.screenWidth >> 1) - themeManager.smallPadding
        cellHeight: (themeManager.screenWidth >> 1) - themeManager.smallPadding
        model: uploaderQueueModel
        delegate: UploadPhotoComponent {
            onClicked: cancelUpload(folder_code);
        }
    }

    function cancelUpload(folderCode) {
        var confirmationDialog = CreateComponent.createConfirmationDialog("../", uploadingQueueScreen, "This will abort the upload in progress of this photo, Process with removal?");
        confirmationDialog.clicked.connect(
            function() {
                uploaderQueueModel.removeQueueFromFolderCode(folderCode);
            }
        );
    }

    function goToTop() {
        body.contentY = 0;
    }

    Component.onCompleted: globalServices.uploadingQueueChanged.connect(onUploadingQueueChanged);
    Component.onDestruction: globalServices.uploadingQueueChanged.disconnect(onUploadingQueueChanged);

    function onUploadingQueueChanged() {
        if (uploaderQueueModel.getQueueCount() === 0)
            pageStack.pop();
    }
}
