import MOLOMELib 1.0
import QtQuick 1.0
import QtWebKit 1.0
import "../UIComponents"
import "../ListItem"
import "../ButtonComponents"
import "../../util/constant.js" as Constant
import "../../util/common.js" as Common
import "../js/createComponent.js" as CreateComponent
import "../../platforms"
import "../ListDelegate"

PageWrapper {
    id: userTimelineScreen
    width: themeManager.screenWidth
    height: themeManager.screenHeight

    orientationLock: themeManager.pageOrientationPortrait

    property string title
    property string userName
    property int picture_per_page: 21
    property int reqId: 1007
    property int newestId
    property int oldestId

    onUserNameChanged: prepareUserTimeline(userTimelineScreen.userName, false);

    /*
    Text {
        id: noPhototext
        wrapMode: Text.WrapAtWordBoundaryOrAnywhere
        anchors.centerIn: parent
        width: parent.width - themeManager.twentyPadding
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.margins: themeManager.bigPadding
        visible: userTimelineScreen.photo_Count == 0 ? true : false
        color: "gray"
        horizontalAlignment: Text.AlignHCenter
        text: "No photo."
    }
    */
    Header {
        id: header
        hasBack: true
        anchors.top: parent.top
        z: 1
        onBackClicked: pageStack.pop();
        MouseArea {
            id: goToTopHitBox
            anchors.fill: parent
            onClicked: goToTop();
        }
    }

    HeaderBar {
        id: headerCaption
        anchors.top: header.bottom
        text: userTimelineScreen.title
        z: 1
    }

    Text {
        id: cannotAccessProfileText
        visible: false
        anchors.top: headerCaption.bottom
        anchors.topMargin: (parent.height - header.height - headerCaption.height - font.pixelSize) >> 1
        anchors.horizontalCenter: parent.horizontalCenter
        text: "You cannot access this profile"
        style: Text.Raised
        styleColor: "#e6e6e6"
        color: "#808080"
        font.pixelSize: themeManager.profileDetailUsernameFontSize
    }

    GridView {
        id: timelineView
        property bool isLoading: false
        anchors.top: headerCaption.bottom
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.leftMargin: themeManager.bigPadding
        width: themeManager.screenWidth - themeManager.bigPadding
        model: UserTimelineModel { id: userTimelineModel }
        cellWidth: themeManager.photoComponentWidth + 5
        cellHeight: themeManager.photoComponentHeight + 5
        delegate: PhotoComponentDelegate { cacheMode: ImageCacheMode.CacheNotImportant }

        header: Item10 {}
        footer: Item {
            width: parent.width
            height: childrenRect.height
            LoadMoreButton {
                id: loadMoreButton
                text: isLoading ? "Loading" : "Load More"
                anchors.leftMargin: 0
                isLoading: timelineView.isLoading;
                onClicked: loadMore();
            }
            Item10 { anchors.top: loadMoreButton.bottom; }
        }

        cacheBuffer: timelineView.height * 2

        Component.onCompleted: goToTop();
    }

    function goToTop()
    {
        timelineView.contentY = -themeManager.tenPadding;
    }

    function prepareUserTimeline(username, loadMore) {
        timelineView.isLoading = true
        molomeServiceController.getUserTimelineByUsername(username, 1, userTimelineScreen.picture_per_page, 0, 0, prepareUserTimelineHandler);
    }

    function loadMore() {
        if (timelineView.isLoading)
            return;
        timelineView.isLoading = true
        molomeServiceController.getUserTimelineByUsername(userName, 1, userTimelineScreen.picture_per_page, 0, userTimelineModel.getOldestPictureId(), prepareUserTimelineHandler);
    }

    MolomeServiceHandler {
        id: prepareUserTimelineHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var parseSuccess = userTimelineModel.parseJSON(data);
            if (parseSuccess)
            {
                processData();
                if (userTimelineModel.lastParsedRowCount() < userTimelineScreen.picture_per_page)
                    timelineView.footer = null;
            }
            else
            {
                if (userTimelineModel.getErrorCode() === 22)
                {
                    cannotAccessProfileText.visible = true
                    timelineView.visible = false
                }
            }

            timelineView.isLoading = false
        }
        function onMolomeServiceError(statusCode, message)
        {
            timelineView.isLoading = false
        }
    }

    Component.onCompleted: {
        globalServices.setLovedCommentedData.connect(userTimelineScreen.onLovedCommentedDataSet);
        globalServices.pictureDeleted.connect(onPictureDeleted);
        globalServices.imageCaptionChanged.connect(onImageCaptionChanged);
        globalServices.accessLevelSaltChanged.connect(onAccessLevelSaltChanged);
    }
    Component.onDestruction: {
        globalServices.setLovedCommentedData.disconnect(userTimelineScreen.onLovedCommentedDataSet);
        globalServices.pictureDeleted.disconnect(onPictureDeleted);
        globalServices.imageCaptionChanged.disconnect(onImageCaptionChanged);
        globalServices.accessLevelSaltChanged.disconnect(onAccessLevelSaltChanged);
    }

    function onLovedCommentedDataSet(picture_id, love_count, done_love, comment_count, done_comment)
    {
        userTimelineModel.setLovedCommentedData(picture_id, love_count, done_love, comment_count, done_comment);
    }

    function onPictureDeleted(pictureId) {
        userTimelineModel.removePictureById(pictureId)
    }

    function onImageCaptionChanged(picture_id, caption) {
        userTimelineModel.setPhotoName(picture_id, caption);
    }

    function onAccessLevelSaltChanged(picture_id, access_level, salt) {
        userTimelineModel.setAccessLevelSalt(picture_id, access_level, salt);
    }
}
