import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../../util/common.js" as Common
import "../../util/oauth/oauth.js" as OAuthJS
import "../js/createComponent.js" as CreateComponent
import "../../platforms"

PageWrapper {
    id: vkScreen
    width: themeManager.screenWidth
    height: themeManager.screenHeight
    orientationLock: themeManager.pageOrientationPortrait

    property string oauth_token

    property variant dialog: null
    property int transactionId

    Header {
        id: header
        anchors.top: parent.top
        hasBack: true
        onBackClicked: pageStack.pop();
    }
    Flickable {
        id: vkBox
        width: parent.width
        height: parent.height - header.height
        contentWidth: vk.contentsSize.width
        contentHeight: vk.contentsSize.height
        interactive: true
        clip: true
        anchors.top: header.bottom
        flickableDirection: Flickable.HorizontalAndVerticalFlick

        Vk {
            id: vk
            preferredHeight: vkBox.height
            preferredWidth: vkBox.width
            onTokenReady: whenUserIsAuthenticated(user_vk_token, user_vk_id, user_vk_expires_in);

            LoadingImage {
                id: loadingImage
                anchors.fill: parent
                anchors.centerIn: parent
            }

            Component.onCompleted: nami.clearCookies();

            onLoadStarted: loadingImage.visible = true;
            onLoadFinished: loadingImage.visible = false;
        }
    }

    //Component.onCompleted: molomeServiceController.getVkToken(vkTokenHandler);

    MolomeServiceHandler {
        id: vkTokenHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var param = OAuthJS.OAuth.getParameterMap(OAuthJS.OAuth.decodeForm(data));
            if (param["oauth_token"] !== "")
            {
                vk.doAuthorize(param["oauth_token"]);
                vkScreen.oauth_token = param["oauth_token"];
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(vkScreen, "", "Error: Please try again later");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(vkScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    MolomeServiceHandler {
        id: updateHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(vkScreen.dialog.getPageId(), 0);
                globalServices.emitVkLoggedInStatusChanged(true);
                userManager.setVkAvailibility(true);
                var informationDialog = CreateComponent.createInformationDialog(vkScreen, "", "Linked to VK!");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(vkScreen, "", ret.reason);
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(vkScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    function whenUserIsAuthenticated(user_token, user_id, expires_in) {
        vkScreen.dialog = CreateComponent.createLoadingDialog(vkScreen, "Linking to VK ....");
        vkScreen.dialog.clicked.connect(
            function() {
                molomeServiceController.cancelTransactionByTransactionID(vkScreen.transactionId);
                pageStack.pop();
            }
        );
        vkScreen.transactionId = molomeServiceController.updateVkProfile(user_token, user_id, expires_in, updateHandler);
    }
}
