import QtQuick 1.0
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../../util/common.js" as Common
import "../../util/oauth/oauth.js" as OAuthJS
import "../js/createComponent.js" as CreateComponent
import "../../platforms"

PageWrapper {
    id: weiboScreen
    width: themeManager.screenWidth
    height: themeManager.screenHeight
    orientationLock: themeManager.pageOrientationPortrait

    property string oauth_token

    property variant dialog: null
    property int transactionId

    Header {
        id: header
        anchors.top: parent.top
        hasBack: true
        onBackClicked: pageStack.pop();
    }
    Flickable {
        id: weiboBox
        width: parent.width
        height: parent.height - header.height
        contentWidth: weibo.contentsSize.width
        contentHeight: weibo.contentsSize.height
        interactive: true
        clip: true
        anchors.top: header.bottom
        flickableDirection: Flickable.HorizontalAndVerticalFlick

        Weibo {
            id: weibo
            //tw_oauth_token: oauth_token
            preferredHeight: weiboBox.height
            preferredWidth: weiboBox.width
            onUser_oauth_verifierChanged: whenUserIsAuthenticated(weibo.user_oauth_token, weibo.user_oauth_verifier);

            LoadingImage {
                id: loadingImage
                anchors.fill: parent
                anchors.centerIn: parent
            }

            Component.onCompleted: nami.clearCookies();

            onLoadStarted: loadingImage.visible = true;
            onLoadFinished: loadingImage.visible = false;
        }
    }

    Component.onCompleted: {
        weibo.url = "https://api.weibo.com/oauth2/authorize?client_id=2996510837&response_type=code&redirect_uri=http://molo.me/auth/weibo/?command=cb";
        //molomeServiceController.getWeiboToken(weiboTokenHandler);
    }

    MolomeServiceHandler {
        id: weiboTokenHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var param = OAuthJS.OAuth.getParameterMap(OAuthJS.OAuth.decodeForm(data));
            if (param["oauth_token"] !== "")
            {
                weibo.doAuthorize(param["oauth_token"]);
                weiboScreen.oauth_token = param["oauth_token"];
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(weiboScreen, "", "Error: Please try again later");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(weiboScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    MolomeServiceHandler {
        id: updateHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(weiboScreen.dialog.getPageId(), 0);
                globalServices.emitWeiboLoggedInStatusChanged(true);
                userManager.setWeiboAvailibility(true);
                var informationDialog = CreateComponent.createInformationDialog(weiboScreen, "", "Linked to Weibo!");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(weiboScreen, "", ret.reason);
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(weiboScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    MolomeServiceHandler {
        id: weiboAccessTokenHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var param = OAuthJS.OAuth.getParameterMap(OAuthJS.OAuth.decodeForm(data));
            if (param.oauth_token !== "")
            {
                weiboScreen.transactionId = molomeServiceController.updateWeiboProfile(param.oauth_token, param.oauth_token_secret, updateHandler);
            }
            else
            {
                var informationDialog = CreateComponent.createInformationDialog(weiboScreen, "", "Error: Please try again");
                informationDialog.clicked.connect(function() { pageStack.pop(); });
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            var informationDialog = CreateComponent.createInformationDialog(weiboScreen, "", message);
            informationDialog.clicked.connect(function() { pageStack.pop(); });
        }
    }

    function whenUserIsAuthenticated(user_oauth_token, user_oauth_verifier) {
        weiboScreen.dialog = CreateComponent.createLoadingDialog(weiboScreen, "Linking to Weibo ....");
        weiboScreen.dialog.clicked.connect(
            function() {
                molomeServiceController.cancelTransactionByTransactionID(weiboScreen.transactionId);
                pageStack.pop();
            }
        );
        weiboScreen.transactionId = molomeServiceController.getWeiboAccessToken(user_oauth_token, user_oauth_verifier, weiboAccessTokenHandler);
    }
}
