import QtQuick 1.0
import MOLOMELib 1.0
import "../ButtonComponents"
import "../UIComponents"
import "../js/createComponent.js" as CreateComponent
import "../../util/common.js" as Common
import "../../platforms"
import "../Dialog"

PageWrapper {
    id: welcomeScreen
    width: themeManager.screenWidth
    height: themeManager.screenHeight
    property variant logInDialog
    property variant registerDialog
    property variant loadingDialog
    orientationLock: themeManager.pageOrientationPortrait

    property string processingUsername

    property int registerTransactionId
    property int loginTransactionId
    property int getFrontPageTransactionId

    property variant pageLoading: null

    Image {
        id: header
        source: "../res/welcome_screen_header.png"
        z: 1
    }
    Item {
        id: body
        anchors.top: header.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: image1.top

        GridView {
            id: frontPageArea
            anchors.fill: parent
            anchors.leftMargin: themeManager.bigPadding * 4 / themeManager.frontPageImagePerRow
            model: FrontPageModel { id: frontPageModel }
            cellWidth: (body.width - themeManager.bigPadding * 2) / themeManager.frontPageImagePerRow
            cellHeight: (body.width - themeManager.bigPadding * 2) / themeManager.frontPageImagePerRow
            delegate: Item {
                width: frontPageArea.cellWidth - (themeManager.bigPadding >> 1)
                height: frontPageArea.cellHeight - (themeManager.bigPadding >> 1)

                CacheableImage {
                    id: badge
                    width: parent.width
                    height: parent.height
                    sourceSize: Qt.size(parent.width, parent.height)
                    loadingImagePath: "../res/loading_thumbnail_image.png"
                    sourceImagePath: "http://p150x150.molo.me/" + picture_code + "_150x150"
                }
            }
            header: Item10 {}
            footer: Item10 {}

            cacheBuffer: frontPageArea.height * 2

            /*
            MolomeServiceHandler {
                id: getPopularTimelineHandler
                function onMolomeServiceDataReceived(success, data)
                {
                    var parseSuccess = frontPageModel.parseJSON(data);
                    frontPageModel.isRefreshing = false
                    if (mainScreen.pageLoading !== null && typeof mainScreen.pageLoading !== "undefined")
                    {
                        mainScreen.pageLoading.visible = false;
                        CreateComponent.destroyComponent(mainScreen.pageLoading.getPageId(), 0);
                    }
                }
                function onMolomeServiceError(statusCode, message)
                {
                    frontPageModel.isRefreshing = false
                }
            }
            */
        }
    }
    Image {
        id: image1
        anchors.bottom: parent.bottom
        source: "../res/welcome_screen_bottom_menu.png"

        Button {
            id: btnLoginRegister
            anchors.centerIn: parent
            bitmap: "../res/login_register_button.png"
            bitmap_pressed: "../res/login_register_button_pressed.png"
            onClicked: pageStack.push(Qt.resolvedUrl("LoginRegisterScreen.qml"));
            text: "Join!"
        }

        SignInButton {
            x: themeManager.welcomeScreenLoginButtonLeft
            y: themeManager.welcomeScreenLoginButtonTop
            visible: false
            onClicked: {
                pageStack.push(Qt.resolvedUrl("LoginRegisterScreen.qml"));
                /*
                welcomeScreen.logInDialog = CreateComponent.createLoginDialog();
                welcomeScreen.logInDialog.clicked.connect(
                    function() {
                        var username = welcomeScreen.logInDialog.getUsername();
                        var password = welcomeScreen.logInDialog.getPassword();
                        if (username === "")
                            CreateComponent.createInformationDialog(welcomeScreen,"","Please enter username.");
                        else if (password === "")
                            CreateComponent.createInformationDialog(welcomeScreen,"","Please enter password.");
                        else
                            login(username,password);
                    }
                );
                */
            }
        }

        NewUserButton {
            x: themeManager.welcomeScreenRegisterButtonLeft
            y: themeManager.welcomeScreenRegisterButtonTop
            visible: false
            onClicked: {
                welcomeScreen.registerDialog = CreateComponent.createRegisterDialog();
                welcomeScreen.registerDialog.clicked.connect(
                    function() {
                        var username = welcomeScreen.registerDialog.getUsername();
                        var password = welcomeScreen.registerDialog.getPassword();
                        var confirmPassword = welcomeScreen.registerDialog.getConfirmPassword();
                        var email = welcomeScreen.registerDialog.getEmail();
                        if(username === "" || password === "" || confirmPassword === "" || email === "")
                            CreateComponent.createInformationDialog(welcomeScreen,"","Please fill all required fields.");
                        else if (password !== confirmPassword)
                            CreateComponent.createInformationDialog(welcomeScreen, "", "Passwords mismatched.");
                        else
                            register(username, password, email);
                    }
                );
            }
        }
    }

    Timer {
        id: timerDestroyLoadingDialog
        repeat: false
        running: false
        triggeredOnStart: false
        interval: 10
        onTriggered: {
            if (loadingDialog)
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
        }
    }

    MolomeServiceHandler {
        id: loginHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                welcomeScreen.logInDialog.destroyDialog();
                userManager.setLoggedUserInformation(ret.user_id, processingUsername, ret.oauth_token, ret.oauth_token_secret);
                userManager.loadLoggedInAccount();
                // To MainScreen
                pageStack.clear();
                pageStack.push(Qt.resolvedUrl("MainScreen.qml"),{isLogInFromWelComeScreen: true})
            }
            else
            {
                CreateComponent.createInformationDialog(welcomeScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(welcomeScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function login(username, password) {
        processingUsername = username;
        loadingDialog = CreateComponent.createLoadingDialog(welcomeScreen, "Logging in ....");
        loadingDialog.clicked.connect(
            function() {
                molomeServiceController.cancelTransactionByTransactionID(loginTransactionId);
            }
        );
        loginTransactionId = molomeServiceController.loginUser(username, password, loginHandler);
    }

    MolomeServiceHandler {
        id: registerHandler
        function onMolomeServiceDataReceived(success, data)
        {
            var ret = JSON.parse(data)
            if (ret.success)
            {
                CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
                welcomeScreen.registerDialog.destroyDialog();
                userManager.setLoggedUserInformation(ret.user_id, processingUsername, ret.oauth_token, ret.oauth_token_secret);
                userManager.loadLoggedInAccount();
                // To MainScreen
                pageStack.pop();
                pageStack.push(Qt.resolvedUrl("../Screen/FriendListScreen.qml"), {title: qsTr("Suggested Friends"), isSuggestFriend: true, btnLoadMoreActive: false, isNewUser : true});
            }
            else
            {
                CreateComponent.createInformationDialog(welcomeScreen, "", ret.reason);
                timerDestroyLoadingDialog.start();
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.createInformationDialog(welcomeScreen, "", message);
            timerDestroyLoadingDialog.start();
        }
    }

    function register(username, password, email) {
        processingUsername = username;
        loadingDialog = CreateComponent.createLoadingDialog(welcomeScreen, "Registering ....");
        loadingDialog.clicked.connect(
            function() {
                molomeServiceController.cancelTransactionByTransactionID(registerTransactionId);
            }
        );
        registerTransactionId = molomeServiceController.registerUser(username, password, email, registerHandler);
    }


    Component.onCompleted: {
        refreshFrontPage();
    }

    Component.onDestruction: {
        frontPageModel.isRefreshing = false
        frontPageModel.clear();
        molomeServiceController.cancelTransactionByTransactionID(welcomeScreen.getFrontPageTransactionId);
    }

    MolomeServiceHandler {
        id: getFrontPageTimelineHandler
        function onMolomeServiceDataReceived(success, data)
        {
            CreateComponent.destroyComponent(welcomeScreen.pageLoading.getPageId(), 0);
            var parseSuccess = frontPageModel.parseJSON(data);
            frontPageModel.isRefreshing = false
            if (welcomeScreen.pageLoading !== null && typeof welcomeScreen.pageLoading !== "undefined")
                welcomeScreen.pageLoading.visible = false;
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.destroyComponent(welcomeScreen.pageLoading.getPageId(), 0);
            frontPageModel.isRefreshing = false
        }
    }

    function refreshFrontPage() {
        if (frontPageModel.isRefreshing)
            return;
        frontPageModel.isRefreshing = true
        if (frontPageModel.getCount() === 0)
            welcomeScreen.pageLoading = CreateComponent.createLoadingComponent(body);
        welcomeScreen.getFrontPageTransactionId = molomeServiceController.getFrontPageTimeline(getFrontPageTimelineHandler);
    }

}
