import QtQuick 1.0
import QtWebKit 1.0
//import QtMultimediaKit 1.1
import MOLOMELib 1.0
import "../UIComponents"
import "../ButtonComponents"
import "../../util/common.js" as Common
import "../../platforms"

MOLOMECamera {
    id : camera

    signal photoCaptured

    x: 0
    y: 0
    width: themeManager.cameraViewfinderWidth
    height: themeManager.cameraViewfinderHeight
    //focus: visible //to receive focus and capture key events
    captureResolution: (themeManager.isPortrait && finalImageResolution <= 768) ? Qt.size(1024, 768) : Qt.size(1280, 960)

    onCameraStateChanged: {
        console.log("Camera State = " + camera.cameraState);
        if (camera.cameraState === MOLOMECamera.LoadedState) {
            cameraStatusText.text = "";
        }

        if (camera.cameraState === MOLOMECamera.ActiveState) {
            //btnCameraFlash.refreshMode()
            btnCameraFocus.refreshMode()
        }
    }

    onImageSaved: {
        console.log("ImageSaved");

        captureScreen.isImageCaptured = true;

        cameraStatusText.text = "Processing";

        //camera.stop();

        var camWidth;
        var gap;
        var xGap;
        var ratio;
        if (themeManager.isPortrait)
        {
            camWidth = Math.floor(captureScreen.height * 4 / 3); //console.debug("$$camWidth: "+camWidth);
            gap = Math.floor((captureScreen.width - camWidth) * 0.5); //console.debug("$$gap: "+gap);
            xGap = header.height + headerMenu.height + cameraTopBlackArea.height - gap; //console.debug("$$xGap: "+xGap);
            ratio = xGap / captureScreen.height;
        }
        else
        {
            //camWidth = Math.floor(captureScreen.width); //console.debug("$$camWidth: "+camWidth);
            //gap = Math.floor((captureScreen.width - camWidth) * 0.5); //console.debug("$$gap: "+gap);
            //xGap = header.height + headerMenu.height + cameraTopBlackArea.height - gap; //console.debug("$$xGap: "+xGap);
            //ratio = xGap / captureScreen.height;
            ratio = (header.height + headerMenu.height) / captureScreen.height;
        }

        imageProcessor.process(path, ratio, themeManager.isPortrait);
        //imageProcessor.processImage(image, ratio, themeManager.isPortrait);

        camera.photoCaptured();

        timerDeleteFile.start()
    }

    /*
    onError: {
        console.log("Error");
    }
    */

    onCaptureFailed: {
        console.log("CaptureFailed");
    }

    onImageCaptured: {
        console.log("ImageCaptured");

        //previewImage.image = image;
        //previewImage.visible = true;
        //camera.visible = false;

        captureScreen.isImageCaptured = true;

        cameraStatusText.text = "Processing";
        /*

        //camera.stop();

        var camWidth = Math.floor(captureScreen.height * 4 / 3); //console.debug("$$camWidth: "+camWidth);
        var gap = Math.floor((captureScreen.width - camWidth) * 0.5); //console.debug("$$gap: "+gap);
        var xGap = header.height + headerMenu.height + cameraTopBlackArea.height - gap; //console.debug("$$xGap: "+xGap);
        var ratio = xGap / captureScreen.height;

        //console.debug(ratio+"$$$$");
        //imageProcessor.process(camera.capturedImagePath, ratio);
        imageProcessor.processImage(image, ratio);

        camera.photoCaptured();
        */
    }

    onLockStatusChanged: {
        //console.log("LockStatus = " + camera.lockStatus);


        if (camera.lockStatus == MOLOMECamera.Unlocked)
        {
            focusZone.setColor(255, 0, 0);
        }
        else if (camera.lockStatus == MOLOMECamera.Searching)
        {
            focusZone.setColor(255, 255, 0);
        }
        else if (camera.lockStatus == MOLOMECamera.Locked)
        {
            camera.unlock()

            focusZone.setColor(0, 255, 0);
        }

        focusZone.visible = true;

        timerHideFocusZone.restart()
    }

    Timer {
        id: timerHideFocusZone
        repeat: false
        running: false
        interval: 2000
        onTriggered: {
            focusZone.visible = false;
        }
    }

    Timer {
        id: timerDeleteFile
        repeat: false
        running: false
        interval: 10
        onTriggered: {
            if (camera !== null)
            {
                storageManager.deleteFile(camera.capturedImagePath);
            }
        }
    }

}
