import QtQuick 1.0
import "../../util/constant.js" as Constant
import "../../util/common.js" as Common
import "../ButtonComponents"
import "../ListComponentSubItem"

Rectangle {
    id: notificationItem
    width: parent.width
    height: themeManager.notificationComponentHeight

    property bool pressed: middleArea.pressed && middleArea.containsMouse

    property int uid: _uid
    property int uid2: _uid2
    property string photoSrcLeft: _photoSrcLeft
    property string photoSrcRight: _photoSrcRight
    property variant dataVMap: _data
    property bool pinned: _pinned
    property bool follow: _follow
    property int action: _action
    property string text: _text
    property bool isNew: _isNew
    property string timestamp: _timestamp

    property int rightMode

    color: pressed ? Constant.COLOR_ARGB_SELECT_BLUE : (pinned ? Constant.COLOR_ARGB_NOTIF_PINNED_ITEM : (isNew ? Constant.COLOR_ARGB_NOTIF_NEW_ITEM : Constant.COLOR_ARGB_NOTIF_NORMAL))

    onActionChanged: {
        if (action === Constant.NOTIFICATION_ACTION_PHOTO)
            rightMode = Constant.NOTIFICATION_RIGHT_AREA_PROFILE_IMAGE;
        else if (action === Constant.NOTIFICATION_ACTION_FOLLOW)
            rightMode = Constant.NOTIFICATION_RIGHT_AREA_FOLLOW;
        else
            rightMode = Constant.NOTIFICATION_RIGHT_AREA_NONE;
    }

    Image {
        id: imageLeft
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.topMargin: themeManager.smallPadding
        anchors.leftMargin: themeManager.bigPadding
        width: themeManager.notificationPhotoWidthHeight
        height: themeManager.notificationPhotoWidthHeight
        sourceSize: Qt.size(themeManager.notificationPhotoWidthHeight, themeManager.notificationPhotoWidthHeight)
        asynchronous: true
        source: notificationItem.photoSrcLeft

        Rectangle{
            id: imageLeftArea
            anchors.fill: parent
            color: (leftAreaHitBox.pressed && leftAreaHitBox.containsMouse) ? Constant.COLOR_ARGB_SELECT_BLUE : Constant.COLOR_ARGB_TRANSPARENT

            MouseArea {
                id: leftAreaHitBox
                anchors.fill: parent
                onClicked: notificationList.clicked(Constant.NOTIFICATION_AREA_LEFT, dataVMap);
            }
        }
    }

    Item {
        id: rightArea
        anchors.top: parent.top
        anchors.right: parent.right
        anchors.topMargin: themeManager.smallPadding
        anchors.rightMargin: themeManager.smallPadding

        Component.onCompleted:
        {
            if (rightMode === Constant.NOTIFICATION_RIGHT_AREA_FOLLOW) {
                rightAreaLoader.sourceComponent = followButtonComponent
            } else if (rightMode === Constant.NOTIFICATION_RIGHT_AREA_PROFILE_IMAGE) {
                rightAreaLoader.sourceComponent = imageRightFrameComponent
            } else {
                rightArea.width = 0;
                rightArea.height = 0;
            }
        }

        Loader {
            id: rightAreaLoader
        }

        Component {
            id: imageRightFrameComponent

            NotificationRightFrame {
                id: imageRightFrame

                Rectangle {
                    id: frameRect
                    anchors.fill: parent
                    property bool pressed: imageRightAreaHitBox.pressed && imageRightAreaHitBox.containsMouse
                    color: pressed ? "#0983E8" : "#00000000"
                }

                Image {
                    id: imageRight
                    anchors.top: parent.top
                    anchors.right: parent.right
                    anchors.topMargin: 3
                    anchors.rightMargin: themeManager.smallPadding
                    width: themeManager.notificationPhotoRightWidthHeight
                    height: themeManager.notificationPhotoRightWidthHeight
                    sourceSize: Qt.size(themeManager.notificationPhotoRightWidthHeight, themeManager.notificationPhotoRightWidthHeight)
                    asynchronous: true
                    source: notificationItem.photoSrcRight

                    Rectangle{
                        anchors.fill: parent
                        color : Constant.COLOR_ARGB_TRANSPARENT

                        MouseArea {
                            id: imageRightAreaHitBox
                            anchors.fill: parent
                            onClicked: notificationList.clicked(Constant.NOTIFICATION_AREA_RIGHT, dataVMap);
                        }
                    }
                }

                Component.onCompleted: {
                    rightArea.width = imageRightFrame.width;
                    rightArea.height = imageRightFrame.height;
                }
            }
        }

        Component {
            id: followButtonComponent
            FollowButton {
                id: followButton
                isFollow: notificationItem.follow
                anchors.top: parent.top
                anchors.topMargin: themeManager.bigPadding
                onClicked: {
                    notificationList.clicked(Constant.NOTIFICATION_AREA_RIGHT, dataVMap);
                }
                Component.onCompleted: {
                    rightArea.width = followButton.width;
                    rightArea.height = followButton.height;
                }
            }
        }

        Component {
            id: friendRequestComponent
            Item {
                width: childrenRect.width
                height: childrenRect.height
                Button {
                    id: btnAcceptFriend
                    anchors.verticalCenter: parent.verticalCenter
                    bitmap: "../res/btn_friend_accept.png"
                    bitmap_pressed: "../res/btn_friend_accept_pressed.png"
                    onClicked: {

                    }
                }
                Button {
                    id: btnRejectFriend
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.left: btnAcceptFriend.right
                    bitmap: "../res/btn_friend_reject.png"
                    bitmap_pressed: "../res/btn_friend_reject_pressed.png"
                    onClicked: {

                    }
                }
            }
        }
    }

    Item {
        id: contentArea
        anchors.left: imageLeft.right
        anchors.right: rightArea.left
        anchors.top: imageLeft.top
        anchors.bottom: imageLeft.bottom

        Text {
            id: textUpperLine
            anchors.top: parent.top
            anchors.topMargin: themeManager.smallPadding
            anchors.left: parent.left
            anchors.right: parent.right
            height: themeManager.notificationTextAreaHeight
            color: pressed ? "#FFFFFF" : "#606060"
            //text: notificationItem.text
            style: pressed ? Text.Normal : Text.Raised
            styleColor: "#ffffff"
            font.pixelSize: themeManager.notificationTextUpperFontSize
            anchors.rightMargin: themeManager.bigPadding
            anchors.leftMargin: themeManager.bigPadding
            verticalAlignment: Text.AlignVCenter
            wrapMode: Text.Wrap

            Component.onCompleted: text = notificationItem.text
        }
        Text {
            id: textLowerLine
            anchors.top: textUpperLine.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            height: themeManager.notificationTextAreaHeight
            color: pressed ? "#FFFFFF" : "#808080"
            //text: dateTimeModel.setDateTime(notificationItem.timestamp, Constant.FORMAT_DATE_TIME)
            style: pressed ? Text.Normal : Text.Raised
            styleColor: "#ffffff"
            font.pixelSize: themeManager.notificationTextLowerFontSize
            anchors.rightMargin: themeManager.bigPadding
            anchors.leftMargin: themeManager.bigPadding
            verticalAlignment: Text.AlignVCenter

            Component.onCompleted: text = dateTimeModel.setDateTime(notificationItem.timestamp, Constant.FORMAT_DATE_TIME)
        }

        MouseArea {
            id: middleArea
            anchors.fill: parent
            onClicked: {
                notificationList.clicked(Constant.NOTIFICATION_AREA_MIDDLE, dataVMap);
            }
        }
    }

    Rectangle {
        color: "#B0B0B0"
        width: parent.width
        height: 1
        anchors.bottom: parent.bottom
    }

}
