import MOLOMELib 1.0
import QtQuick 1.0
import "../ButtonComponents"
import "../../util/constant.js" as Constant
import "../../util/common.js" as Common

Item {
    id: rect
    height: themeManager.profileDetailComponentHeight
    property int numOfPhoto
    property int numOfFollower
    property int numOfFollowing
    property string username
    property string imageProfile: ""
    property bool isFollower
    property bool isLoggedInUser
    property bool isProtected: false
    property bool isFollowed: false
    property bool isFollowRequested: false
    property bool blocked: false

    property bool isFullProfileVisible: profileViewComponent.isFullProfileVisible

    signal photoSummaryClicked
    signal followerSummaryClicked
    signal followingSummaryClicked
    signal editProfileClicked
    signal profilePictureClicked

    onImageProfileChanged: {
        if (rect.imageProfile == "null")
            rect.imageProfile = "";
        imageProfilePic.sourceImagePath = "http://p96x96.molo.me/" + rect.imageProfile + "_96x96";
    }

    CacheableImage {
        id: imageProfilePic
        x: themeManager.imageProfileDetailComponentX
        y: themeManager.imageProfileDetailComponentY
        height: themeManager.imageProfileDetailComponentWidthHeight
        width: themeManager.imageProfileDetailComponentWidthHeight
        sourceSize: Qt.size(themeManager.imageProfileDetailComponentWidthHeight, themeManager.imageProfileDetailComponentWidthHeight)
        loadingImagePath: "../res/loading_thumbnail_image.png"
        cacheMode: ImageCacheMode.CacheProfileImage

        Rectangle {
            id: imageLeftArea
            anchors.fill: parent
            color : (leftArea.pressed && leftArea.containsMouse) ? Constant.COLOR_ARGB_SELECT_BLUE : Constant.COLOR_ARGB_TRANSPARENT
            visible: (imageProfile != "")
            MouseArea {
                id: leftArea
                anchors.fill: parent
                onClicked: rect.profilePictureClicked()
            }
        }
    }

    Text {
        id: txtUserProtected
        x: themeManager.profileDetailComponentPhotoSummaryBtnX
        y: themeManager.profileDetailComponentSummaryBtnY
        text: " User is protected"
        style: Text.Raised
        styleColor: "#e6e6e6"
        color: "#B0B0B0"
        font.pixelSize: themeManager.profileDetailUsernameFontSize * 3 / 4
        visible: !isFullProfileVisible
    }

    PhotoSummaryButton {
        id: photoSummary
        x: themeManager.profileDetailComponentPhotoSummaryBtnX
        y: themeManager.profileDetailComponentSummaryBtnY
        textType: "Photo"
        textValue: rect.numOfPhoto
        visible: isFullProfileVisible
        onClicked: rect.photoSummaryClicked()
    }
    PhotoSummaryButton {
        id: followerSummary
        x: themeManager.profileDetailComponentFollowerSummaryBtnX
        y: themeManager.profileDetailComponentSummaryBtnY
        textType: "Follower"
        textValue: rect.numOfFollower
        visible: isFullProfileVisible
        onClicked: rect.followerSummaryClicked();
    }
    PhotoSummaryButton {
        id: followingSummary
        x: themeManager.profileDetailComponentFollowingSummaryBtnX
        y: themeManager.profileDetailComponentSummaryBtnY
        textType: "Following"
        textValue: rect.numOfFollowing
        visible: isFullProfileVisible
        onClicked: rect.followingSummaryClicked()
    }
    Text {
        id: txtUsername
        x: themeManager.profileDetailUsernameX
        y: themeManager.profileDetailUsernameY
        text: parent.username
        style: Text.Raised
        styleColor: "#e6e6e6"
        color: "#808080"
        font.pixelSize: themeManager.profileDetailUsernameFontSize
    }
    Image {
        id: imgKeyLock
        source: "../res/key_lock.png"
        anchors.left: txtUsername.right
        anchors.bottom: txtUsername.bottom
        visible: isProtected
    }

    RadioButton {
        id: setting
        x: themeManager.profileDetailSettingX
        y: 0
        bitmap: "../res/btn_config.png"
        bitmap_pressed: "../res/btn_config_click.png"
        bitmap_selected: "../res/btn_config_click.png"
        visible: parent.isLoggedInUser
        onClicked: rect.editProfileClicked()
    }

    Rectangle {
        id: separator
        width: parent.width; height: 1; color: "#cccccc"
        anchors.top: parent.bottom
    }
}
