import QtQuick 1.0
import MOLOMELib 1.0
import "../ButtonComponents"
import "../../util/constant.js" as Constant

Rectangle {
    id: followComponent
    property bool isFollowed
    property bool isFollowRequested
    property bool blocked: false

    signal followClicked
    signal unfollowClicked
    signal blockClicked
    signal unblockClicked

    width: themeManager.screenWidth
    height: themeManager.profileFollowComponentHeight
    color: "#80000000"

    Text {
        id: youFollowOrNot
        text: parent.blocked ? "You block this user" : (parent.isFollowRequested ? "Request Sent" : (parent.isFollowed ? "You are following this user" : "You aren't following this user"))
        anchors.left: parent.left
        anchors.leftMargin: themeManager.bigPadding
        anchors.verticalCenter: parent.verticalCenter
        verticalAlignment: Text.AlignVCenter
        style: Text.Raised
        styleColor: "#999999"
        color: "#e6e6e6"
        font.pixelSize: themeManager.followingFontSize
        anchors.right: btnFollowing.left
        anchors.rightMargin: themeManager.smallPadding
    }
    Button {
        id: btnBlock
        visible: !blocked
        anchors.verticalCenter: parent.verticalCenter
        anchors.right: parent.right
        anchors.rightMargin: themeManager.bigPadding
        bitmap: "../res/btn_block.png"
        bitmap_pressed: "../res/btn_block_pressed.png"
        onClicked: followComponent.blockClicked()
    }
    Button {
        id: btnUnblock
        visible: blocked
        anchors.verticalCenter: parent.verticalCenter
        anchors.right: parent.right
        anchors.rightMargin: themeManager.bigPadding
        bitmap: "../res/btn_blocked.png"
        bitmap_pressed: "../res/btn_blocked_pressed.png"
        onClicked: followComponent.unblockClicked()
    }
    SmallButton {
        id: btnRequestSent
        text: "Requested"
        anchors.verticalCenter: parent.verticalCenter
        anchors.right: btnBlock.visible ? btnBlock.left : btnUnblock.left
        anchors.rightMargin: themeManager.smallPadding
        visible: !blocked && parent.isFollowRequested
        textSize: themeManager.smallButtonFontSize
        iconSource: "../res/following_sign.png"
        onClicked: followComponent.unfollowClicked()
    }
    SmallButton {
        id: btnFollowing
        text: "Following"
        anchors.verticalCenter: parent.verticalCenter
        anchors.right: btnBlock.visible ? btnBlock.left : btnUnblock.left
        anchors.rightMargin: themeManager.smallPadding
        visible: !blocked && parent.isFollowed && !parent.isFollowRequested
        textSize: themeManager.smallButtonFontSize
        iconSource: "../res/following_sign.png"
        onClicked: followComponent.unfollowClicked()
    }
    SmallButton {
        id: btnUnFollow
        text: "Follow"
        anchors.verticalCenter: parent.verticalCenter
        color: Constant.COLOR_GRAY
        anchors.right: btnBlock.visible ? btnBlock.left : btnUnblock.left
        anchors.rightMargin: themeManager.smallPadding
        visible: !blocked && !parent.isFollowed && !parent.isFollowRequested
        onClicked: followComponent.followClicked()
    }
}
