import MOLOMELib 1.0
import QtQuick 1.0
import "../UIComponents"
import "../js/createComponent.js" as CreateComponent
import "../../util/constant.js" as Constant
import "../../util/common.js" as Common
import "../ListItem"
import "../js/storage.js" as Storage
import "../js/uiUtils.js" as UIUtils


Flickable {
    id: profileViewComponent
    contentHeight: body.childrenRect.height
    contentWidth: parent.width

    signal badgeClicked(int badge_id,string badgeName,string description,string bigBadgeSource,string badgeSource,string badgeSource_)
    property variant loadingComponent: null
    property variant loadingDialog: null
    property int userId
    property string username
    property string profileByMode
    property int getProfileTransactionId: 0
    property int blockTransactionId: 0
    property int unblockTransactionId: 0
    property bool blocked: false
    property bool isFollowed: false
    property bool isFollowRequested: false
    property bool isProtected: false

    property bool isFullProfileVisible: isFollowed || !isProtected || (profileViewComponent.userId === userManager.getUserId())

    property alias manager: profileViewManager

    onUserIdChanged: {
        if (profileByMode !== "") return;
        if (profileViewManager.isRefreshing) return;
        profileByMode = "userId";
        prepareUserProfile();
    }

    onUsernameChanged: {
        if (profileByMode !== "") return;
        if (profileViewManager.isRefreshing) return;
        profileByMode = "username";
        prepareUserProfile();
    }

    ProfileViewManager {
        id: profileViewManager
    }

    Text {
        id: cannotAccessProfileText
        visible: false
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        text: "You cannot access this profile"
        style: Text.Raised
        styleColor: "#e6e6e6"
        color: "#808080"
        font.pixelSize: themeManager.profileDetailUsernameFontSize
    }

    Item {
        id: body
        visible: false
        width: parent.width
        anchors.left: parent.left
        anchors.right: parent.right
        Item10 {
            id: spaceItemTopMost
            anchors.top: parent.top
        }
        ProfileDetailsComponent {
            id: profileDetails
            anchors.top: spaceItemTopMost.bottom
            blocked: profileViewComponent.blocked
            isProtected: profileViewComponent.isProtected
            isFollowed: profileViewComponent.isFollowed
            isFollowRequested: profileViewComponent.isFollowRequested
            isLoggedInUser: profileViewComponent.userId === userManager.getUserId() ? true : false
            onFollowerSummaryClicked: UIUtils.openUserFollowerScreen(profileDetails.username);
            onFollowingSummaryClicked: UIUtils.openUserFollowingScreen(profileDetails.username);
            onPhotoSummaryClicked: UIUtils.openUserTimelineScreen(profileDetails.username);
            onProfilePictureClicked: {
                if (profileDetails.imageProfile !== "")
                    UIUtils.openPhotoViewFromPictureInfo(profileViewManager.getProfilePictureInfo());
            }
            onEditProfileClicked: pageStack.push(Qt.resolvedUrl("../Screen/ProfileSettingScreen.qml"))
        }
        Item10 {
            id: spaceItemFollow
            anchors.top: profileDetails.bottom
        }
        ProfileFollowComponent {
            id: profileFollow
            anchors.top: spaceItemFollow.bottom
            visible: profileViewComponent.userId === userManager.getUserId() ? false : true
            height: profileFollow.visible === true ? themeManager.profileFollowComponentHeight : 0
            isFollowed: profileViewComponent.isFollowed
            isFollowRequested: profileViewComponent.isFollowRequested
            blocked: profileViewComponent.blocked
            onUnfollowClicked: {
                molomeServiceController.unfollowUser(profileViewComponent.username);
                globalServices.emitSetFollowStatus(profileViewComponent.username, false);
                globalServices.emitClearTimelineRequested();
            }
            onFollowClicked: {
                molomeServiceController.followUser(profileViewComponent.username);
                globalServices.emitSetFollowStatus(profileViewComponent.username, true);
                globalServices.emitClearTimelineRequested();
            }
            onBlockClicked: {
                var dialog = CreateComponent.createConfirmationDialog("../", profileViewScreen, "Do you want to block this user?");
                dialog.clicked.connect(
                   function() {
                        loadingDialog = CreateComponent.createLoadingDialog(profileViewScreen, "Blocking ...");
                        loadingDialog.clicked.connect(
                            function() {
                                molomeServiceController.cancelTransactionByTransactionID(profileViewComponent.blockTransactionId);
                            }
                        );
                        molomeServiceController.blockUser(profileViewComponent.userId, blockUserHandler);
                    }
                );
            }
            onUnblockClicked: {
                loadingDialog = CreateComponent.createLoadingDialog(profileViewScreen, "Unblocking ...");
                loadingDialog.clicked.connect(
                    function() {
                        molomeServiceController.cancelTransactionByTransactionID(profileViewComponent.unblockTransactionId);
                    }
                );
                molomeServiceController.unblockUser(profileViewComponent.userId, unblockUserHandler);
            }
        }
        Item10 {
            id: spaceItemBio
            anchors.top: profileFollow.bottom
        }
        GroupLabel {
            id: profileDescription
            anchors.top: spaceItemBio.bottom
            anchors.right: parent.right
            anchors.rightMargin: themeManager.bigPadding
            anchors.left: parent.left
            anchors.leftMargin: themeManager.bigPadding
        }
        Item10 {
            id: spaceItemBadges
            anchors.top: profileDescription.bottom
        }
        ProfileBadgeComponent {
            id: badgeArea
            anchors.top: spaceItemBadges.bottom
            onClicked: profileViewComponent.badgeClicked(badge_id,badgeName,description,bigBadgeSource,badgeSource,badgeSource_);
        }
        Item10 {
            id: spaceItemPhotos
            anchors.top: badgeArea.bottom
        }
        Item {
            id: photoHeader
            anchors.top: spaceItemPhotos.bottom
            anchors.left: parent.left
            anchors.leftMargin: themeManager.bigPadding
            width: childrenRect.width
            height: photoHeaderText.height + themeManager.twentyPadding
            visible: isFullProfileVisible
            Text {
                id: photoHeaderText
                text: "Recent Photos"
                font.bold: true
                font.pixelSize: themeManager.profileViewCaptionFontSize
                styleColor: "#e6e6e6"
                color: "#808080"
                anchors.verticalCenter: parent.verticalCenter
            }
        }
        PhotoList {
            id: photoArea
            anchors.top: photoHeader.bottom
            width: parent.width
            anchors.left: parent.left
            anchors.leftMargin: themeManager.bigPadding
            anchors.right: parent.right
            anchors.rightMargin: themeManager.bigPadding
            anchors.margins: themeManager.listBetweenPadding
            visible: isFullProfileVisible
        }
        Item10 {
            id: spaceItemBottomMost
            anchors.top: photoArea.bottom
        }
        Item10 {
            id: bottomBox
            anchors.top: spaceItemBottomMost.bottom
        }

    }
    Component.onCompleted: {
        globalServices.bioChanged.connect(onBioChanged);
        globalServices.setLovedCommentedData.connect(profileViewComponent.onLovedCommentedDataSet);
        globalServices.setFollowStatus.connect(profileViewComponent.onFollowStatusSet);
        globalServices.blockedStatusChanged.connect(profileViewComponent.onBlockedStatusChanged);
        globalServices.userProtectedChanged.connect(profileViewComponent.onUserProtectedChanged);
    }
    Component.onDestruction: {
        globalServices.bioChanged.disconnect(onBioChanged);
        globalServices.setLovedCommentedData.disconnect(profileViewComponent.onLovedCommentedDataSet);
        globalServices.setFollowStatus.disconnect(profileViewComponent.onFollowStatusSet);
        globalServices.blockedStatusChanged.disconnect(profileViewComponent.onBlockedStatusChanged);
        globalServices.userProtectedChanged.disconnect(profileViewComponent.onUserProtectedChanged);
    }

    function onLovedCommentedDataSet(picture_id, love_count, done_love, comment_count, done_comment)
    {
        profileViewManager.setLovedCommentedData(picture_id, love_count, done_love, comment_count, done_comment);
    }

    function onFollowStatusSet(username, followed)
    {
        if (username === profileViewComponent.username)
        {
            if (!followed)
            {
                profileViewComponent.isFollowed = false;
                profileViewComponent.isFollowRequested = false;
            }
            else
            {
                if (profileViewComponent.isProtected)
                    profileViewComponent.isFollowRequested = followed
                else
                    profileViewComponent.isFollowed = followed
            }
        }
    }

    function onBioChanged(userId, bio)
    {
        if (userId > 0 && userId === profileViewComponent.userId)
        {
            profileViewManager.setBio(bio);
            profileDescription.bioText = "Bio: " + profileViewManager.getBio();
        }
    }

    function onBlockedStatusChanged(user_id, blocked)
    {
        if (profileViewComponent.userId === user_id)
            profileViewComponent.blocked = blocked
    }

    function onUserProtectedChanged(user_id, is_protected)
    {
        if (profileViewComponent.userId === user_id)
            profileViewComponent.isProtected = is_protected;
    }

    function prepareUserProfile() {
        if (profileViewManager.isRefreshing)
            return;

        profileViewManager.isRefreshing = true

        if (profileViewComponent.userId !== userManager.getUserId())
            profileViewComponent.loadingComponent = CreateComponent.createLoadingComponent(profileViewComponent);

        if (profileByMode === "userId")
            profileViewComponent.getProfileTransactionId = molomeServiceController.getUserProfilesByUserId(profileViewComponent.userId, prepareUserProfileHandler);
        else
            profileViewComponent.getProfileTransactionId = molomeServiceController.getUserProfilesByUsername(profileViewComponent.username, prepareUserProfileHandler);
    }

    function refresh() {
        prepareUserProfile();
    }

    function cancel() {
        profileViewManager.isRefreshing = false
        if (profileViewComponent.loadingComponent !== null && typeof profileViewComponent.loadingComponent !== "undefined")
        {
            profileViewComponent.loadingComponent.visible = false;
            CreateComponent.destroyComponent(profileViewComponent.loadingComponent, 0);
        }
        molomeServiceController.cancelTransactionByTransactionID(profileViewComponent.getProfileTransactionId);
    }

    MolomeServiceHandler {
        id: prepareUserProfileHandler
        function onMolomeServiceDataReceived(success, data)
        {
            profileViewManager.isRefreshing = false
            var parseSuccess = profileViewManager.parseJSON(data);
            if (parseSuccess)
            {
                processData();
                if (profileViewComponent.userId === userManager.getUserId())
                    Storage.setData("profileViewJson", data);
            }
            else
            {
                if (profileViewManager.getErrorCode() === 22)
                {
                    // Cannot access due to blocking or so
                    cannotAccessProfileText.visible = true;
                }
            }

            if (profileViewComponent.loadingComponent !== null && typeof profileViewComponent.loadingComponent !== "undefined")
            {
                profileViewComponent.loadingComponent.visible = false;
                CreateComponent.destroyComponent(profileViewComponent.loadingComponent, 0);
            }
        }
        function onMolomeServiceError(statusCode, message)
        {
            profileViewManager.isRefreshing = false;
            if (profileViewComponent.loadingComponent !== null && typeof profileViewComponent.loadingComponent !== "undefined")
            {
                profileViewComponent.loadingComponent.visible = false;
                CreateComponent.destroyComponent(profileViewComponent.loadingComponent, 0);
            }
        }
    }

    /* Block User */

    MolomeServiceHandler {
        id: blockUserHandler
        function onMolomeServiceDataReceived(success, data)
        {
            CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
            profileViewComponent.blocked = true;
            globalServices.emitSetFollowStatus(profileViewComponent.username, false);
            globalServices.emitBlockedStatusChanged(profileViewComponent.userId, true);
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
        }
    }

    MolomeServiceHandler {
        id: unblockUserHandler
        function onMolomeServiceDataReceived(success, data)
        {
            CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
            profileViewComponent.blocked = false;
            globalServices.emitBlockedStatusChanged(profileViewComponent.userId, false);
        }
        function onMolomeServiceError(statusCode, message)
        {
            CreateComponent.destroyComponent(loadingDialog.getPageId(),0);
        }
    }

    /* End Block User */

    function addDataProfileWhenOffine() {
        if (Storage.getData("profileViewJson") !== null) {
            var data = Storage.getData("profileViewJson");
            var parseSuccess = profileViewManager.parseJSON(data);
            if (parseSuccess)
                processData();
        }
        profileViewComponent.userId = userManager.getUserId();
    }

    function processData() {
        profileViewComponent.userId = profileViewManager.getUserId();
        profileDetails.username = profileViewManager.getUsername();
        profileDetails.numOfPhoto = profileViewManager.getNumOfPhoto();
        profileDetails.numOfFollower = profileViewManager.getNumOfFollower();
        profileDetails.numOfFollowing = profileViewManager.getNumOfFollowing();
        profileDescription.bioText = "Bio: " + profileViewManager.getBio();
        profileDetails.imageProfile = profileViewManager.getProfilePictureCode();
        profileViewComponent.isProtected = profileViewManager.getProtected();
        profileViewComponent.isFollowed = profileViewManager.getFollowed();
        profileViewComponent.isFollowRequested = profileViewManager.getFollowRequested();
        profileViewComponent.blocked = profileViewManager.getBlocked();
        body.visible = true

        if (profileViewComponent.userId === userManager.getUserId())
        {
            userManager.setTwitterAvailibility(profileViewManager.getUseTwitter());
            userManager.setFacebookAvailibility(profileViewManager.getUseFacebook());
            userManager.setTumblrAvailibility(profileViewManager.getUseTumblr());
            userManager.setFlickrAvailibility(profileViewManager.getUseFlickr());
            userManager.setWeiboAvailibility(profileViewManager.getUseWeibo());
            userManager.setVkAvailibility(profileViewManager.getUseVk());
            userManager.setDropBoxAvailibility(profileViewManager.getUseDropBox());
            userManager.setGDriveAvailibility(profileViewManager.getUseGDrive());
            userManager.setPicasaAvailibility(profileViewManager.getUsePicasa());
            userManager.setProfileDetails(profileViewManager.getBio(), profileViewManager.getEmail());
            userManager.setProtected(profileViewManager.getProtected());
            userManager.setPhotoCount(profileViewManager.getNumOfPhoto());
        }
    }

    function goToTop() {
        profileViewComponent.contentY = 0;
    }

    function deletePhoto() {
        profileDetails.numOfPhoto -=1;
    }
}
